Module: IbmCloudPower

Defined in:
lib/ibm_cloud_power/version.rb,
lib/ibm_cloud_power.rb,
lib/ibm_cloud_power/api_error.rb,
lib/ibm_cloud_power/api_client.rb,
lib/ibm_cloud_power/models/job.rb,
lib/ibm_cloud_power/models/src.rb,
lib/ibm_cloud_power/models/host.rb,
lib/ibm_cloud_power/models/jobs.rb,
lib/ibm_cloud_power/models/site.rb,
lib/ibm_cloud_power/models/task.rb,
lib/ibm_cloud_power/models/error.rb,
lib/ibm_cloud_power/models/event.rb,
lib/ibm_cloud_power/models/image.rb,
lib/ibm_cloud_power/models/route.rb,
lib/ibm_cloud_power/configuration.rb,
lib/ibm_cloud_power/models/events.rb,
lib/ibm_cloud_power/models/images.rb,
lib/ibm_cloud_power/models/routes.rb,
lib/ibm_cloud_power/models/status.rb,
lib/ibm_cloud_power/models/system.rb,
lib/ibm_cloud_power/models/tenant.rb,
lib/ibm_cloud_power/models/volume.rb,
lib/ibm_cloud_power/api/routes_api.rb,
lib/ibm_cloud_power/api_model_base.rb,
lib/ibm_cloud_power/models/network.rb,
lib/ibm_cloud_power/models/ssh_key.rb,
lib/ibm_cloud_power/models/volumes.rb,
lib/ibm_cloud_power/models/add_host.rb,
lib/ibm_cloud_power/models/host_put.rb,
lib/ibm_cloud_power/models/networks.rb,
lib/ibm_cloud_power/models/pod_data.rb,
lib/ibm_cloud_power/models/snapshot.rb,
lib/ibm_cloud_power/models/ssh_keys.rb,
lib/ibm_cloud_power/api/networks_api.rb,
lib/ibm_cloud_power/api/ssh_keys_api.rb,
lib/ibm_cloud_power/models/operation.rb,
lib/ibm_cloud_power/models/secondary.rb,
lib/ibm_cloud_power/models/snapshots.rb,
lib/ibm_cloud_power/models/workspace.rb,
lib/ibm_cloud_power/api/snapshots_api.rb,
lib/ibm_cloud_power/models/datacenter.rb,
lib/ibm_cloud_power/models/event_user.rb,
lib/ibm_cloud_power/models/host_group.rb,
lib/ibm_cloud_power/models/ike_policy.rb,
lib/ibm_cloud_power/models/job_action.rb,
lib/ibm_cloud_power/models/job_status.rb,
lib/ibm_cloud_power/models/network_id.rb,
lib/ibm_cloud_power/models/operations.rb,
lib/ibm_cloud_power/models/pin_policy.rb,
lib/ibm_cloud_power/models/sap_create.rb,
lib/ibm_cloud_power/models/workspaces.rb,
lib/ibm_cloud_power/api/workspaces_api.rb,
lib/ibm_cloud_power/models/datacenters.rb,
lib/ibm_cloud_power/models/host_create.rb,
lib/ibm_cloud_power/models/network_ids.rb,
lib/ibm_cloud_power/models/sap_profile.rb,
lib/ibm_cloud_power/models/snapshot_v1.rb,
lib/ibm_cloud_power/models/stock_image.rb,
lib/ibm_cloud_power/models/system_pool.rb,
lib/ibm_cloud_power/models/volume_info.rb,
lib/ibm_cloud_power/api/datacenters_api.rb,
lib/ibm_cloud_power/api/host_groups_api.rb,
lib/ibm_cloud_power/api/p_cloud_sap_api.rb,
lib/ibm_cloud_power/models/create_image.rb,
lib/ibm_cloud_power/models/export_image.rb,
lib/ibm_cloud_power/models/ike_policies.rb,
lib/ibm_cloud_power/models/image_volume.rb,
lib/ibm_cloud_power/models/job_workflow.rb,
lib/ibm_cloud_power/models/network_peer.rb,
lib/ibm_cloud_power/models/network_port.rb,
lib/ibm_cloud_power/models/peer_subnets.rb,
lib/ibm_cloud_power/models/pod_capacity.rb,
lib/ibm_cloud_power/models/pvm_instance.rb,
lib/ibm_cloud_power/models/route_create.rb,
lib/ibm_cloud_power/models/route_filter.rb,
lib/ibm_cloud_power/models/route_report.rb,
lib/ibm_cloud_power/models/route_update.rb,
lib/ibm_cloud_power/models/sap_profiles.rb,
lib/ibm_cloud_power/models/storage_tier.rb,
lib/ibm_cloud_power/models/volume_group.rb,
lib/ibm_cloud_power/api/p_cloud_jobs_api.rb,
lib/ibm_cloud_power/models/access_config.rb,
lib/ibm_cloud_power/models/cloned_volume.rb,
lib/ibm_cloud_power/models/host_capacity.rb,
lib/ibm_cloud_power/models/image_taskref.rb,
lib/ibm_cloud_power/models/ip_sec_policy.rb,
lib/ibm_cloud_power/models/job_operation.rb,
lib/ibm_cloud_power/models/job_reference.rb,
lib/ibm_cloud_power/models/job_resources.rb,
lib/ibm_cloud_power/models/network_peers.rb,
lib/ibm_cloud_power/models/network_ports.rb,
lib/ibm_cloud_power/models/pvm_instances.rb,
lib/ibm_cloud_power/models/snapshot_list.rb,
lib/ibm_cloud_power/models/software_tier.rb,
lib/ibm_cloud_power/models/tenant_update.rb,
lib/ibm_cloud_power/models/update_volume.rb,
lib/ibm_cloud_power/models/virtual_cores.rb,
lib/ibm_cloud_power/models/volume_action.rb,
lib/ibm_cloud_power/models/volume_groups.rb,
lib/ibm_cloud_power/models/volumes_clone.rb,
lib/ibm_cloud_power/api/network_peers_api.rb,
lib/ibm_cloud_power/api/p_cloud_tasks_api.rb,
lib/ibm_cloud_power/models/available_host.rb,
lib/ibm_cloud_power/models/cloud_instance.rb,
lib/ibm_cloud_power/models/ike_policy_ref.rb,
lib/ibm_cloud_power/models/network_create.rb,
lib/ibm_cloud_power/models/network_update.rb,
lib/ibm_cloud_power/models/peer_interface.rb,
lib/ibm_cloud_power/models/task_reference.rb,
lib/ibm_cloud_power/models/volumes_attach.rb,
lib/ibm_cloud_power/models/volumes_clones.rb,
lib/ibm_cloud_power/models/volumes_delete.rb,
lib/ibm_cloud_power/models/volumes_detach.rb,
lib/ibm_cloud_power/models/vp_mem_volumes.rb,
lib/ibm_cloud_power/models/vpn_connection.rb,
lib/ibm_cloud_power/api/p_cloud_events_api.rb,
lib/ibm_cloud_power/api/p_cloud_images_api.rb,
lib/ibm_cloud_power/models/get_bulk_volume.rb,
lib/ibm_cloud_power/models/host_host_group.rb,
lib/ibm_cloud_power/models/image_reference.rb,
lib/ibm_cloud_power/models/ip_sec_policies.rb,
lib/ibm_cloud_power/models/min_max_default.rb,
lib/ibm_cloud_power/models/peering_network.rb,
lib/ibm_cloud_power/models/placement_group.rb,
lib/ibm_cloud_power/models/snapshot_create.rb,
lib/ibm_cloud_power/models/snapshot_update.rb,
lib/ibm_cloud_power/models/trusted_profile.rb,
lib/ibm_cloud_power/models/vpn_connections.rb,
lib/ibm_cloud_power/api/p_cloud_tenants_api.rb,
lib/ibm_cloud_power/api/p_cloud_volumes_api.rb,
lib/ibm_cloud_power/models/cloud_connection.rb,
lib/ibm_cloud_power/models/console_language.rb,
lib/ibm_cloud_power/models/ip_address_range.rb,
lib/ibm_cloud_power/models/metadata_service.rb,
lib/ibm_cloud_power/models/placement_groups.rb,
lib/ibm_cloud_power/models/pvm_instances_v2.rb,
lib/ibm_cloud_power/models/snapshot_restore.rb,
lib/ibm_cloud_power/models/storage_affinity.rb,
lib/ibm_cloud_power/models/storage_pool_map.rb,
lib/ibm_cloud_power/models/system_resources.rb,
lib/ibm_cloud_power/models/volume_reference.rb,
lib/ibm_cloud_power/api/p_cloud_networks_api.rb,
lib/ibm_cloud_power/models/clone_task_status.rb,
lib/ibm_cloud_power/models/cloud_connections.rb,
lib/ibm_cloud_power/models/console_languages.rb,
lib/ibm_cloud_power/models/deployment_target.rb,
lib/ibm_cloud_power/models/disaster_recovery.rb,
lib/ibm_cloud_power/models/host_group_create.rb,
lib/ibm_cloud_power/models/ike_policy_create.rb,
lib/ibm_cloud_power/models/ike_policy_update.rb,
lib/ibm_cloud_power/models/ip_sec_policy_ref.rb,
lib/ibm_cloud_power/models/network_interface.rb,
lib/ibm_cloud_power/models/network_reference.rb,
lib/ibm_cloud_power/models/pvm_instance_host.rb,
lib/ibm_cloud_power/models/software_licenses.rb,
lib/ibm_cloud_power/models/supported_systems.rb,
lib/ibm_cloud_power/models/volume_onboarding.rb,
lib/ibm_cloud_power/models/workspace_details.rb,
lib/ibm_cloud_power/models/workspace_ssh_key.rb,
lib/ibm_cloud_power/api/p_cloud_instances_api.rb,
lib/ibm_cloud_power/api/p_cloud_snapshots_api.rb,
lib/ibm_cloud_power/models/create_data_volume.rb,
lib/ibm_cloud_power/models/flash_copy_mapping.rb,
lib/ibm_cloud_power/models/host_group_summary.rb,
lib/ibm_cloud_power/models/network_interfaces.rb,
lib/ibm_cloud_power/models/peer_subnet_update.rb,
lib/ibm_cloud_power/models/pvm_instance_cores.rb,
lib/ibm_cloud_power/models/pvm_instance_fault.rb,
lib/ibm_cloud_power/models/route_report_route.rb,
lib/ibm_cloud_power/models/status_description.rb,
lib/ibm_cloud_power/models/storage_controller.rb,
lib/ibm_cloud_power/models/volume_onboardings.rb,
lib/ibm_cloud_power/models/workspace_location.rb,
lib/ibm_cloud_power/models/workspace_ssh_keys.rb,
lib/ibm_cloud_power/models/datacenter_location.rb,
lib/ibm_cloud_power/models/dead_peer_detection.rb,
lib/ibm_cloud_power/models/host_capacity_cores.rb,
lib/ibm_cloud_power/models/host_group_share_op.rb,
lib/ibm_cloud_power/models/network_peer_create.rb,
lib/ibm_cloud_power/models/network_peer_update.rb,
lib/ibm_cloud_power/models/network_port_create.rb,
lib/ibm_cloud_power/models/network_port_update.rb,
lib/ibm_cloud_power/models/pvm_instance_action.rb,
lib/ibm_cloud_power/models/pvm_instance_create.rb,
lib/ibm_cloud_power/models/pvm_instance_delete.rb,
lib/ibm_cloud_power/models/pvm_instance_health.rb,
lib/ibm_cloud_power/models/pvm_instance_memory.rb,
lib/ibm_cloud_power/models/pvm_instance_update.rb,
lib/ibm_cloud_power/models/replication_service.rb,
lib/ibm_cloud_power/models/route_filter_create.rb,
lib/ibm_cloud_power/models/spp_placement_group.rb,
lib/ibm_cloud_power/models/volume_group_action.rb,
lib/ibm_cloud_power/models/volume_group_create.rb,
lib/ibm_cloud_power/models/volume_group_update.rb,
lib/ibm_cloud_power/models/capabilities_details.rb,
lib/ibm_cloud_power/models/clone_task_reference.rb,
lib/ibm_cloud_power/models/cloned_volume_detail.rb,
lib/ibm_cloud_power/models/cloud_connection_vpc.rb,
lib/ibm_cloud_power/models/image_import_details.rb,
lib/ibm_cloud_power/models/image_specifications.rb,
lib/ibm_cloud_power/models/ip_sec_policy_create.rb,
lib/ibm_cloud_power/models/ip_sec_policy_update.rb,
lib/ibm_cloud_power/models/job_resource_details.rb,
lib/ibm_cloud_power/models/multi_volumes_create.rb,
lib/ibm_cloud_power/models/pvm_instance_capture.rb,
lib/ibm_cloud_power/models/pvm_instance_console.rb,
lib/ibm_cloud_power/models/pvm_instance_network.rb,
lib/ibm_cloud_power/models/spp_placement_groups.rb,
lib/ibm_cloud_power/models/system_pool_capacity.rb,
lib/ibm_cloud_power/models/volume_group_details.rb,
lib/ibm_cloud_power/models/volume_snapshot_list.rb,
lib/ibm_cloud_power/models/volumes_clone_cancel.rb,
lib/ibm_cloud_power/models/volumes_clone_create.rb,
lib/ibm_cloud_power/models/volumes_clone_detail.rb,
lib/ibm_cloud_power/models/vp_mem_volume_attach.rb,
lib/ibm_cloud_power/models/vp_mem_volume_create.rb,
lib/ibm_cloud_power/models/vp_mem_volume_update.rb,
lib/ibm_cloud_power/api/p_cloud_pod_capacity_api.rb,
lib/ibm_cloud_power/api/p_cloud_vpn_policies_api.rb,
lib/ibm_cloud_power/models/network_address_group.rb,
lib/ibm_cloud_power/models/pvm_instance_networks.rb,
lib/ibm_cloud_power/models/sap_profile_reference.rb,
lib/ibm_cloud_power/models/shared_processor_pool.rb,
lib/ibm_cloud_power/models/storage_pool_capacity.rb,
lib/ibm_cloud_power/models/storage_pool_combined.rb,
lib/ibm_cloud_power/models/storage_type_capacity.rb,
lib/ibm_cloud_power/models/virtual_serial_number.rb,
lib/ibm_cloud_power/models/volume_groups_details.rb,
lib/ibm_cloud_power/models/volumes_clone_execute.rb,
lib/ibm_cloud_power/models/volumes_clone_request.rb,
lib/ibm_cloud_power/models/vpn_connection_create.rb,
lib/ibm_cloud_power/models/vpn_connection_update.rb,
lib/ibm_cloud_power/api/p_cloud_pvm_instances_api.rb,
lib/ibm_cloud_power/api/p_cloud_storage_tiers_api.rb,
lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb,
lib/ibm_cloud_power/models/host_resource_capacity.rb,
lib/ibm_cloud_power/models/network_address_groups.rb,
lib/ibm_cloud_power/models/network_security_group.rb,
lib/ibm_cloud_power/models/placement_group_create.rb,
lib/ibm_cloud_power/models/placement_group_server.rb,
lib/ibm_cloud_power/models/pvm_instance_operation.rb,
lib/ibm_cloud_power/models/pvm_instance_reference.rb,
lib/ibm_cloud_power/models/pvm_instance_v2_health.rb,
lib/ibm_cloud_power/models/shared_processor_pools.rb,
lib/ibm_cloud_power/models/storage_pools_capacity.rb,
lib/ibm_cloud_power/models/storage_types_capacity.rb,
lib/ibm_cloud_power/models/target_trusted_profile.rb,
lib/ibm_cloud_power/models/update_trusted_profile.rb,
lib/ibm_cloud_power/models/volumes_clone_response.rb,
lib/ibm_cloud_power/api/network_address_groups_api.rb,
lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb,
lib/ibm_cloud_power/models/available_host_capacity.rb,
lib/ibm_cloud_power/models/cloud_connection_create.rb,
lib/ibm_cloud_power/models/cloud_connection_update.rb,
lib/ibm_cloud_power/models/network_security_groups.rb,
lib/ibm_cloud_power/models/pvm_instance_deployment.rb,
lib/ibm_cloud_power/models/supported_software_tier.rb,
lib/ibm_cloud_power/models/update_metadata_service.rb,
lib/ibm_cloud_power/models/volumes_delete_response.rb,
lib/ibm_cloud_power/models/vp_mem_volume_reference.rb,
lib/ibm_cloud_power/api/network_security_groups_api.rb,
lib/ibm_cloud_power/api/p_cloud_vpn_connections_api.rb,
lib/ibm_cloud_power/models/cloud_connection_classic.rb,
lib/ibm_cloud_power/models/cloud_instance_reference.rb,
lib/ibm_cloud_power/models/create_workspace_ssh_key.rb,
lib/ibm_cloud_power/models/network_interface_create.rb,
lib/ibm_cloud_power/models/network_interface_update.rb,
lib/ibm_cloud_power/models/pvm_instance_add_network.rb,
lib/ibm_cloud_power/models/remote_copy_relationship.rb,
lib/ibm_cloud_power/models/sap_profile_vpmem_volume.rb,
lib/ibm_cloud_power/models/snapshot_create_response.rb,
lib/ibm_cloud_power/models/status_description_error.rb,
lib/ibm_cloud_power/models/update_workspace_ssh_key.rb,
lib/ibm_cloud_power/models/volume_group_action_stop.rb,
lib/ibm_cloud_power/models/volume_onboarding_common.rb,
lib/ibm_cloud_power/models/volume_onboarding_create.rb,
lib/ibm_cloud_power/api/p_cloud_placement_groups_api.rb,
lib/ibm_cloud_power/api/p_cloud_storage_capacity_api.rb,
lib/ibm_cloud_power/api/p_cloud_tenants_ssh_keys_api.rb,
lib/ibm_cloud_power/models/ike_policy_authentication.rb,
lib/ibm_cloud_power/models/network_port_pvm_instance.rb,
lib/ibm_cloud_power/models/pvm_instance_multi_create.rb,
lib/ibm_cloud_power/models/pvm_instance_reference_v2.rb,
lib/ibm_cloud_power/models/volume_group_action_reset.rb,
lib/ibm_cloud_power/models/volume_group_action_start.rb,
lib/ibm_cloud_power/models/volume_onboarding_failure.rb,
lib/ibm_cloud_power/api/p_cloud_cloud_connections_api.rb,
lib/ibm_cloud_power/api/p_cloud_disaster_recovery_api.rb,
lib/ibm_cloud_power/api/p_cloud_volume_onboarding_api.rb,
lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb,
lib/ibm_cloud_power/models/disaster_recovery_location.rb,
lib/ibm_cloud_power/models/maximum_storage_allocation.rb,
lib/ibm_cloud_power/models/network_interface_instance.rb,
lib/ibm_cloud_power/models/network_ip_address_metrics.rb,
lib/ibm_cloud_power/models/pvm_instance_configuration.rb,
lib/ibm_cloud_power/models/pvm_instance_virtual_cores.rb,
lib/ibm_cloud_power/models/pvm_instance_volume_update.rb,
lib/ibm_cloud_power/models/spp_placement_group_create.rb,
lib/ibm_cloud_power/models/cloud_connection_gre_tunnel.rb,
lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb,
lib/ibm_cloud_power/models/create_cos_image_import_job.rb,
lib/ibm_cloud_power/models/disaster_recovery_locations.rb,
lib/ibm_cloud_power/models/ipsec_policy_authentication.rb,
lib/ibm_cloud_power/models/network_address_translation.rb,
lib/ibm_cloud_power/models/network_security_group_rule.rb,
lib/ibm_cloud_power/models/pvm_instance_remove_network.rb,
lib/ibm_cloud_power/models/replication_target_location.rb,
lib/ibm_cloud_power/models/volumes_attachment_response.rb,
lib/ibm_cloud_power/models/volumes_clone_async_request.rb,
lib/ibm_cloud_power/models/volumes_detachment_response.rb,
lib/ibm_cloud_power/models/network_address_group_create.rb,
lib/ibm_cloud_power/models/network_address_group_member.rb,
lib/ibm_cloud_power/models/network_address_group_update.rb,
lib/ibm_cloud_power/models/network_security_group_clone.rb,
lib/ibm_cloud_power/models/pvm_instance_placement_group.rb,
lib/ibm_cloud_power/models/pvm_instance_update_response.rb,
lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb,
lib/ibm_cloud_power/models/remove_virtual_serial_number.rb,
lib/ibm_cloud_power/models/shared_processor_pool_create.rb,
lib/ibm_cloud_power/models/shared_processor_pool_detail.rb,
lib/ibm_cloud_power/models/shared_processor_pool_server.rb,
lib/ibm_cloud_power/models/shared_processor_pool_update.rb,
lib/ibm_cloud_power/models/update_virtual_serial_number.rb,
lib/ibm_cloud_power/models/volume_group_create_response.rb,
lib/ibm_cloud_power/models/volume_group_storage_details.rb,
lib/ibm_cloud_power/api/p_cloud_spp_placement_groups_api.rb,
lib/ibm_cloud_power/models/available_host_capacity_cores.rb,
lib/ibm_cloud_power/models/cloud_connection_endpoint_vpc.rb,
lib/ibm_cloud_power/models/network_security_group_create.rb,
lib/ibm_cloud_power/models/network_security_group_member.rb,
lib/ibm_cloud_power/models/network_security_group_update.rb,
lib/ibm_cloud_power/models/pvm_instance_operating_system.rb,
lib/ibm_cloud_power/models/system_pool_shared_core_ratio.rb,
lib/ibm_cloud_power/api/p_cloud_virtual_serial_number_api.rb,
lib/ibm_cloud_power/models/network_security_groups_action.rb,
lib/ibm_cloud_power/models/vpn_connection_create_response.rb,
lib/ibm_cloud_power/api/p_cloud_shared_processor_pools_api.rb,
lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb,
lib/ibm_cloud_power/models/cloud_connection_create_classic.rb,
lib/ibm_cloud_power/models/network_cloud_connections_inner.rb,
lib/ibm_cloud_power/models/network_security_group_add_rule.rb,
lib/ibm_cloud_power/models/volume_remote_copy_relationship.rb,
lib/ibm_cloud_power/models/add_server_virtual_serial_number.rb,
lib/ibm_cloud_power/models/auxiliary_volumes_for_onboarding.rb,
lib/ibm_cloud_power/models/available_host_resource_capacity.rb,
lib/ibm_cloud_power/models/cloud_connection_create_response.rb,
lib/ibm_cloud_power/models/get_server_virtual_serial_number.rb,
lib/ibm_cloud_power/models/network_address_group_add_member.rb,
lib/ibm_cloud_power/models/network_security_group_rule_port.rb,
lib/ibm_cloud_power/models/volume_onboarding_all_of_results.rb,
lib/ibm_cloud_power/models/cloud_connection_endpoint_classic.rb,
lib/ibm_cloud_power/models/network_security_group_add_member.rb,
lib/ibm_cloud_power/models/volume_onboarding_create_response.rb,
lib/ibm_cloud_power/models/cloud_connection_gre_tunnel_create.rb,
lib/ibm_cloud_power/models/network_security_group_move_member.rb,
lib/ibm_cloud_power/models/network_security_group_rule_remote.rb,
lib/ibm_cloud_power/models/create_server_virtual_serial_number.rb,
lib/ibm_cloud_power/models/delete_server_virtual_serial_number.rb,
lib/ibm_cloud_power/models/update_server_virtual_serial_number.rb,
lib/ibm_cloud_power/models/workspace_power_edge_router_details.rb,
lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb,
lib/ibm_cloud_power/models/shared_processor_pool_placement_group.rb,
lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb,
lib/ibm_cloud_power/models/capabilities_details_supported_systems.rb,
lib/ibm_cloud_power/models/volume_group_remote_copy_relationships.rb,
lib/ibm_cloud_power/models/volume_onboarding_create_volumes_inner.rb,
lib/ibm_cloud_power/models/cloud_connection_virtual_private_clouds.rb,
lib/ibm_cloud_power/models/cloud_connection_endpoint_classic_update.rb,
lib/ibm_cloud_power/models/workspace_network_security_groups_details.rb,
lib/ibm_cloud_power/models/disaster_recovery_asynchronous_replication.rb,
lib/ibm_cloud_power/models/network_security_group_rule_protocol_tcp_flag.rb,
lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb,
lib/ibm_cloud_power/models/shared_processor_pool_detail_shared_processor_pool.rb,
lib/ibm_cloud_power/models/auxiliary_volumes_for_onboarding_auxiliary_volumes_inner.rb,
lib/ibm_cloud_power/models/volume_onboarding_all_of_results_volume_onboarding_failures.rb,
lib/ibm_cloud_power/models/cloud_connection_virtual_private_clouds_virtual_private_clouds_inner.rb

Overview

#Power Cloud API

Introduction You can use the IBM® Power® Virtual Server to easily deploy and configure virtual servers that are running AIX, IBM i, or Linux (RHEL and SLES) workloads. To learn about using Power Virtual Server, see: - Getting started with IBM Power Virtual Servers - IBM Power Virtual Server CLI Reference ## Endpoint URLs The Power Virtual Server service uses regional endpoints over both public and private network. Automatically generated regional API endpoints (service URL) will default to IBM Cloud Regions which may cause your request to fail. You should always use the Power Virtual Server regions in the service URL. The following table shows the IBM Cloud® regions and their corresponding Power Virtual Server region where the APIs are available: | Country | Power Virtual Server region | Location | Public end-point (service URL) | | ---------------- | ------------------------------------------ | -------------------------- | ----------------------------------------- | | Australia | Sydney | syd04 \n syd05 | https://syd.power-iaas.cloud.ibm.com | | Brazil | Sao Paulo | sao01 \n sao04 | https://sao.power-iaas.cloud.ibm.com | | Canada | Montreal | mon01 | https://mon.power-iaas.cloud.ibm.com | | | Toronto | tor01 | https://tor.power-iaas.cloud.ibm.com | | Germany | Frankfurt | eu-de-1 \n eu-de-2 | https://eu-de.power-iaas.cloud.ibm.com | | UK/Great Britain | London | lon04 \n lon06 | https://lon.power-iaas.cloud.ibm.com | | India | Chennai | che01 \n che02 \n che03 | https://che.power-iaas.cloud.ibm.com | | | Mumbai | in-mum-1 \n in-mum-2 | https://in-mum.power-iaas.cloud.ibm.com | | Japan | Tokyo | tok04 | https://tok.power-iaas.cloud.ibm.com | | | Osaka | osa21 | https://osa.power-iaas.cloud.ibm.com | | Spain | Madrid | mad02 \n mad04 | https://mad.power-iaas.cloud.ibm.com | | United States | Washington DC | us-east \n wdc06 \n wdc07 | https://us-east.power-iaas.cloud.ibm.com | | | Dallas | dal10 \n dal12 \n us-south | https://us-south.power-iaas.cloud.ibm.com | | Country | Power Virtual Server region | Location | Private end-point (service URL) | | ---------------- | ------------------------------------------ | -------------------------- | ------------------------------------------------- | | Australia | Sydney | syd04 \n syd05 | https://private.au-syd.power-iaas.cloud.ibm.com | | Brazil | Sao Paulo | sao01 \n sao04 | https://private.br-sao.power-iaas.cloud.ibm.com | | Canada | Montreal | mon01 | https://private.ca-mon.power-iaas.cloud.ibm.com | | | Toronto | tor01 | https://private.ca-tor.power-iaas.cloud.ibm.com | | Germany | Frankfurt | eu-de-1 \n eu-de-2 | https://private.eu-de.power-iaas.cloud.ibm.com | | UK/Great Britain | London | lon04 \n lon06 | https://private.eu-gb.power-iaas.cloud.ibm.com | | India | Chennai | che01 \n che02 \n che03 | https://private.in-che.power-iaas.cloud.ibm.com | | | Mumbai | in-mum-1 \n in-mum-2 | https://private.in-mum.power-iaas.cloud.ibm.com | | Japan | Tokyo | tok04 | https://private.jp-tok.power-iaas.cloud.ibm.com | | | Osaka | osa21 | https://private.jp-osa.power-iaas.cloud.ibm.com | | Spain | Madrid | mad02 \n mad04 | https://private.eu-es.power-iaas.cloud.ibm.com | | United States | Washington DC | us-east \n wdc06 \n wdc07 | https://private.us-east.power-iaas.cloud.ibm.com | | | Dallas | dal10 \n dal12 \n us-south | https://private.us-south.power-iaas.cloud.ibm.com | ## Curl service URL intro To call the API, select the service URL that corresponds to the region of your choice and add a method path to form the complete request URL. For example, to list all the workspaces available in the us-south region, make a GET request to https://us-south.iaas.cloud.ibm.com/v1/workspaces. Example request to call the us-south service URL: codeblock curl -H \"Authorization: Bearer {token}\" -X {http_method} \"https://us-south.iaas.cloud.ibm.com/v1{path}\" Replace {token}, {http_method}, and {path} in this example with the values for your particular request. ## Authentication The Power Virtual Server API uses Identity and Access Management (IAM) to authenticate requests. To call each API method, you must be assigned a role that includes the required IAM actions. Each method has an Authorization section that lists the required actions and, if applicable, the conditions under which each action is required. Check your access on the IBM Cloud console by navigating to Users > User > Access. For more information about IAM actions and how they map to roles, see Assigning access to account management services and Managing IAM access for Power Virtual Server. Learn about obtaining an IAM token for an authenticated user or service ID in the IAM Identity Services API. If you first create an API key, you can use it to generate an IAM token. To use the API, add a valid IAM token to the HTTP Authorization request header. For example, -H 'Authorization: Bearer {token}'. For specific APIs you must need to include your IBM Cloud IAM access token and the Power Virtual Server instance ID, also known as your Cloud Resource Name (CRN), in each request. The first part of your CRN contains your Tenant ID and the second part contains your Cloud Instance ID. The following example shows a typical CRN: text crn:v1:staging:public:power-iaas:us-east:a/abcdefghijklmnopqrstuvwxyzabcdef:121d5ee5-b87d-4a0e-86b8-aaff422135478:: Tenant ID {tenant_id} = abcdefghijklmnopqrstuvwxyzabcdef Cloud Instance ID {cloud_instance_id} = 121d5ee5-b87d-4a0e-86b8-aaff422135478 You can retrieve an access token by first creating an API key, and then exchanging your API key for a IBM Cloud IAM token. For more information, see Retrieving an access token programmatically and Retrieving your instance ID. To retrieve your access token: sh curl -X POST \\ \"https://iam.cloud.ibm.com/identity/token\" \\ --header 'Content-Type: application/x-www-form-urlencoded' \\ --header 'Accept: application/json' \\ --data-urlencode 'grant_type=urn:ibm:params:oauth:grant-type:apikey' \\ --data-urlencode 'apikey={api_key}' To use the API, replace {token} with the token obtained above from IAM, replace {http_method} with an HTTP method such as POST, and replace {url} with a request URL such as https://us-south.iaas.cloud.ibm.com/v1/workspaces/{workspace_id}: sh curl -H \"Authorization: Bearer {token}\" -X {http_method} \"{url}\" -H \"CRN\" ## Auditing Monitor API activity within your account by using the IBM Cloud Activity Tracker service. Each time you make an API call, one or more events are generated that you can track and audit from within Activity Tracker. Specific auditing event types are listed for each individual method. For more information about Power Virtual Server activity tracking, see Activity Tracker events. ## Error handling This API uses standard HTTP response codes to indicate whether a method completed successfully. A 200 response indicates success. A 400 type response indicates a failure, and a 500 type response indicates an internal system error. | HTTP Error Code | Description | Recovery | | --------------- | -------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | | 400 | Bad Request | The input parameters in the request body are either incomplete, malformed, or too large. Be sure to include all required parameters in your request. | | 401 | Unauthorized | You are not authorized to make this request. Log in to IBM Cloud and try submitting the request again. If this error persists, contact the account owner to check your permissions. | | 403 | Forbidden | The supplied authentication is not authorized to perform the requested operation. Either you do not have valid access through IAM access policies or your request is denied. If this error persists, contact the account owner to check your permissions. | | 404 | Not Found | The requested resource could not be found but may be available in the future. | | 405 | Method Not Allowed | The requested resource does not support the request method. | | 406 | Not Acceptable | The resource the client requested is not available in a format allowed by the Accept header supplied by the client. | | 408 | Request Timeout | The connection to the server timed out. Wait a few minutes, and try submitting the request again. | | 409 | Conflict | The request cannot be completed because of a conflict between the request and the current state of the resource. | | 412 | Precondition Failed | The client specified one or more preconditions in its headers, and the server cannot meet those preconditions. | | 426 | Upgrade Required | The server refuses to perform the request using the current protocol but might perform the request after the client upgrades to a different protocol. | | 500 | Internal Server Error | The request cannot be processed because the client encountered an unexpected condition on the server. Wait a few minutes and try submitting the request again. If this error persists, contact IBM Support. | | 501 | Not Implemented | The server either does not recognize the request method, or it lacks the ability to fulfill the request. | | 502 | Bad Gateway | The server was acting as a gateway or proxy and received an invalid response from the upstream server. | | 503 | Service Unavailable | The server cannot process the request. Generally, this condition is temporary, such as when a server is overloaded or down for scheduled maintenance. This condition could also be due to an unplanned outage of a service that is needed to process the request. Wait a few minutes and try submitting the request again. If this error persists, contact IBM Support. | | 504 | Gateway Timeout | The server was acting as a gateway or proxy and did not receive a timely response from the upstream server. | | 505 | HTTP Version Not Supported | The server does not support the HTTP protocol version that is used in the request. | ## Release notes Use the release notes to learn about the latest changes to the Power Virtual Server API. ### June 2026 Added the following APIs associated with vPMEM volumes: - Update a vPMEM volume attached to this PVM Instance ### December 2025 Added the following APIs associated with vPMEM volumes: - List all vPMEM volumes attached to this PVM Instance - Create a vPMEM volume to be attached to this PVM Instance - Delete a vPMEM volume attached to this PVM Instance - Get information about a vPMEM volume ### September 2025 Added the following APIs associated with network peers: - Get the list of Network Peers for a workspace - Create a new Network Peer - Get the list of Network Interfaces for a workspace - Delete a Network Peer from a workspace - Get the details of a Network Peer - Update a Network Peer - Create a new Route Filter - Delete a Route Filter from a Network Peer - Get the details of a Route Filter ### July 2025 Added the following APIs associated with routes: - Get all routes in the workspace - Perform a route creation - Get the route report for a workspace - Delete a route - Get a route's information - Update a route's information Added the following APIs associated with ssh keys: - List SSH Keys - Add a new SSH key - Delete ssh-key - Get ssh-key information - Update the ssh key Added an API to list the supported IBM i software tiers: List supported software tiers (IBMi licensing) ### February 2025 Added the following APIs associated with network address groups: - Get the list of Network Address Groups for a workspace - Create a new Network Address Group - Delete a Network Address Group from a workspace - Get the detail of a Network Address Group - Update a Network Address Group - Add a member to a Network Address Group - Delete the member from a Network Address Group Added the following APIs associated with network security groups: - Get the list of Network Security Groups for a workspace - Create a new Network Security Group - Perform a Network Security Groups action (enable, disable) on a workspace. - Delete a Network Security Group from a workspace - Get the detail of a Network Security Group - Clone a Network Security Group - Update a Network Security Group - Add a member to a Network Security Group - Delete the member from a Network Security Group - Move a Network Security Group member to another Network Security Group - Add a rule to a Network Security Group - Delete the rule from a Network Security Group ### December 2023 The following APIs are availavle: - Get all Datacenters information and capabilities - Get a Datacenter's information and capabilities - Get all Workspaces information and capabilities for a tenant - Get a Workspace's information and capabilities ### November 2023 - New API List all supported storage tiers for this cloud instance is available. ### September 2023 - Added parameters availableCapacity, maxAllocationSize, replicationEnabled, storageHost in the Storage capacity for a storage pool in a region (GET). ### December 2022 - You can now get new error messages for undefined response codes for new service endpoint response codes. ### September 2022 - Added the following APIs associated with shared processor pool: - Get the list of Shared Processor Pools for a cloud instance - Create a new Shared Processor Pool - Get the detail of a Shared Processor Pool for a cloud instance - Update a Shared Processor Pool for a cloud instance - Delete a Shared Processor Pool from a cloud instance - Added the following APIs associated with global recovery service: - Disaster recovery - Get the disaster recovery site details for the current location - Get all disaster recovery locations supported by Power Virtual Server - Volume - Perform an action on a Volume - Get a list of flashcopy mappings of a given volume - Get remote copy relationship of a volume - Volume onboarding - List all volume onboardings for this cloud instance - Onboard auxiliary volumes to target site - Get the information of volume onboarding operation - Volume groups - Get all volume groups - Create a new volume group - Get all volume groups with details - Get volume Group - updates the volume group - Delete a cloud instance volume group - Perform an action (start stop reset ) on a volume group - Get volume Group details - Get remote copy relationships of the volume belonging to volume group - Get storage details of volume group ### October 2021 - Added the following APIs associated with VPN connections: - Get VPN connections - Add IKE policy - Add IPsec policy ### September 2021 - Added the following APIs associated with Image Capture, Image Import, and Image Export: - Capture a PVM instance and create a deployable image - Add image export job to the jobs queue - Create a new image from available images in COS - List up to the last 5 jobs initiated by the cloud instance - Added the following APIs associated with storage volumes: - Create multiple data volumes from a single definition - Added the following APIs associated with private endpoint: - Endpoint URL ### June 2021 - Added the following APIs associated with placement groups: - Create a server placement group - Get all server placement groups - Get server placement group details - Delete server placement group - Add server to placement group - Remove server from placement group ### May 2021 - Added the following APIs associated with Cloud connections: - Create a new Cloud connection - Get all Cloud connections in a specific cloud instance - Get a Cloud connection's state or information - Update a Cloud connection - Delete a Cloud connection - Get information about a Cloud connections attached network - Add a network to the Cloud connection - Delete a network from a Cloud connection ### February 2021 - Added the following APIs associated with volume clone requests: - Create a new volumes clone request and initiate the Prepare action - Get the list of volumes-clone request for a cloud instance - Get the details for a volumes-clone request - Delete a volumes-clone request - Initiate the Start action for a volume-clone request - Initiate the Execute action for a volumes-clone request - Cancel a volume-clone request and initiate the Cleanup action - Added the following APIs for requests related to storage capacity: - Get storage capacity for all available storage types in a region - Get storage capacity for a storage type in a region - Get storage capacity for all available storage pools in a region - Get storage capacity for a storage pool in a region

The version of the OpenAPI document: 2.5.0 Contact: ismirlia@us.ibm.com Generated by: https://openapi-generator.tech Generator version: 7.23.0

Defined Under Namespace

Classes: AccessConfig, AddHost, AddServerVirtualSerialNumber, ApiClient, ApiError, ApiModelBase, AuxiliaryVolumeForOnboarding, AuxiliaryVolumesForOnboarding, AuxiliaryVolumesForOnboardingAuxiliaryVolumesInner, AvailableHost, AvailableHostCapacity, AvailableHostCapacityCores, AvailableHostResourceCapacity, CapabilitiesDetails, CapabilitiesDetailsDisasterRecovery, CapabilitiesDetailsSupportedSystems, CloneTaskReference, CloneTaskStatus, ClonedVolume, ClonedVolumeDetail, ClonedVolumeDetailClone, CloudConnection, CloudConnectionClassic, CloudConnectionCreate, CloudConnectionCreateClassic, CloudConnectionCreateResponse, CloudConnectionEndpointClassic, CloudConnectionEndpointClassicUpdate, CloudConnectionEndpointVPC, CloudConnectionGRETunnel, CloudConnectionGRETunnelCreate, CloudConnectionUpdate, CloudConnectionVirtualPrivateClouds, CloudConnectionVirtualPrivateCloudsVirtualPrivateCloudsInner, CloudConnectionVpc, CloudConnections, CloudInstance, CloudInstanceReference, CloudInstanceUsageLimits, Configuration, ConsoleLanguage, ConsoleLanguages, CreateCosImageImportJob, CreateDataVolume, CreateImage, CreateServerVirtualSerialNumber, CreateWorkspaceSSHKey, Datacenter, DatacenterLocation, Datacenters, DatacentersApi, DeadPeerDetection, DeleteServerVirtualSerialNumber, DeploymentTarget, DisasterRecovery, DisasterRecoveryAsynchronousReplication, DisasterRecoveryLocation, DisasterRecoveryLocations, Error, Event, EventUser, Events, ExportImage, FlashCopyMapping, GetBulkVolume, GetServerVirtualSerialNumber, Host, HostCapacity, HostCapacityCores, HostCreate, HostGroup, HostGroupCreate, HostGroupShareOp, HostGroupSummary, HostGroupsApi, HostHostGroup, HostPut, HostResourceCapacity, IKEPolicies, IKEPolicy, IKEPolicyAuthentication, IKEPolicyCreate, IKEPolicyRef, IKEPolicyUpdate, IPAddressRange, IPSECPolicyAuthentication, IPSecPolicies, IPSecPolicy, IPSecPolicyCreate, IPSecPolicyRef, IPSecPolicyUpdate, Image, ImageImportDetails, ImageReference, ImageSpecifications, ImageTaskref, ImageVolume, Images, Job, JobAction, JobOperation, JobReference, JobResourceDetails, JobResources, JobStatus, JobWorkflow, Jobs, MaximumStorageAllocation, MetadataService, MinMaxDefault, MultiVolumesCreate, Network, NetworkAddressGroup, NetworkAddressGroupAddMember, NetworkAddressGroupCreate, NetworkAddressGroupMember, NetworkAddressGroupUpdate, NetworkAddressGroups, NetworkAddressGroupsApi, NetworkAddressTranslation, NetworkCloudConnectionsInner, NetworkCreate, NetworkID, NetworkIDs, NetworkInterface, NetworkInterfaceCreate, NetworkInterfaceInstance, NetworkInterfaceUpdate, NetworkInterfaces, NetworkIpAddressMetrics, NetworkPeer, NetworkPeerCreate, NetworkPeerUpdate, NetworkPeers, NetworkPeersApi, NetworkPort, NetworkPortCreate, NetworkPortPvmInstance, NetworkPortUpdate, NetworkPorts, NetworkReference, NetworkSecurityGroup, NetworkSecurityGroupAddMember, NetworkSecurityGroupAddRule, NetworkSecurityGroupClone, NetworkSecurityGroupCreate, NetworkSecurityGroupMember, NetworkSecurityGroupMoveMember, NetworkSecurityGroupRule, NetworkSecurityGroupRulePort, NetworkSecurityGroupRuleProtocol, NetworkSecurityGroupRuleProtocolTcpFlag, NetworkSecurityGroupRuleRemote, NetworkSecurityGroupUpdate, NetworkSecurityGroups, NetworkSecurityGroupsAction, NetworkSecurityGroupsApi, NetworkUpdate, Networks, NetworksApi, Operation, Operations, PCloudCloudConnectionsApi, PCloudDisasterRecoveryApi, PCloudEventsApi, PCloudImagesApi, PCloudInstancesApi, PCloudJobsApi, PCloudNetworksApi, PCloudPVMInstancesApi, PCloudPlacementGroupsApi, PCloudPodCapacityApi, PCloudSAPApi, PCloudSPPPlacementGroupsApi, PCloudSharedProcessorPoolsApi, PCloudSnapshotsApi, PCloudStorageCapacityApi, PCloudStorageTiersApi, PCloudTasksApi, PCloudTenantsApi, PCloudTenantsSSHKeysApi, PCloudVPMemVolumesApi, PCloudVPNConnectionsApi, PCloudVPNPoliciesApi, PCloudVirtualSerialNumberApi, PCloudVolumeGroupsApi, PCloudVolumeOnboardingApi, PCloudVolumesApi, PVMInstance, PVMInstanceAction, PVMInstanceAddNetwork, PVMInstanceCapture, PVMInstanceConfiguration, PVMInstanceConsole, PVMInstanceCores, PVMInstanceCreate, PVMInstanceDelete, PVMInstanceFault, PVMInstanceHealth, PVMInstanceMemory, PVMInstanceMultiCreate, PVMInstanceNetwork, PVMInstanceNetworks, PVMInstanceOperatingSystem, PVMInstanceOperation, PVMInstanceReference, PVMInstanceReferenceV2, PVMInstanceRemoveNetwork, PVMInstanceUpdate, PVMInstanceUpdateResponse, PVMInstanceV2Health, PVMInstanceV2NetworkPort, PVMInstanceVirtualCores, PVMInstanceVolumeUpdate, PVMInstances, PVMInstancesV2, PeerInterface, PeerSubnetUpdate, PeerSubnets, PeeringNetwork, PinPolicy, PlacementGroup, PlacementGroupCreate, PlacementGroupServer, PlacementGroups, PodCapacity, PodData, PvmInstanceDeployment, PvmInstanceHost, PvmInstancePlacementGroup, RemoteCopyRelationship, RemoveVirtualSerialNumber, ReplicationService, ReplicationTargetLocation, Route, RouteCreate, RouteFilter, RouteFilterCreate, RouteReport, RouteReportRoute, RouteUpdate, Routes, RoutesApi, SAPCreate, SAPProfile, SAPProfileReference, SAPProfileVpmemVolume, SAPProfiles, SPPPlacementGroup, SPPPlacementGroupCreate, SPPPlacementGroups, SRC, SSHKey, SSHKeys, SSHKeysApi, Secondary, SharedProcessorPool, SharedProcessorPoolCreate, SharedProcessorPoolDetail, SharedProcessorPoolDetailSharedProcessorPool, SharedProcessorPoolPlacementGroup, SharedProcessorPoolServer, SharedProcessorPoolUpdate, SharedProcessorPools, Site, Snapshot, SnapshotCreate, SnapshotCreateResponse, SnapshotList, SnapshotRestore, SnapshotUpdate, SnapshotV1, Snapshots, SnapshotsApi, SoftwareLicenses, SoftwareTier, Status, StatusDescription, StatusDescriptionError, StockImage, StorageAffinity, StorageController, StoragePoolCapacity, StoragePoolCombined, StoragePoolMap, StoragePoolsCapacity, StoragePoolsCapacityMaximumStorageAllocation, StorageTier, StorageTypeCapacity, StorageTypesCapacity, SupportedSoftwareTier, SupportedSystems, System, SystemPool, SystemPoolCapacity, SystemPoolSharedCoreRatio, SystemResources, TargetTrustedProfile, Task, TaskReference, Tenant, TenantUpdate, TrustedProfile, UpdateMetadataService, UpdateServerVirtualSerialNumber, UpdateTrustedProfile, UpdateVirtualSerialNumber, UpdateVolume, UpdateWorkspaceSSHKey, VPMemVolumeAttach, VPMemVolumeCreate, VPMemVolumeReference, VPMemVolumeUpdate, VPMemVolumes, VPNConnection, VPNConnectionCreate, VPNConnectionCreateResponse, VPNConnectionUpdate, VPNConnections, VirtualCores, VirtualSerialNumber, Volume, VolumeAction, VolumeGroup, VolumeGroupAction, VolumeGroupActionReset, VolumeGroupActionStart, VolumeGroupActionStop, VolumeGroupCreate, VolumeGroupCreateResponse, VolumeGroupDetails, VolumeGroupRemoteCopyRelationships, VolumeGroupStorageDetails, VolumeGroupUpdate, VolumeGroups, VolumeGroupsDetails, VolumeInfo, VolumeOnboarding, VolumeOnboardingAllOfResults, VolumeOnboardingAllOfResultsVolumeOnboardingFailures, VolumeOnboardingCommon, VolumeOnboardingCreate, VolumeOnboardingCreateResponse, VolumeOnboardingCreateVolumesInner, VolumeOnboardingFailure, VolumeOnboardings, VolumeReference, VolumeRemoteCopyRelationship, VolumeSnapshotList, Volumes, VolumesAttach, VolumesAttachmentResponse, VolumesClone, VolumesCloneAsyncRequest, VolumesCloneCancel, VolumesCloneCreate, VolumesCloneDetail, VolumesCloneExecute, VolumesCloneRequest, VolumesCloneResponse, VolumesClones, VolumesDelete, VolumesDeleteResponse, VolumesDetach, VolumesDetachmentResponse, Workspace, WorkspaceDetails, WorkspaceLocation, WorkspaceNetworkSecurityGroupsDetails, WorkspacePowerEdgeRouterDetails, WorkspaceSSHKey, WorkspaceSSHKeys, Workspaces, WorkspacesApi

Constant Summary collapse

VERSION =
'3.1.0'

Class Method Summary collapse

Class Method Details

.configureObject

Customize default settings for the SDK using block. IbmCloudPower.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.



402
403
404
405
406
407
408
# File 'lib/ibm_cloud_power.rb', line 402

def configure
  if block_given?
    yield(Configuration.default)
  else
    Configuration.default
  end
end