Class: IbmCloudPower::AuxiliaryVolumeForOnboarding
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::AuxiliaryVolumeForOnboarding
- Defined in:
- lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb
Instance Attribute Summary collapse
-
#aux_volume_name ⇒ Object
auxiliary volume name at storage host level.
-
#name ⇒ Object
display name of auxVolumeName once onboarded,auxVolumeName will be set to display name if not provided.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuxiliaryVolumeForOnboarding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuxiliaryVolumeForOnboarding
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::AuxiliaryVolumeForOnboarding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::AuxiliaryVolumeForOnboarding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'aux_volume_name') self.aux_volume_name = attributes[:'aux_volume_name'] else self.aux_volume_name = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end end |
Instance Attribute Details
#aux_volume_name ⇒ Object
auxiliary volume name at storage host level
19 20 21 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 19 def aux_volume_name @aux_volume_name end |
#name ⇒ Object
display name of auxVolumeName once onboarded,auxVolumeName will be set to display name if not provided.
22 23 24 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 22 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 25 def self.attribute_map { :'aux_volume_name' => :'auxVolumeName', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 43 def self.openapi_types { :'aux_volume_name' => :'String', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && aux_volume_name == o.aux_volume_name && name == o.name end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 160 def hash [aux_volume_name, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @aux_volume_name.nil? invalid_properties.push('invalid value for "aux_volume_name", aux_volume_name cannot be nil.') end if !@name.nil? && @name.to_s.length > 120 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 120.') end pattern = Regexp.new(/^[\s]*[A-Za-z0-9:_.\-][A-Za-z0-9\s:_.\-]*$/) if !@name.nil? && @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 110 111 112 |
# File 'lib/ibm_cloud_power/models/auxiliary_volume_for_onboarding.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @aux_volume_name.nil? return false if !@name.nil? && @name.to_s.length > 120 return false if !@name.nil? && @name !~ Regexp.new(/^[\s]*[A-Za-z0-9:_.\-][A-Za-z0-9\s:_.\-]*$/) true end |