Class: IbmCloudPower::CapabilitiesDetailsDisasterRecovery

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CapabilitiesDetailsDisasterRecovery

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CapabilitiesDetailsDisasterRecovery` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CapabilitiesDetailsDisasterRecovery`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'asynchronous_replication')
    self.asynchronous_replication = attributes[:'asynchronous_replication']
  else
    self.asynchronous_replication = nil
  end

  if attributes.key?(:'synchronous_replication')
    self.synchronous_replication = attributes[:'synchronous_replication']
  end
end

Instance Attribute Details

#asynchronous_replicationObject

Returns the value of attribute asynchronous_replication.



18
19
20
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 18

def asynchronous_replication
  @asynchronous_replication
end

#synchronous_replicationObject

Returns the value of attribute synchronous_replication.



20
21
22
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 20

def synchronous_replication
  @synchronous_replication
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



31
32
33
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 31

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



36
37
38
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 36

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 23

def self.attribute_map
  {
    :'asynchronous_replication' => :'asynchronousReplication',
    :'synchronous_replication' => :'synchronousReplication'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 142

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



55
56
57
58
59
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 55

def self.openapi_all_of
  [
  :'DisasterRecovery'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



49
50
51
52
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 49

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



41
42
43
44
45
46
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 41

def self.openapi_types
  {
    :'asynchronous_replication' => :'DisasterRecoveryAsynchronousReplication',
    :'synchronous_replication' => :'DisasterRecoveryAsynchronousReplication'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



120
121
122
123
124
125
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 120

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      asynchronous_replication == o.asynchronous_replication &&
      synchronous_replication == o.synchronous_replication
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


129
130
131
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 129

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



135
136
137
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 135

def hash
  [asynchronous_replication, synchronous_replication].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



90
91
92
93
94
95
96
97
98
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 90

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @asynchronous_replication.nil?
    invalid_properties.push('invalid value for "asynchronous_replication", asynchronous_replication cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 164

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



102
103
104
105
106
# File 'lib/ibm_cloud_power/models/capabilities_details_disaster_recovery.rb', line 102

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @asynchronous_replication.nil?
  true
end