Class: IbmCloudPower::ClonedVolumeDetailClone

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClonedVolumeDetailClone

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::ClonedVolumeDetailClone` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::ClonedVolumeDetailClone`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'volume_id')
    self.volume_id = attributes[:'volume_id']
  end
end

Instance Attribute Details

#crnObject

The CRN for this resource



19
20
21
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 19

def crn
  @crn
end

#nameObject

Name of the volume



22
23
24
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 22

def name
  @name
end

#volume_idObject

ID of the volume



25
26
27
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 25

def volume_id
  @volume_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 28

def self.attribute_map
  {
    :'crn' => :'crn',
    :'name' => :'name',
    :'volume_id' => :'volumeID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 137

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



62
63
64
65
66
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 62

def self.openapi_all_of
  [
  :'VolumeInfo'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 47

def self.openapi_types
  {
    :'crn' => :'String',
    :'name' => :'String',
    :'volume_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



114
115
116
117
118
119
120
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 114

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      crn == o.crn &&
      name == o.name &&
      volume_id == o.volume_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


124
125
126
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 124

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



130
131
132
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 130

def hash
  [crn, name, volume_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



99
100
101
102
103
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 99

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 159

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



107
108
109
110
# File 'lib/ibm_cloud_power/models/cloned_volume_detail_clone.rb', line 107

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end