Class: IbmCloudPower::CloudInstanceReference

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/cloud_instance_reference.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CloudInstanceReference

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CloudInstanceReference` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CloudInstanceReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'capabilities')
    if (value = attributes[:'capabilities']).is_a?(Array)
      self.capabilities = value
    end
  end

  if attributes.key?(:'cloud_instance_id')
    self.cloud_instance_id = attributes[:'cloud_instance_id']
  else
    self.cloud_instance_id = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'href')
    self.href = attributes[:'href']
  else
    self.href = nil
  end

  if attributes.key?(:'initialized')
    self.initialized = attributes[:'initialized']
  else
    self.initialized = nil
  end

  if attributes.key?(:'limits')
    self.limits = attributes[:'limits']
  else
    self.limits = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  else
    self.region = nil
  end
end

Instance Attribute Details

#capabilitiesObject

Cloud Instance Capabilities



19
20
21
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 19

def capabilities
  @capabilities
end

#cloud_instance_idObject

Cloud Instance ID



22
23
24
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 22

def cloud_instance_id
  @cloud_instance_id
end

#enabledObject

Indicates if the cloud instance is enabled



25
26
27
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 25

def enabled
  @enabled
end

#hrefObject

Link to Cloud Instance resource



28
29
30
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 28

def href
  @href
end

#initializedObject

Indicates if the cloud instance is initialized and ready for use



31
32
33
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 31

def initialized
  @initialized
end

#limitsObject

Limits on the cloud instance



34
35
36
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 34

def limits
  @limits
end

#nameObject

Cloud Instance Name



37
38
39
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 37

def name
  @name
end

#regionObject

The region the cloud instance lives



40
41
42
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 40

def region
  @region
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 43

def self.attribute_map
  {
    :'capabilities' => :'capabilities',
    :'cloud_instance_id' => :'cloudInstanceID',
    :'enabled' => :'enabled',
    :'href' => :'href',
    :'initialized' => :'initialized',
    :'limits' => :'limits',
    :'name' => :'name',
    :'region' => :'region'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 301

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 67

def self.openapi_types
  {
    :'capabilities' => :'Array<String>',
    :'cloud_instance_id' => :'String',
    :'enabled' => :'Boolean',
    :'href' => :'String',
    :'initialized' => :'Boolean',
    :'limits' => :'CloudInstanceUsageLimits',
    :'name' => :'String',
    :'region' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 273

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      capabilities == o.capabilities &&
      cloud_instance_id == o.cloud_instance_id &&
      enabled == o.enabled &&
      href == o.href &&
      initialized == o.initialized &&
      limits == o.limits &&
      name == o.name &&
      region == o.region
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


288
289
290
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 288

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



294
295
296
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 294

def hash
  [capabilities, cloud_instance_id, enabled, href, initialized, limits, name, region].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @cloud_instance_id.nil?
    invalid_properties.push('invalid value for "cloud_instance_id", cloud_instance_id cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @href.nil?
    invalid_properties.push('invalid value for "href", href cannot be nil.')
  end

  if @initialized.nil?
    invalid_properties.push('invalid value for "initialized", initialized cannot be nil.')
  end

  if @limits.nil?
    invalid_properties.push('invalid value for "limits", limits cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @region.nil?
    invalid_properties.push('invalid value for "region", region cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
194
195
196
197
198
199
# File 'lib/ibm_cloud_power/models/cloud_instance_reference.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @cloud_instance_id.nil?
  return false if @enabled.nil?
  return false if @href.nil?
  return false if @initialized.nil?
  return false if @limits.nil?
  return false if @name.nil?
  return false if @region.nil?
  true
end