Class: IbmCloudPower::CloudInstanceUsageLimits

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CloudInstanceUsageLimits

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CloudInstanceUsageLimits` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CloudInstanceUsageLimits`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'instance_memory')
    self.instance_memory = attributes[:'instance_memory']
  end

  if attributes.key?(:'instance_proc_units')
    self.instance_proc_units = attributes[:'instance_proc_units']
  end

  if attributes.key?(:'instances')
    self.instances = attributes[:'instances']
  else
    self.instances = nil
  end

  if attributes.key?(:'memory')
    self.memory = attributes[:'memory']
  else
    self.memory = nil
  end

  if attributes.key?(:'peering_bandwidth')
    self.peering_bandwidth = attributes[:'peering_bandwidth']
  end

  if attributes.key?(:'peering_networks')
    self.peering_networks = attributes[:'peering_networks']
  end

  if attributes.key?(:'proc_units')
    self.proc_units = attributes[:'proc_units']
  else
    self.proc_units = nil
  end

  if attributes.key?(:'processors')
    self.processors = attributes[:'processors']
  else
    self.processors = nil
  end

  if attributes.key?(:'storage')
    self.storage = attributes[:'storage']
  else
    self.storage = nil
  end

  if attributes.key?(:'storage_ssd')
    self.storage_ssd = attributes[:'storage_ssd']
  end

  if attributes.key?(:'storage_standard')
    self.storage_standard = attributes[:'storage_standard']
  end
end

Instance Attribute Details

#instance_memoryObject

Maximum memory (in GiB) per PVMInstance



19
20
21
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 19

def instance_memory
  @instance_memory
end

#instance_proc_unitsObject

Maximum proc units per PVMInstance



22
23
24
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 22

def instance_proc_units
  @instance_proc_units
end

#instancesObject

Number of power instances allowed



25
26
27
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 25

def instances
  @instances
end

#memoryObject

Amount of memory allowed



28
29
30
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 28

def memory
  @memory
end

#peering_bandwidthObject

Maximum network bandwidth to GCP Mbps



31
32
33
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 31

def peering_bandwidth
  @peering_bandwidth
end

#peering_networksObject

Amount of peering networks allowed



34
35
36
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 34

def peering_networks
  @peering_networks
end

#proc_unitsObject

Number of processor units allowed



37
38
39
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 37

def proc_units
  @proc_units
end

#processorsObject

Number of processors allowed



40
41
42
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 40

def processors
  @processors
end

#storageObject

Amount of storage allowed (TiB)



43
44
45
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 43

def storage
  @storage
end

#storage_ssdObject

Amount of SSD storage allowed (TiB)



46
47
48
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 46

def storage_ssd
  @storage_ssd
end

#storage_standardObject

Amount of standard (HDD) storage allowed (TiB)



49
50
51
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 49

def storage_standard
  @storage_standard
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 52

def self.attribute_map
  {
    :'instance_memory' => :'instanceMemory',
    :'instance_proc_units' => :'instanceProcUnits',
    :'instances' => :'instances',
    :'memory' => :'memory',
    :'peering_bandwidth' => :'peeringBandwidth',
    :'peering_networks' => :'peeringNetworks',
    :'proc_units' => :'procUnits',
    :'processors' => :'processors',
    :'storage' => :'storage',
    :'storage_ssd' => :'storageSSD',
    :'storage_standard' => :'storageStandard'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 295

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 79

def self.openapi_types
  {
    :'instance_memory' => :'Float',
    :'instance_proc_units' => :'Float',
    :'instances' => :'Float',
    :'memory' => :'Float',
    :'peering_bandwidth' => :'Integer',
    :'peering_networks' => :'Integer',
    :'proc_units' => :'Float',
    :'processors' => :'Float',
    :'storage' => :'Float',
    :'storage_ssd' => :'Float',
    :'storage_standard' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 264

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      instance_memory == o.instance_memory &&
      instance_proc_units == o.instance_proc_units &&
      instances == o.instances &&
      memory == o.memory &&
      peering_bandwidth == o.peering_bandwidth &&
      peering_networks == o.peering_networks &&
      proc_units == o.proc_units &&
      processors == o.processors &&
      storage == o.storage &&
      storage_ssd == o.storage_ssd &&
      storage_standard == o.storage_standard
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


282
283
284
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 282

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



288
289
290
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 288

def hash
  [instance_memory, instance_proc_units, instances, memory, peering_bandwidth, peering_networks, proc_units, processors, storage, storage_ssd, storage_standard].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @instances.nil?
    invalid_properties.push('invalid value for "instances", instances cannot be nil.')
  end

  if @memory.nil?
    invalid_properties.push('invalid value for "memory", memory cannot be nil.')
  end

  if @proc_units.nil?
    invalid_properties.push('invalid value for "proc_units", proc_units cannot be nil.')
  end

  if @processors.nil?
    invalid_properties.push('invalid value for "processors", processors cannot be nil.')
  end

  if @storage.nil?
    invalid_properties.push('invalid value for "storage", storage cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 317

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
# File 'lib/ibm_cloud_power/models/cloud_instance_usage_limits.rb', line 202

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @instances.nil?
  return false if @memory.nil?
  return false if @proc_units.nil?
  return false if @processors.nil?
  return false if @storage.nil?
  true
end