Class: IbmCloudPower::CreateImage

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/create_image.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateImage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/ibm_cloud_power/models/create_image.rb', line 140

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CreateImage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CreateImage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_key')
    self.access_key = attributes[:'access_key']
  end

  if attributes.key?(:'bucket_name')
    self.bucket_name = attributes[:'bucket_name']
  end

  if attributes.key?(:'disk_type')
    self.disk_type = attributes[:'disk_type']
  end

  if attributes.key?(:'image_filename')
    self.image_filename = attributes[:'image_filename']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  end

  if attributes.key?(:'image_name')
    self.image_name = attributes[:'image_name']
  end

  if attributes.key?(:'image_path')
    self.image_path = attributes[:'image_path']
  end

  if attributes.key?(:'os_type')
    self.os_type = attributes[:'os_type']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.key?(:'secret_key')
    self.secret_key = attributes[:'secret_key']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  else
    self.source = nil
  end

  if attributes.key?(:'storage_affinity')
    self.storage_affinity = attributes[:'storage_affinity']
  end

  if attributes.key?(:'storage_pool')
    self.storage_pool = attributes[:'storage_pool']
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end
end

Instance Attribute Details

#access_keyObject

Cloud Storage access key; required for import image



19
20
21
# File 'lib/ibm_cloud_power/models/create_image.rb', line 19

def access_key
  @access_key
end

#bucket_nameObject

Cloud Storage bucket name; bucket-name; required for import image



22
23
24
# File 'lib/ibm_cloud_power/models/create_image.rb', line 22

def bucket_name
  @bucket_name
end

#disk_typeObject

Type of Disk; if diskType is not provided the disk type will default to 'tier3'. Used only when importing an image from cloud storage.



25
26
27
# File 'lib/ibm_cloud_power/models/create_image.rb', line 25

def disk_type
  @disk_type
end

#image_filenameObject

Cloud Storage image filename; required for import image



28
29
30
# File 'lib/ibm_cloud_power/models/create_image.rb', line 28

def image_filename
  @image_filename
end

#image_idObject

Image ID of existing source image; required for copy image



31
32
33
# File 'lib/ibm_cloud_power/models/create_image.rb', line 31

def image_id
  @image_id
end

#image_nameObject

Name to give created image; required for import image



34
35
36
# File 'lib/ibm_cloud_power/models/create_image.rb', line 34

def image_name
  @image_name
end

#image_pathObject

(deprecated - replaced by region, imageFilename and bucketName) Path to image starting with service endpoint and ending with image filename



37
38
39
# File 'lib/ibm_cloud_power/models/create_image.rb', line 37

def image_path
  @image_path
end

#os_typeObject

Image OS Type, required if importing a raw image; raw images can only be imported using the command line interface



40
41
42
# File 'lib/ibm_cloud_power/models/create_image.rb', line 40

def os_type
  @os_type
end

#regionObject

Cloud Storage Region; only required to access IBM Cloud Storage



43
44
45
# File 'lib/ibm_cloud_power/models/create_image.rb', line 43

def region
  @region
end

#secret_keyObject

Cloud Storage secret key; required for import image



46
47
48
# File 'lib/ibm_cloud_power/models/create_image.rb', line 46

def secret_key
  @secret_key
end

#sourceObject

Source of the image >Note: url option is deprecated, this option is supported till Oct 2022



49
50
51
# File 'lib/ibm_cloud_power/models/create_image.rb', line 49

def source
  @source
end

#storage_affinityObject

The storage affinity data; ignored if storagePool is provided; Used only when importing an image from cloud storage.



52
53
54
# File 'lib/ibm_cloud_power/models/create_image.rb', line 52

def storage_affinity
  @storage_affinity
end

#storage_poolObject

Storage pool where the image will be loaded; if provided then storageAffinity will be ignored; Used only when importing an image from cloud storage.



55
56
57
# File 'lib/ibm_cloud_power/models/create_image.rb', line 55

def storage_pool
  @storage_pool
end

#user_tagsObject

List of user tags



58
59
60
# File 'lib/ibm_cloud_power/models/create_image.rb', line 58

def user_tags
  @user_tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



103
104
105
# File 'lib/ibm_cloud_power/models/create_image.rb', line 103

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/ibm_cloud_power/models/create_image.rb', line 108

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/ibm_cloud_power/models/create_image.rb', line 83

def self.attribute_map
  {
    :'access_key' => :'accessKey',
    :'bucket_name' => :'bucketName',
    :'disk_type' => :'diskType',
    :'image_filename' => :'imageFilename',
    :'image_id' => :'imageID',
    :'image_name' => :'imageName',
    :'image_path' => :'imagePath',
    :'os_type' => :'osType',
    :'region' => :'region',
    :'secret_key' => :'secretKey',
    :'source' => :'source',
    :'storage_affinity' => :'storageAffinity',
    :'storage_pool' => :'storagePool',
    :'user_tags' => :'userTags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/ibm_cloud_power/models/create_image.rb', line 314

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



133
134
135
136
# File 'lib/ibm_cloud_power/models/create_image.rb', line 133

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/ibm_cloud_power/models/create_image.rb', line 113

def self.openapi_types
  {
    :'access_key' => :'String',
    :'bucket_name' => :'String',
    :'disk_type' => :'String',
    :'image_filename' => :'String',
    :'image_id' => :'String',
    :'image_name' => :'String',
    :'image_path' => :'String',
    :'os_type' => :'String',
    :'region' => :'String',
    :'secret_key' => :'String',
    :'source' => :'String',
    :'storage_affinity' => :'StorageAffinity',
    :'storage_pool' => :'String',
    :'user_tags' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/ibm_cloud_power/models/create_image.rb', line 280

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_key == o.access_key &&
      bucket_name == o.bucket_name &&
      disk_type == o.disk_type &&
      image_filename == o.image_filename &&
      image_id == o.image_id &&
      image_name == o.image_name &&
      image_path == o.image_path &&
      os_type == o.os_type &&
      region == o.region &&
      secret_key == o.secret_key &&
      source == o.source &&
      storage_affinity == o.storage_affinity &&
      storage_pool == o.storage_pool &&
      user_tags == o.user_tags
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/ibm_cloud_power/models/create_image.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



307
308
309
# File 'lib/ibm_cloud_power/models/create_image.rb', line 307

def hash
  [access_key, bucket_name, disk_type, image_filename, image_id, image_name, image_path, os_type, region, secret_key, source, storage_affinity, storage_pool, user_tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/ibm_cloud_power/models/create_image.rb', line 217

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  if !@user_tags.nil? && @user_tags.length > 100
    invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/ibm_cloud_power/models/create_image.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
238
239
240
241
242
# File 'lib/ibm_cloud_power/models/create_image.rb', line 233

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  os_type_validator = EnumAttributeValidator.new('String', ["aix", "ibmi", "rhel", "sles"])
  return false unless os_type_validator.valid?(@os_type)
  return false if @source.nil?
  source_validator = EnumAttributeValidator.new('String', ["root-project", "url"])
  return false unless source_validator.valid?(@source)
  return false if !@user_tags.nil? && @user_tags.length > 100
  true
end