Class: IbmCloudPower::DeadPeerDetection

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/dead_peer_detection.rb

Overview

Dead Peer Detection of the VPN Connection

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeadPeerDetection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::DeadPeerDetection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::DeadPeerDetection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = nil
  end

  if attributes.key?(:'interval')
    self.interval = attributes[:'interval']
  else
    self.interval = 10
  end

  if attributes.key?(:'threshold')
    self.threshold = attributes[:'threshold']
  else
    self.threshold = 5
  end
end

Instance Attribute Details

#actionObject

Action to take when a Peer Gateway stops responding



20
21
22
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 20

def action
  @action
end

#intervalObject

How often to test that the Peer Gateway is responsive



23
24
25
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 23

def interval
  @interval
end

#thresholdObject

The number of attempts to connect before tearing down the connection



26
27
28
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 26

def threshold
  @threshold
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 51

def self.attribute_map
  {
    :'action' => :'action',
    :'interval' => :'interval',
    :'threshold' => :'threshold'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 70

def self.openapi_types
  {
    :'action' => :'String',
    :'interval' => :'Integer',
    :'threshold' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      interval == o.interval &&
      threshold == o.threshold
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 235

def hash
  [action, interval, threshold].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @interval.nil?
    invalid_properties.push('invalid value for "interval", interval cannot be nil.')
  end

  if @interval > 60
    invalid_properties.push('invalid value for "interval", must be smaller than or equal to 60.')
  end

  if @interval < 2
    invalid_properties.push('invalid value for "interval", must be greater than or equal to 2.')
  end

  if @threshold.nil?
    invalid_properties.push('invalid value for "threshold", threshold cannot be nil.')
  end

  if @threshold > 5
    invalid_properties.push('invalid value for "threshold", must be smaller than or equal to 5.')
  end

  if @threshold < 1
    invalid_properties.push('invalid value for "threshold", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/ibm_cloud_power/models/dead_peer_detection.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @action.nil?
  action_validator = EnumAttributeValidator.new('String', ["restart"])
  return false unless action_validator.valid?(@action)
  return false if @interval.nil?
  return false if @interval > 60
  return false if @interval < 2
  return false if @threshold.nil?
  return false if @threshold > 5
  return false if @threshold < 1
  true
end