Class: IbmCloudPower::FlashCopyMapping

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/flash_copy_mapping.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlashCopyMapping

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::FlashCopyMapping` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::FlashCopyMapping`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'copy_rate')
    self.copy_rate = attributes[:'copy_rate']
  end

  if attributes.key?(:'flash_copy_name')
    self.flash_copy_name = attributes[:'flash_copy_name']
  else
    self.flash_copy_name = nil
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  end

  if attributes.key?(:'source_volume_name')
    self.source_volume_name = attributes[:'source_volume_name']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'target_volume_name')
    self.target_volume_name = attributes[:'target_volume_name']
  end
end

Instance Attribute Details

#copy_rateObject

Indicates the rate of flash copy operation of a volume



19
20
21
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 19

def copy_rate
  @copy_rate
end

#flash_copy_nameObject

Indicates flash copy name of the volume



22
23
24
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 22

def flash_copy_name
  @flash_copy_name
end

#progressObject

Indicates the progress of flash copy operation



25
26
27
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 25

def progress
  @progress
end

#source_volume_nameObject

Indicates name of the source volume



28
29
30
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 28

def source_volume_name
  @source_volume_name
end

#start_timeObject

Indicates the start time of flash copy operation



31
32
33
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 31

def start_time
  @start_time
end

#statusObject

Copy status of a volume



34
35
36
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 34

def status
  @status
end

#target_volume_nameObject

Indicates name of the target volume



37
38
39
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 37

def target_volume_name
  @target_volume_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 40

def self.attribute_map
  {
    :'copy_rate' => :'copyRate',
    :'flash_copy_name' => :'flashCopyName',
    :'progress' => :'progress',
    :'source_volume_name' => :'sourceVolumeName',
    :'start_time' => :'startTime',
    :'status' => :'status',
    :'target_volume_name' => :'targetVolumeName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 187

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 63

def self.openapi_types
  {
    :'copy_rate' => :'Integer',
    :'flash_copy_name' => :'String',
    :'progress' => :'Integer',
    :'source_volume_name' => :'String',
    :'start_time' => :'Time',
    :'status' => :'String',
    :'target_volume_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



160
161
162
163
164
165
166
167
168
169
170
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      copy_rate == o.copy_rate &&
      flash_copy_name == o.flash_copy_name &&
      progress == o.progress &&
      source_volume_name == o.source_volume_name &&
      start_time == o.start_time &&
      status == o.status &&
      target_volume_name == o.target_volume_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 180

def hash
  [copy_rate, flash_copy_name, progress, source_volume_name, start_time, status, target_volume_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @flash_copy_name.nil?
    invalid_properties.push('invalid value for "flash_copy_name", flash_copy_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
# File 'lib/ibm_cloud_power/models/flash_copy_mapping.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @flash_copy_name.nil?
  true
end