Class: IbmCloudPower::HostGroup
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::HostGroup
- Defined in:
- lib/ibm_cloud_power/models/host_group.rb
Overview
Description of a host group
Instance Attribute Summary collapse
-
#creation_date ⇒ Object
Date/Time of host group creation.
-
#hosts ⇒ Object
List of hosts.
-
#id ⇒ Object
Host group ID.
-
#name ⇒ Object
Name of the host group.
-
#primary ⇒ Object
ID of the workspace owning the host group.
-
#secondaries ⇒ Object
IDs of workspaces the host group has been shared with.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostGroup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ HostGroup
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::HostGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::HostGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'hosts') if (value = attributes[:'hosts']).is_a?(Array) self.hosts = value end end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'primary') self.primary = attributes[:'primary'] end if attributes.key?(:'secondaries') if (value = attributes[:'secondaries']).is_a?(Array) self.secondaries = value end end end |
Instance Attribute Details
#creation_date ⇒ Object
Date/Time of host group creation
20 21 22 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 20 def creation_date @creation_date end |
#hosts ⇒ Object
List of hosts
23 24 25 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 23 def hosts @hosts end |
#id ⇒ Object
Host group ID
26 27 28 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 26 def id @id end |
#name ⇒ Object
Name of the host group
29 30 31 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 29 def name @name end |
#primary ⇒ Object
ID of the workspace owning the host group
32 33 34 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 32 def primary @primary end |
#secondaries ⇒ Object
IDs of workspaces the host group has been shared with
35 36 37 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 35 def secondaries @secondaries end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 38 def self.attribute_map { :'creation_date' => :'creationDate', :'hosts' => :'hosts', :'id' => :'id', :'name' => :'name', :'primary' => :'primary', :'secondaries' => :'secondaries' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 165 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 60 def self.openapi_types { :'creation_date' => :'Time', :'hosts' => :'Array<String>', :'id' => :'String', :'name' => :'String', :'primary' => :'String', :'secondaries' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
139 140 141 142 143 144 145 146 147 148 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 139 def ==(o) return true if self.equal?(o) self.class == o.class && creation_date == o.creation_date && hosts == o.hosts && id == o.id && name == o.name && primary == o.primary && secondaries == o.secondaries end |
#eql?(o) ⇒ Boolean
152 153 154 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 152 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 158 def hash [creation_date, hosts, id, name, primary, secondaries].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 124 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 |
# File 'lib/ibm_cloud_power/models/host_group.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |