Class: IbmCloudPower::HostGroupsApi
- Inherits:
-
Object
- Object
- IbmCloudPower::HostGroupsApi
- Defined in:
- lib/ibm_cloud_power/api/host_groups_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ HostGroupsApi
constructor
A new instance of HostGroupsApi.
-
#v1_available_hosts(opts = {}) ⇒ Hash<String, AvailableHost>
List all the hosts that can be reserved.
-
#v1_available_hosts_with_http_info(opts = {}) ⇒ Array<(Hash<String, AvailableHost>, Integer, Hash)>
List all the hosts that can be reserved.
-
#v1_host_groups_get(opts = {}) ⇒ Array<HostGroup>
Get the list of host groups for the workspace.
-
#v1_host_groups_get_with_http_info(opts = {}) ⇒ Array<(Array<HostGroup>, Integer, Hash)>
Get the list of host groups for the workspace.
-
#v1_host_groups_id_get(host_group_id, opts = {}) ⇒ HostGroup
Get the details of a host group.
-
#v1_host_groups_id_get_with_http_info(host_group_id, opts = {}) ⇒ Array<(HostGroup, Integer, Hash)>
Get the details of a host group.
-
#v1_host_groups_id_put(host_group_id, body, opts = {}) ⇒ HostGroup
Share/unshare a host group with another workspace.
-
#v1_host_groups_id_put_with_http_info(host_group_id, body, opts = {}) ⇒ Array<(HostGroup, Integer, Hash)>
Share/unshare a host group with another workspace.
-
#v1_host_groups_post(body, opts = {}) ⇒ HostGroup
Create a host group with one (or more) host.
-
#v1_host_groups_post_with_http_info(body, opts = {}) ⇒ Array<(HostGroup, Integer, Hash)>
Create a host group with one (or more) host.
-
#v1_hosts_get(opts = {}) ⇒ Array<Host>
Get the list of all the hosts the workspace has access to.
-
#v1_hosts_get_with_http_info(opts = {}) ⇒ Array<(Array<Host>, Integer, Hash)>
Get the list of all the hosts the workspace has access to.
-
#v1_hosts_id_delete(host_id, opts = {}) ⇒ Object
Release a host from its host group.
-
#v1_hosts_id_delete_with_http_info(host_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Release a host from its host group.
-
#v1_hosts_id_get(host_id, opts = {}) ⇒ Host
Get the details about a host.
-
#v1_hosts_id_get_with_http_info(host_id, opts = {}) ⇒ Array<(Host, Integer, Hash)>
Get the details about a host.
-
#v1_hosts_id_put(host_id, body, opts = {}) ⇒ Host
Modify the display name of a host.
-
#v1_hosts_id_put_with_http_info(host_id, body, opts = {}) ⇒ Array<(Host, Integer, Hash)>
Modify the display name of a host.
-
#v1_hosts_post(body, opts = {}) ⇒ Array<Host>
Add new host(s) to an existing host group.
-
#v1_hosts_post_with_http_info(body, opts = {}) ⇒ Array<(Array<Host>, Integer, Hash)>
Add new host(s) to an existing host group.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ HostGroupsApi
Returns a new instance of HostGroupsApi.
19 20 21 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_available_hosts(opts = {}) ⇒ Hash<String, AvailableHost>
List all the hosts that can be reserved
25 26 27 28 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 25 def v1_available_hosts(opts = {}) data, _status_code, _headers = v1_available_hosts_with_http_info(opts) data end |
#v1_available_hosts_with_http_info(opts = {}) ⇒ Array<(Hash<String, AvailableHost>, Integer, Hash)>
List all the hosts that can be reserved
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 33 def v1_available_hosts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_available_hosts ...' end # resource path local_var_path = '/v1/available-hosts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, AvailableHost>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_available_hosts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_available_hosts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_host_groups_get(opts = {}) ⇒ Array<HostGroup>
Get the list of host groups for the workspace
80 81 82 83 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 80 def v1_host_groups_get(opts = {}) data, _status_code, _headers = v1_host_groups_get_with_http_info(opts) data end |
#v1_host_groups_get_with_http_info(opts = {}) ⇒ Array<(Array<HostGroup>, Integer, Hash)>
Get the list of host groups for the workspace
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 88 def v1_host_groups_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_host_groups_get ...' end # resource path local_var_path = '/v1/host-groups' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<HostGroup>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_host_groups_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_host_groups_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_host_groups_id_get(host_group_id, opts = {}) ⇒ HostGroup
Get the details of a host group
136 137 138 139 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 136 def v1_host_groups_id_get(host_group_id, opts = {}) data, _status_code, _headers = v1_host_groups_id_get_with_http_info(host_group_id, opts) data end |
#v1_host_groups_id_get_with_http_info(host_group_id, opts = {}) ⇒ Array<(HostGroup, Integer, Hash)>
Get the details of a host group
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 145 def v1_host_groups_id_get_with_http_info(host_group_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_host_groups_id_get ...' end # verify the required parameter 'host_group_id' is set if @api_client.config.client_side_validation && host_group_id.nil? fail ArgumentError, "Missing the required parameter 'host_group_id' when calling HostGroupsApi.v1_host_groups_id_get" end # resource path local_var_path = '/v1/host-groups/{host_group_id}'.sub('{host_group_id}', CGI.escape(host_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'HostGroup' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_host_groups_id_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_host_groups_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_host_groups_id_put(host_group_id, body, opts = {}) ⇒ HostGroup
Share/unshare a host group with another workspace
198 199 200 201 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 198 def v1_host_groups_id_put(host_group_id, body, opts = {}) data, _status_code, _headers = v1_host_groups_id_put_with_http_info(host_group_id, body, opts) data end |
#v1_host_groups_id_put_with_http_info(host_group_id, body, opts = {}) ⇒ Array<(HostGroup, Integer, Hash)>
Share/unshare a host group with another workspace
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 208 def v1_host_groups_id_put_with_http_info(host_group_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_host_groups_id_put ...' end # verify the required parameter 'host_group_id' is set if @api_client.config.client_side_validation && host_group_id.nil? fail ArgumentError, "Missing the required parameter 'host_group_id' when calling HostGroupsApi.v1_host_groups_id_put" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling HostGroupsApi.v1_host_groups_id_put" end # resource path local_var_path = '/v1/host-groups/{host_group_id}'.sub('{host_group_id}', CGI.escape(host_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'HostGroup' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_host_groups_id_put", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_host_groups_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_host_groups_post(body, opts = {}) ⇒ HostGroup
Create a host group with one (or more) host
269 270 271 272 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 269 def v1_host_groups_post(body, opts = {}) data, _status_code, _headers = v1_host_groups_post_with_http_info(body, opts) data end |
#v1_host_groups_post_with_http_info(body, opts = {}) ⇒ Array<(HostGroup, Integer, Hash)>
Create a host group with one (or more) host
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 278 def v1_host_groups_post_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_host_groups_post ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling HostGroupsApi.v1_host_groups_post" end # resource path local_var_path = '/v1/host-groups' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'HostGroup' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_host_groups_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_host_groups_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_hosts_get(opts = {}) ⇒ Array<Host>
Get the list of all the hosts the workspace has access to
334 335 336 337 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 334 def v1_hosts_get(opts = {}) data, _status_code, _headers = v1_hosts_get_with_http_info(opts) data end |
#v1_hosts_get_with_http_info(opts = {}) ⇒ Array<(Array<Host>, Integer, Hash)>
Get the list of all the hosts the workspace has access to
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 342 def v1_hosts_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_hosts_get ...' end # resource path local_var_path = '/v1/hosts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Host>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_hosts_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_hosts_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_hosts_id_delete(host_id, opts = {}) ⇒ Object
Release a host from its host group
390 391 392 393 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 390 def v1_hosts_id_delete(host_id, opts = {}) data, _status_code, _headers = v1_hosts_id_delete_with_http_info(host_id, opts) data end |
#v1_hosts_id_delete_with_http_info(host_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Release a host from its host group
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 399 def v1_hosts_id_delete_with_http_info(host_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_hosts_id_delete ...' end # verify the required parameter 'host_id' is set if @api_client.config.client_side_validation && host_id.nil? fail ArgumentError, "Missing the required parameter 'host_id' when calling HostGroupsApi.v1_hosts_id_delete" end # resource path local_var_path = '/v1/hosts/{host_id}'.sub('{host_id}', CGI.escape(host_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_hosts_id_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_hosts_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_hosts_id_get(host_id, opts = {}) ⇒ Host
Get the details about a host
451 452 453 454 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 451 def v1_hosts_id_get(host_id, opts = {}) data, _status_code, _headers = v1_hosts_id_get_with_http_info(host_id, opts) data end |
#v1_hosts_id_get_with_http_info(host_id, opts = {}) ⇒ Array<(Host, Integer, Hash)>
Get the details about a host
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 460 def v1_hosts_id_get_with_http_info(host_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_hosts_id_get ...' end # verify the required parameter 'host_id' is set if @api_client.config.client_side_validation && host_id.nil? fail ArgumentError, "Missing the required parameter 'host_id' when calling HostGroupsApi.v1_hosts_id_get" end # resource path local_var_path = '/v1/hosts/{host_id}'.sub('{host_id}', CGI.escape(host_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Host' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_hosts_id_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_hosts_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_hosts_id_put(host_id, body, opts = {}) ⇒ Host
Modify the display name of a host
513 514 515 516 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 513 def v1_hosts_id_put(host_id, body, opts = {}) data, _status_code, _headers = v1_hosts_id_put_with_http_info(host_id, body, opts) data end |
#v1_hosts_id_put_with_http_info(host_id, body, opts = {}) ⇒ Array<(Host, Integer, Hash)>
Modify the display name of a host
523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 523 def v1_hosts_id_put_with_http_info(host_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_hosts_id_put ...' end # verify the required parameter 'host_id' is set if @api_client.config.client_side_validation && host_id.nil? fail ArgumentError, "Missing the required parameter 'host_id' when calling HostGroupsApi.v1_hosts_id_put" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling HostGroupsApi.v1_hosts_id_put" end # resource path local_var_path = '/v1/hosts/{host_id}'.sub('{host_id}', CGI.escape(host_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'Host' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_hosts_id_put", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_hosts_id_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_hosts_post(body, opts = {}) ⇒ Array<Host>
Add new host(s) to an existing host group
584 585 586 587 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 584 def v1_hosts_post(body, opts = {}) data, _status_code, _headers = v1_hosts_post_with_http_info(body, opts) data end |
#v1_hosts_post_with_http_info(body, opts = {}) ⇒ Array<(Array<Host>, Integer, Hash)>
Add new host(s) to an existing host group
593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/ibm_cloud_power/api/host_groups_api.rb', line 593 def v1_hosts_post_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HostGroupsApi.v1_hosts_post ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling HostGroupsApi.v1_hosts_post" end # resource path local_var_path = '/v1/hosts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'Array<Host>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HostGroupsApi.v1_hosts_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HostGroupsApi#v1_hosts_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |