Class: IbmCloudPower::IKEPolicyCreate

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/ike_policy_create.rb

Overview

IKE Policy object used for creation

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IKEPolicyCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::IKEPolicyCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::IKEPolicyCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'authentication')
    self.authentication = attributes[:'authentication']
  end

  if attributes.key?(:'dh_group')
    self.dh_group = attributes[:'dh_group']
  else
    self.dh_group = nil
  end

  if attributes.key?(:'encryption')
    self.encryption = attributes[:'encryption']
  else
    self.encryption = nil
  end

  if attributes.key?(:'key_lifetime')
    self.key_lifetime = attributes[:'key_lifetime']
  else
    self.key_lifetime = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'preshared_key')
    self.preshared_key = attributes[:'preshared_key']
  else
    self.preshared_key = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end
end

Instance Attribute Details

#authenticationObject

Returns the value of attribute authentication.



19
20
21
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 19

def authentication
  @authentication
end

#dh_groupObject

DH group of the IKE Policy



22
23
24
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 22

def dh_group
  @dh_group
end

#encryptionObject

encryption of the IKE Policy



25
26
27
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 25

def encryption
  @encryption
end

#key_lifetimeObject

Policy key lifetime



28
29
30
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 28

def key_lifetime
  @key_lifetime
end

#nameObject

name of the IKE Policy



31
32
33
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 31

def name
  @name
end

#preshared_keyObject

Preshared key used in this IKE Policy (length of preshared key must be even)



34
35
36
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 34

def preshared_key
  @preshared_key
end

#versionObject

version of the IKE Policy



37
38
39
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 37

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 62

def self.attribute_map
  {
    :'authentication' => :'authentication',
    :'dh_group' => :'dhGroup',
    :'encryption' => :'encryption',
    :'key_lifetime' => :'keyLifetime',
    :'name' => :'name',
    :'preshared_key' => :'presharedKey',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 336

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 85

def self.openapi_types
  {
    :'authentication' => :'IKEPolicyAuthentication',
    :'dh_group' => :'Integer',
    :'encryption' => :'String',
    :'key_lifetime' => :'Integer',
    :'name' => :'String',
    :'preshared_key' => :'String',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



309
310
311
312
313
314
315
316
317
318
319
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 309

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      authentication == o.authentication &&
      dh_group == o.dh_group &&
      encryption == o.encryption &&
      key_lifetime == o.key_lifetime &&
      name == o.name &&
      preshared_key == o.preshared_key &&
      version == o.version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


323
324
325
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 323

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



329
330
331
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 329

def hash
  [authentication, dh_group, encryption, key_lifetime, name, preshared_key, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @dh_group.nil?
    invalid_properties.push('invalid value for "dh_group", dh_group cannot be nil.')
  end

  if @encryption.nil?
    invalid_properties.push('invalid value for "encryption", encryption cannot be nil.')
  end

  if @key_lifetime.nil?
    invalid_properties.push('invalid value for "key_lifetime", key_lifetime cannot be nil.')
  end

  if @key_lifetime > 86400
    invalid_properties.push('invalid value for "key_lifetime", must be smaller than or equal to 86400.')
  end

  if @key_lifetime < 180
    invalid_properties.push('invalid value for "key_lifetime", must be greater than or equal to 180.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 47
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 47.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @preshared_key.nil?
    invalid_properties.push('invalid value for "preshared_key", preshared_key cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 358

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/ibm_cloud_power/models/ike_policy_create.rb', line 210

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @dh_group.nil?
  dh_group_validator = EnumAttributeValidator.new('Integer', [1, 2, 5, 14, 19, 20, 24])
  return false unless dh_group_validator.valid?(@dh_group)
  return false if @encryption.nil?
  encryption_validator = EnumAttributeValidator.new('String', ["aes-256-cbc", "aes-192-cbc", "aes-128-cbc", "aes-256-gcm", "aes-128-gcm", "3des-cbc"])
  return false unless encryption_validator.valid?(@encryption)
  return false if @key_lifetime.nil?
  return false if @key_lifetime > 86400
  return false if @key_lifetime < 180
  return false if @name.nil?
  return false if @name.to_s.length > 47
  return false if @name.to_s.length < 1
  return false if @preshared_key.nil?
  return false if @version.nil?
  version_validator = EnumAttributeValidator.new('Integer', [1, 2])
  return false unless version_validator.valid?(@version)
  true
end