Class: IbmCloudPower::IPSecPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::IPSecPolicy
- Defined in:
- lib/ibm_cloud_power/models/ip_sec_policy.rb
Overview
IPSec Policy object
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#authentication ⇒ Object
Returns the value of attribute authentication.
-
#dh_group ⇒ Object
Diffie-Hellman group.
-
#encryption ⇒ Object
connection encryption policy.
-
#id ⇒ Object
unique identifier of the IPSec Policy.
-
#key_lifetime ⇒ Object
Policy key lifetime.
-
#name ⇒ Object
IPSec Policy name.
-
#pfs ⇒ Object
Perfect Forward Secrecy.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IPSecPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IPSecPolicy
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::IPSecPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::IPSecPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'authentication') self.authentication = attributes[:'authentication'] else self.authentication = nil end if attributes.key?(:'dh_group') self.dh_group = attributes[:'dh_group'] else self.dh_group = nil end if attributes.key?(:'encryption') self.encryption = attributes[:'encryption'] else self.encryption = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'key_lifetime') self.key_lifetime = attributes[:'key_lifetime'] else self.key_lifetime = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'pfs') self.pfs = attributes[:'pfs'] else self.pfs = nil end end |
Instance Attribute Details
#authentication ⇒ Object
Returns the value of attribute authentication.
19 20 21 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 19 def authentication @authentication end |
#dh_group ⇒ Object
Diffie-Hellman group
22 23 24 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 22 def dh_group @dh_group end |
#encryption ⇒ Object
connection encryption policy
25 26 27 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 25 def encryption @encryption end |
#id ⇒ Object
unique identifier of the IPSec Policy
28 29 30 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 28 def id @id end |
#key_lifetime ⇒ Object
Policy key lifetime
31 32 33 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 31 def key_lifetime @key_lifetime end |
#name ⇒ Object
IPSec Policy name
34 35 36 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 34 def name @name end |
#pfs ⇒ Object
Perfect Forward Secrecy
37 38 39 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 37 def pfs @pfs end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 62 def self.attribute_map { :'authentication' => :'authentication', :'dh_group' => :'dhGroup', :'encryption' => :'encryption', :'id' => :'id', :'key_lifetime' => :'keyLifetime', :'name' => :'name', :'pfs' => :'pfs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 333 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 85 def self.openapi_types { :'authentication' => :'IPSECPolicyAuthentication', :'dh_group' => :'Integer', :'encryption' => :'String', :'id' => :'String', :'key_lifetime' => :'Integer', :'name' => :'String', :'pfs' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 306 def ==(o) return true if self.equal?(o) self.class == o.class && authentication == o.authentication && dh_group == o.dh_group && encryption == o.encryption && id == o.id && key_lifetime == o.key_lifetime && name == o.name && pfs == o.pfs end |
#eql?(o) ⇒ Boolean
320 321 322 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 320 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
326 327 328 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 326 def hash [authentication, dh_group, encryption, id, key_lifetime, name, pfs].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @authentication.nil? invalid_properties.push('invalid value for "authentication", authentication cannot be nil.') end if @dh_group.nil? invalid_properties.push('invalid value for "dh_group", dh_group cannot be nil.') end if @encryption.nil? invalid_properties.push('invalid value for "encryption", encryption cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @key_lifetime.nil? invalid_properties.push('invalid value for "key_lifetime", key_lifetime cannot be nil.') end if @key_lifetime > 86400 invalid_properties.push('invalid value for "key_lifetime", must be smaller than or equal to 86400.') end if @key_lifetime < 180 invalid_properties.push('invalid value for "key_lifetime", must be greater than or equal to 180.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @pfs.nil? invalid_properties.push('invalid value for "pfs", pfs cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 355 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/ibm_cloud_power/models/ip_sec_policy.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @authentication.nil? return false if @dh_group.nil? dh_group_validator = EnumAttributeValidator.new('Integer', [1, 2, 5, 14, 19, 20, 24]) return false unless dh_group_validator.valid?(@dh_group) return false if @encryption.nil? encryption_validator = EnumAttributeValidator.new('String', ["aes-256-cbc", "aes-192-cbc", "aes-128-cbc", "aes-256-gcm", "aes-192-gcm", "aes-128-gcm", "3des-cbc"]) return false unless encryption_validator.valid?(@encryption) return false if @id.nil? return false if @key_lifetime.nil? return false if @key_lifetime > 86400 return false if @key_lifetime < 180 return false if @name.nil? return false if @pfs.nil? true end |