Class: IbmCloudPower::Image

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/image.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Image

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/ibm_cloud_power/models/image.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Image` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Image`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  else
    self.image_id = nil
  end

  if attributes.key?(:'last_update_date')
    self.last_update_date = attributes[:'last_update_date']
  else
    self.last_update_date = nil
  end

  if attributes.key?(:'max_image_volume_size')
    self.max_image_volume_size = attributes[:'max_image_volume_size']
  else
    self.max_image_volume_size = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'servers')
    if (value = attributes[:'servers']).is_a?(Array)
      self.servers = value
    end
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = nil
  end

  if attributes.key?(:'specifications')
    self.specifications = attributes[:'specifications']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'storage_pool')
    self.storage_pool = attributes[:'storage_pool']
  else
    self.storage_pool = nil
  end

  if attributes.key?(:'storage_type')
    self.storage_type = attributes[:'storage_type']
  else
    self.storage_type = nil
  end

  if attributes.key?(:'taskref')
    self.taskref = attributes[:'taskref']
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end

  if attributes.key?(:'volumes')
    if (value = attributes[:'volumes']).is_a?(Array)
      self.volumes = value
    end
  end
end

Instance Attribute Details

#creation_dateObject

Creation Date



19
20
21
# File 'lib/ibm_cloud_power/models/image.rb', line 19

def creation_date
  @creation_date
end

#crnObject

The CRN for this resource



22
23
24
# File 'lib/ibm_cloud_power/models/image.rb', line 22

def crn
  @crn
end

#descriptionObject

Description



25
26
27
# File 'lib/ibm_cloud_power/models/image.rb', line 25

def description
  @description
end

#image_idObject

Image ID



28
29
30
# File 'lib/ibm_cloud_power/models/image.rb', line 28

def image_id
  @image_id
end

#last_update_dateObject

Last Update Date



31
32
33
# File 'lib/ibm_cloud_power/models/image.rb', line 31

def last_update_date
  @last_update_date
end

#max_image_volume_sizeObject

Maximum image volume size for multi-volume image



34
35
36
# File 'lib/ibm_cloud_power/models/image.rb', line 34

def max_image_volume_size
  @max_image_volume_size
end

#nameObject

Image Name



37
38
39
# File 'lib/ibm_cloud_power/models/image.rb', line 37

def name
  @name
end

#serversObject

List of Servers that have deployed the image



40
41
42
# File 'lib/ibm_cloud_power/models/image.rb', line 40

def servers
  @servers
end

#sizeObject

Image Size



43
44
45
# File 'lib/ibm_cloud_power/models/image.rb', line 43

def size
  @size
end

#specificationsObject

Returns the value of attribute specifications.



45
46
47
# File 'lib/ibm_cloud_power/models/image.rb', line 45

def specifications
  @specifications
end

#stateObject

Image State



48
49
50
# File 'lib/ibm_cloud_power/models/image.rb', line 48

def state
  @state
end

#storage_poolObject

Storage pool where the image resides



51
52
53
# File 'lib/ibm_cloud_power/models/image.rb', line 51

def storage_pool
  @storage_pool
end

#storage_typeObject

Storage type for image



54
55
56
# File 'lib/ibm_cloud_power/models/image.rb', line 54

def storage_type
  @storage_type
end

#taskrefObject

Returns the value of attribute taskref.



56
57
58
# File 'lib/ibm_cloud_power/models/image.rb', line 56

def taskref
  @taskref
end

#user_tagsObject

List of user tags



59
60
61
# File 'lib/ibm_cloud_power/models/image.rb', line 59

def user_tags
  @user_tags
end

#volumesObject

Image Volumes



62
63
64
# File 'lib/ibm_cloud_power/models/image.rb', line 62

def volumes
  @volumes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/ibm_cloud_power/models/image.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/ibm_cloud_power/models/image.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/ibm_cloud_power/models/image.rb', line 65

def self.attribute_map
  {
    :'creation_date' => :'creationDate',
    :'crn' => :'crn',
    :'description' => :'description',
    :'image_id' => :'imageID',
    :'last_update_date' => :'lastUpdateDate',
    :'max_image_volume_size' => :'maxImageVolumeSize',
    :'name' => :'name',
    :'servers' => :'servers',
    :'size' => :'size',
    :'specifications' => :'specifications',
    :'state' => :'state',
    :'storage_pool' => :'storagePool',
    :'storage_type' => :'storageType',
    :'taskref' => :'taskref',
    :'user_tags' => :'userTags',
    :'volumes' => :'volumes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/ibm_cloud_power/models/image.rb', line 419

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/ibm_cloud_power/models/image.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/ibm_cloud_power/models/image.rb', line 97

def self.openapi_types
  {
    :'creation_date' => :'Time',
    :'crn' => :'String',
    :'description' => :'String',
    :'image_id' => :'String',
    :'last_update_date' => :'Time',
    :'max_image_volume_size' => :'Float',
    :'name' => :'String',
    :'servers' => :'Array<String>',
    :'size' => :'Float',
    :'specifications' => :'ImageSpecifications',
    :'state' => :'String',
    :'storage_pool' => :'String',
    :'storage_type' => :'String',
    :'taskref' => :'ImageTaskref',
    :'user_tags' => :'Array<String>',
    :'volumes' => :'Array<ImageVolume>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/ibm_cloud_power/models/image.rb', line 383

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      creation_date == o.creation_date &&
      crn == o.crn &&
      description == o.description &&
      image_id == o.image_id &&
      last_update_date == o.last_update_date &&
      max_image_volume_size == o.max_image_volume_size &&
      name == o.name &&
      servers == o.servers &&
      size == o.size &&
      specifications == o.specifications &&
      state == o.state &&
      storage_pool == o.storage_pool &&
      storage_type == o.storage_type &&
      taskref == o.taskref &&
      user_tags == o.user_tags &&
      volumes == o.volumes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


406
407
408
# File 'lib/ibm_cloud_power/models/image.rb', line 406

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



412
413
414
# File 'lib/ibm_cloud_power/models/image.rb', line 412

def hash
  [creation_date, crn, description, image_id, last_update_date, max_image_volume_size, name, servers, size, specifications, state, storage_pool, storage_type, taskref, user_tags, volumes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/ibm_cloud_power/models/image.rb', line 229

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @image_id.nil?
    invalid_properties.push('invalid value for "image_id", image_id cannot be nil.')
  end

  if @last_update_date.nil?
    invalid_properties.push('invalid value for "last_update_date", last_update_date cannot be nil.')
  end

  if @max_image_volume_size.nil?
    invalid_properties.push('invalid value for "max_image_volume_size", max_image_volume_size cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  if @storage_pool.nil?
    invalid_properties.push('invalid value for "storage_pool", storage_pool cannot be nil.')
  end

  if @storage_type.nil?
    invalid_properties.push('invalid value for "storage_type", storage_type cannot be nil.')
  end

  if !@user_tags.nil? && @user_tags.length > 100
    invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/ibm_cloud_power/models/image.rb', line 441

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/ibm_cloud_power/models/image.rb', line 273

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @creation_date.nil?
  return false if @image_id.nil?
  return false if @last_update_date.nil?
  return false if @max_image_volume_size.nil?
  return false if @name.nil?
  return false if @size.nil?
  return false if @storage_pool.nil?
  return false if @storage_type.nil?
  return false if !@user_tags.nil? && @user_tags.length > 100
  true
end