Class: IbmCloudPower::ImageReference

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/image_reference.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ImageReference

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::ImageReference` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::ImageReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'href')
    self.href = attributes[:'href']
  else
    self.href = nil
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  else
    self.image_id = nil
  end

  if attributes.key?(:'last_update_date')
    self.last_update_date = attributes[:'last_update_date']
  else
    self.last_update_date = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'specifications')
    self.specifications = attributes[:'specifications']
  else
    self.specifications = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'storage_pool')
    self.storage_pool = attributes[:'storage_pool']
  else
    self.storage_pool = nil
  end

  if attributes.key?(:'storage_type')
    self.storage_type = attributes[:'storage_type']
  else
    self.storage_type = nil
  end
end

Instance Attribute Details

#creation_dateObject

Creation Date



19
20
21
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 19

def creation_date
  @creation_date
end

#crnObject

The CRN for this resource



22
23
24
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 22

def crn
  @crn
end

#descriptionObject

Description



25
26
27
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 25

def description
  @description
end

#hrefObject

Link to Image resource



28
29
30
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 28

def href
  @href
end

#image_idObject

Image ID



31
32
33
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 31

def image_id
  @image_id
end

#last_update_dateObject

Last Update Date



34
35
36
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 34

def last_update_date
  @last_update_date
end

#nameObject

Image Name



37
38
39
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 37

def name
  @name
end

#specificationsObject

Returns the value of attribute specifications.



39
40
41
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 39

def specifications
  @specifications
end

#stateObject

Image State



42
43
44
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 42

def state
  @state
end

#storage_poolObject

Storage pool where image resides



45
46
47
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 45

def storage_pool
  @storage_pool
end

#storage_typeObject

Storage type for image



48
49
50
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 48

def storage_type
  @storage_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 51

def self.attribute_map
  {
    :'creation_date' => :'creationDate',
    :'crn' => :'crn',
    :'description' => :'description',
    :'href' => :'href',
    :'image_id' => :'imageID',
    :'last_update_date' => :'lastUpdateDate',
    :'name' => :'name',
    :'specifications' => :'specifications',
    :'state' => :'state',
    :'storage_pool' => :'storagePool',
    :'storage_type' => :'storageType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 379

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 78

def self.openapi_types
  {
    :'creation_date' => :'Time',
    :'crn' => :'String',
    :'description' => :'String',
    :'href' => :'String',
    :'image_id' => :'String',
    :'last_update_date' => :'Time',
    :'name' => :'String',
    :'specifications' => :'ImageSpecifications',
    :'state' => :'String',
    :'storage_pool' => :'String',
    :'storage_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 348

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      creation_date == o.creation_date &&
      crn == o.crn &&
      description == o.description &&
      href == o.href &&
      image_id == o.image_id &&
      last_update_date == o.last_update_date &&
      name == o.name &&
      specifications == o.specifications &&
      state == o.state &&
      storage_pool == o.storage_pool &&
      storage_type == o.storage_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


366
367
368
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 366

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



372
373
374
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 372

def hash
  [creation_date, crn, description, href, image_id, last_update_date, name, specifications, state, storage_pool, storage_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @href.nil?
    invalid_properties.push('invalid value for "href", href cannot be nil.')
  end

  if @image_id.nil?
    invalid_properties.push('invalid value for "image_id", image_id cannot be nil.')
  end

  if @last_update_date.nil?
    invalid_properties.push('invalid value for "last_update_date", last_update_date cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @specifications.nil?
    invalid_properties.push('invalid value for "specifications", specifications cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @storage_pool.nil?
    invalid_properties.push('invalid value for "storage_pool", storage_pool cannot be nil.')
  end

  if @storage_type.nil?
    invalid_properties.push('invalid value for "storage_type", storage_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 401

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/ibm_cloud_power/models/image_reference.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @creation_date.nil?
  return false if @description.nil?
  return false if @href.nil?
  return false if @image_id.nil?
  return false if @last_update_date.nil?
  return false if @name.nil?
  return false if @specifications.nil?
  return false if @state.nil?
  return false if @storage_pool.nil?
  return false if @storage_type.nil?
  true
end