Class: IbmCloudPower::ImageSpecifications
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::ImageSpecifications
- Defined in:
- lib/ibm_cloud_power/models/image_specifications.rb
Instance Attribute Summary collapse
-
#architecture ⇒ Object
Architecture.
-
#container_format ⇒ Object
Container Format.
-
#disk_format ⇒ Object
Disk Format.
-
#endianness ⇒ Object
Endianness.
-
#hypervisor_type ⇒ Object
Hypervisor Type.
-
#image_type ⇒ Object
Image Type.
-
#operating_system ⇒ Object
Operating System.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImageSpecifications
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ImageSpecifications
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::ImageSpecifications` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::ImageSpecifications`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'architecture') self.architecture = attributes[:'architecture'] end if attributes.key?(:'container_format') self.container_format = attributes[:'container_format'] end if attributes.key?(:'disk_format') self.disk_format = attributes[:'disk_format'] end if attributes.key?(:'endianness') self.endianness = attributes[:'endianness'] end if attributes.key?(:'hypervisor_type') self.hypervisor_type = attributes[:'hypervisor_type'] end if attributes.key?(:'image_type') self.image_type = attributes[:'image_type'] end if attributes.key?(:'operating_system') self. = attributes[:'operating_system'] end end |
Instance Attribute Details
#architecture ⇒ Object
Architecture
19 20 21 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 19 def architecture @architecture end |
#container_format ⇒ Object
Container Format
22 23 24 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 22 def container_format @container_format end |
#disk_format ⇒ Object
Disk Format
25 26 27 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 25 def disk_format @disk_format end |
#endianness ⇒ Object
Endianness
28 29 30 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 28 def endianness @endianness end |
#hypervisor_type ⇒ Object
Hypervisor Type
31 32 33 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 31 def hypervisor_type @hypervisor_type end |
#image_type ⇒ Object
Image Type
34 35 36 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 34 def image_type @image_type end |
#operating_system ⇒ Object
Operating System
37 38 39 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 37 def @operating_system end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 40 def self.attribute_map { :'architecture' => :'architecture', :'container_format' => :'containerFormat', :'disk_format' => :'diskFormat', :'endianness' => :'endianness', :'hypervisor_type' => :'hypervisorType', :'image_type' => :'imageType', :'operating_system' => :'operatingSystem' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 177 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
82 83 84 85 86 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 82 def self.openapi_all_of [ :'ImageSpecifications' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 63 def self.openapi_types { :'architecture' => :'String', :'container_format' => :'String', :'disk_format' => :'String', :'endianness' => :'String', :'hypervisor_type' => :'String', :'image_type' => :'String', :'operating_system' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && architecture == o.architecture && container_format == o.container_format && disk_format == o.disk_format && endianness == o.endianness && hypervisor_type == o.hypervisor_type && image_type == o.image_type && == o. end |
#eql?(o) ⇒ Boolean
164 165 166 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 164 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 170 def hash [architecture, container_format, disk_format, endianness, hypervisor_type, image_type, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 |
# File 'lib/ibm_cloud_power/models/image_specifications.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |