Class: IbmCloudPower::JobAction
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::JobAction
- Defined in:
- lib/ibm_cloud_power/models/job_action.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#end_time ⇒ Object
action ending timestamp.
-
#name ⇒ Object
action name.
-
#start_time ⇒ Object
action starting timestamp.
-
#status ⇒ Object
status of the action.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobAction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ JobAction
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::JobAction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::JobAction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#end_time ⇒ Object
action ending timestamp
19 20 21 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 19 def end_time @end_time end |
#name ⇒ Object
action name
22 23 24 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 22 def name @name end |
#start_time ⇒ Object
action starting timestamp
25 26 27 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 25 def start_time @start_time end |
#status ⇒ Object
status of the action
28 29 30 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 28 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 53 def self.attribute_map { :'end_time' => :'endTime', :'name' => :'name', :'start_time' => :'startTime', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 174 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 73 def self.openapi_types { :'end_time' => :'Time', :'name' => :'String', :'start_time' => :'Time', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && end_time == o.end_time && name == o.name && start_time == o.start_time && status == o.status end |
#eql?(o) ⇒ Boolean
161 162 163 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 161 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 167 def hash [end_time, name, start_time, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 135 136 |
# File 'lib/ibm_cloud_power/models/job_action.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["pending", "running", "completed", "failed", "unknown"]) return false unless status_validator.valid?(@status) true end |