Class: IbmCloudPower::JobStatus

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/job_status.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ JobStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/ibm_cloud_power/models/job_status.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::JobStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::JobStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  else
    self.progress = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end
end

Instance Attribute Details

#messageObject

message detailing current state



19
20
21
# File 'lib/ibm_cloud_power/models/job_status.rb', line 19

def message
  @message
end

#progressObject

progress of a job



22
23
24
# File 'lib/ibm_cloud_power/models/job_status.rb', line 22

def progress
  @progress
end

#stateObject

state of a job



25
26
27
# File 'lib/ibm_cloud_power/models/job_status.rb', line 25

def state
  @state
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/ibm_cloud_power/models/job_status.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/ibm_cloud_power/models/job_status.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/ibm_cloud_power/models/job_status.rb', line 28

def self.attribute_map
  {
    :'message' => :'message',
    :'progress' => :'progress',
    :'state' => :'state'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/ibm_cloud_power/models/job_status.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



62
63
64
65
66
# File 'lib/ibm_cloud_power/models/job_status.rb', line 62

def self.openapi_all_of
  [
  :'Status'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/ibm_cloud_power/models/job_status.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/ibm_cloud_power/models/job_status.rb', line 47

def self.openapi_types
  {
    :'message' => :'String',
    :'progress' => :'String',
    :'state' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



148
149
150
151
152
153
154
# File 'lib/ibm_cloud_power/models/job_status.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      message == o.message &&
      progress == o.progress &&
      state == o.state
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/ibm_cloud_power/models/job_status.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/ibm_cloud_power/models/job_status.rb', line 164

def hash
  [message, progress, state].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/ibm_cloud_power/models/job_status.rb', line 103

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @progress.nil?
    invalid_properties.push('invalid value for "progress", progress cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/ibm_cloud_power/models/job_status.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
123
124
# File 'lib/ibm_cloud_power/models/job_status.rb', line 119

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @progress.nil?
  return false if @state.nil?
  true
end