Class: IbmCloudPower::MultiVolumesCreate

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/multi_volumes_create.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MultiVolumesCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::MultiVolumesCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::MultiVolumesCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'affinity_pvm_instance')
    self.affinity_pvm_instance = attributes[:'affinity_pvm_instance']
  end

  if attributes.key?(:'affinity_policy')
    self.affinity_policy = attributes[:'affinity_policy']
  end

  if attributes.key?(:'affinity_volume')
    self.affinity_volume = attributes[:'affinity_volume']
  end

  if attributes.key?(:'anti_affinity_pvm_instances')
    if (value = attributes[:'anti_affinity_pvm_instances']).is_a?(Array)
      self.anti_affinity_pvm_instances = value
    end
  end

  if attributes.key?(:'anti_affinity_volumes')
    if (value = attributes[:'anti_affinity_volumes']).is_a?(Array)
      self.anti_affinity_volumes = value
    end
  end

  if attributes.key?(:'count')
    self.count = attributes[:'count']
  end

  if attributes.key?(:'disk_type')
    self.disk_type = attributes[:'disk_type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'replication_enabled')
    self.replication_enabled = attributes[:'replication_enabled']
  end

  if attributes.key?(:'shareable')
    self.shareable = attributes[:'shareable']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = nil
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end

  if attributes.key?(:'volume_pool')
    self.volume_pool = attributes[:'volume_pool']
  end
end

Instance Attribute Details

#affinity_policyObject

Affinity policy for data volume being created; ignored if volumePool provided; for policy 'affinity' requires one of affinityPVMInstance or affinityVolume to be specified; for policy 'anti-affinity' requires one of antiAffinityPVMInstances or antiAffinityVolumes to be specified



22
23
24
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 22

def affinity_policy
  @affinity_policy
end

#affinity_pvm_instanceObject

PVM Instance (ID or Name)to base volume affinity policy against; required if requesting affinity and affinityVolume is not provided



19
20
21
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 19

def affinity_pvm_instance
  @affinity_pvm_instance
end

#affinity_volumeObject

Volume (ID or Name) to base volume affinity policy against; required if requesting affinity and affinityPVMInstance is not provided



25
26
27
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 25

def affinity_volume
  @affinity_volume
end

#anti_affinity_pvm_instancesObject

List of pvmInstances to base volume anti-affinity policy against; required if requesting anti-affinity and antiAffinityVolumes is not provided



28
29
30
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 28

def anti_affinity_pvm_instances
  @anti_affinity_pvm_instances
end

#anti_affinity_volumesObject

List of volumes to base volume anti-affinity policy against; required if requesting anti-affinity and antiAffinityPVMInstances is not provided



31
32
33
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 31

def anti_affinity_volumes
  @anti_affinity_volumes
end

#countObject

Number of volumes to create



34
35
36
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 34

def count
  @count
end

#disk_typeObject

Type of Disk; if diskType is not provided the disk type will default to 'tier3'.



37
38
39
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 37

def disk_type
  @disk_type
end

#nameObject

Base name of the volume(s)



40
41
42
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 40

def name
  @name
end

#replication_enabledObject

Indicates if the volume should be replication enabled or not



43
44
45
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 43

def replication_enabled
  @replication_enabled
end

#shareableObject

Indicates if the volume is shareable between VMs



46
47
48
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 46

def shareable
  @shareable
end

#sizeObject

Volume Size (GiB)



49
50
51
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 49

def size
  @size
end

#user_tagsObject

List of user tags



52
53
54
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 52

def user_tags
  @user_tags
end

#volume_poolObject

Volume pool where the volume will be created; if provided then affinityPolicy value will be ignored



55
56
57
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 55

def volume_pool
  @volume_pool
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



99
100
101
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 99

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 104

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 80

def self.attribute_map
  {
    :'affinity_pvm_instance' => :'affinityPVMInstance',
    :'affinity_policy' => :'affinityPolicy',
    :'affinity_volume' => :'affinityVolume',
    :'anti_affinity_pvm_instances' => :'antiAffinityPVMInstances',
    :'anti_affinity_volumes' => :'antiAffinityVolumes',
    :'count' => :'count',
    :'disk_type' => :'diskType',
    :'name' => :'name',
    :'replication_enabled' => :'replicationEnabled',
    :'shareable' => :'shareable',
    :'size' => :'size',
    :'user_tags' => :'userTags',
    :'volume_pool' => :'volumePool'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 323

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 128

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 109

def self.openapi_types
  {
    :'affinity_pvm_instance' => :'String',
    :'affinity_policy' => :'String',
    :'affinity_volume' => :'String',
    :'anti_affinity_pvm_instances' => :'Array<String>',
    :'anti_affinity_volumes' => :'Array<String>',
    :'count' => :'Integer',
    :'disk_type' => :'String',
    :'name' => :'String',
    :'replication_enabled' => :'Boolean',
    :'shareable' => :'Boolean',
    :'size' => :'Integer',
    :'user_tags' => :'Array<String>',
    :'volume_pool' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      affinity_pvm_instance == o.affinity_pvm_instance &&
      affinity_policy == o.affinity_policy &&
      affinity_volume == o.affinity_volume &&
      anti_affinity_pvm_instances == o.anti_affinity_pvm_instances &&
      anti_affinity_volumes == o.anti_affinity_volumes &&
      count == o.count &&
      disk_type == o.disk_type &&
      name == o.name &&
      replication_enabled == o.replication_enabled &&
      shareable == o.shareable &&
      size == o.size &&
      user_tags == o.user_tags &&
      volume_pool == o.volume_pool
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 310

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



316
317
318
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 316

def hash
  [affinity_pvm_instance, affinity_policy, affinity_volume, anti_affinity_pvm_instances, anti_affinity_volumes, count, disk_type, name, replication_enabled, shareable, size, user_tags, volume_pool].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 214

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  if !@user_tags.nil? && @user_tags.length > 100
    invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 345

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



234
235
236
237
238
239
240
241
242
# File 'lib/ibm_cloud_power/models/multi_volumes_create.rb', line 234

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  affinity_policy_validator = EnumAttributeValidator.new('String', ["affinity", "anti-affinity"])
  return false unless affinity_policy_validator.valid?(@affinity_policy)
  return false if @name.nil?
  return false if @size.nil?
  return false if !@user_tags.nil? && @user_tags.length > 100
  true
end