Class: IbmCloudPower::NetworkCreate

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/network_create.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetworkCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/ibm_cloud_power/models/network_create.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_config')
    self.access_config = attributes[:'access_config']
  end

  if attributes.key?(:'advertise')
    self.advertise = attributes[:'advertise']
  else
    self.advertise = 'enable'
  end

  if attributes.key?(:'arp_broadcast')
    self.arp_broadcast = attributes[:'arp_broadcast']
  else
    self.arp_broadcast = 'disable'
  end

  if attributes.key?(:'cidr')
    self.cidr = attributes[:'cidr']
  end

  if attributes.key?(:'dns_servers')
    if (value = attributes[:'dns_servers']).is_a?(Array)
      self.dns_servers = value
    end
  end

  if attributes.key?(:'gateway')
    self.gateway = attributes[:'gateway']
  end

  if attributes.key?(:'ip_address_ranges')
    if (value = attributes[:'ip_address_ranges']).is_a?(Array)
      self.ip_address_ranges = value
    end
  end

  if attributes.key?(:'jumbo')
    self.jumbo = attributes[:'jumbo']
  end

  if attributes.key?(:'mtu')
    self.mtu = attributes[:'mtu']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'vlan'
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end
end

Instance Attribute Details

#access_configObject

Returns the value of attribute access_config.



18
19
20
# File 'lib/ibm_cloud_power/models/network_create.rb', line 18

def access_config
  @access_config
end

Indicates if the network is advertised externally of the workspace to PER and\or peer networks



21
22
23
# File 'lib/ibm_cloud_power/models/network_create.rb', line 21

def advertise
  @advertise
end

#arp_broadcastObject

Indicates if ARP broadcast is enabled



24
25
26
# File 'lib/ibm_cloud_power/models/network_create.rb', line 24

def arp_broadcast
  @arp_broadcast
end

#cidrObject

Network in CIDR notation (192.168.0.0/24)



27
28
29
# File 'lib/ibm_cloud_power/models/network_create.rb', line 27

def cidr
  @cidr
end

#dns_serversObject

DNS Servers. If not specified, default is 127.0.0.1 for 'vlan' (private network) and 9.9.9.9 for 'pub-vlan' (public network)



30
31
32
# File 'lib/ibm_cloud_power/models/network_create.rb', line 30

def dns_servers
  @dns_servers
end

#gatewayObject

Gateway IP Address



33
34
35
# File 'lib/ibm_cloud_power/models/network_create.rb', line 33

def gateway
  @gateway
end

#ip_address_rangesObject

IP Address Ranges



36
37
38
# File 'lib/ibm_cloud_power/models/network_create.rb', line 36

def ip_address_ranges
  @ip_address_ranges
end

#jumboObject

(deprecated - replaced by mtu) Enable MTU Jumbo Network (for multi-zone locations only)



39
40
41
# File 'lib/ibm_cloud_power/models/network_create.rb', line 39

def jumbo
  @jumbo
end

#mtuObject

Maximum transmission unit



42
43
44
# File 'lib/ibm_cloud_power/models/network_create.rb', line 42

def mtu
  @mtu
end

#nameObject

Network Name



45
46
47
# File 'lib/ibm_cloud_power/models/network_create.rb', line 45

def name
  @name
end

#typeObject

Type of Network - 'vlan' (private network), 'pub-vlan' (public network)



48
49
50
# File 'lib/ibm_cloud_power/models/network_create.rb', line 48

def type
  @type
end

#user_tagsObject

List of user tags



51
52
53
# File 'lib/ibm_cloud_power/models/network_create.rb', line 51

def user_tags
  @user_tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



94
95
96
# File 'lib/ibm_cloud_power/models/network_create.rb', line 94

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/ibm_cloud_power/models/network_create.rb', line 99

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/ibm_cloud_power/models/network_create.rb', line 76

def self.attribute_map
  {
    :'access_config' => :'accessConfig',
    :'advertise' => :'advertise',
    :'arp_broadcast' => :'arpBroadcast',
    :'cidr' => :'cidr',
    :'dns_servers' => :'dnsServers',
    :'gateway' => :'gateway',
    :'ip_address_ranges' => :'ipAddressRanges',
    :'jumbo' => :'jumbo',
    :'mtu' => :'mtu',
    :'name' => :'name',
    :'type' => :'type',
    :'user_tags' => :'userTags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/ibm_cloud_power/models/network_create.rb', line 371

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
# File 'lib/ibm_cloud_power/models/network_create.rb', line 122

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/ibm_cloud_power/models/network_create.rb', line 104

def self.openapi_types
  {
    :'access_config' => :'AccessConfig',
    :'advertise' => :'String',
    :'arp_broadcast' => :'String',
    :'cidr' => :'String',
    :'dns_servers' => :'Array<String>',
    :'gateway' => :'String',
    :'ip_address_ranges' => :'Array<IPAddressRange>',
    :'jumbo' => :'Boolean',
    :'mtu' => :'Integer',
    :'name' => :'String',
    :'type' => :'String',
    :'user_tags' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/ibm_cloud_power/models/network_create.rb', line 339

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_config == o.access_config &&
      advertise == o.advertise &&
      arp_broadcast == o.arp_broadcast &&
      cidr == o.cidr &&
      dns_servers == o.dns_servers &&
      gateway == o.gateway &&
      ip_address_ranges == o.ip_address_ranges &&
      jumbo == o.jumbo &&
      mtu == o.mtu &&
      name == o.name &&
      type == o.type &&
      user_tags == o.user_tags
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


358
359
360
# File 'lib/ibm_cloud_power/models/network_create.rb', line 358

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



364
365
366
# File 'lib/ibm_cloud_power/models/network_create.rb', line 364

def hash
  [access_config, advertise, arp_broadcast, cidr, dns_servers, gateway, ip_address_ranges, jumbo, mtu, name, type, user_tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/ibm_cloud_power/models/network_create.rb', line 206

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@mtu.nil? && @mtu > 9000
    invalid_properties.push('invalid value for "mtu", must be smaller than or equal to 9000.')
  end

  if !@mtu.nil? && @mtu < 1450
    invalid_properties.push('invalid value for "mtu", must be greater than or equal to 1450.')
  end

  if !@name.nil? && @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9\-_][a-zA-Z0-9\-_]*$/)
  if !@name.nil? && @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@user_tags.nil? && @user_tags.length > 100
    invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/ibm_cloud_power/models/network_create.rb', line 393

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/ibm_cloud_power/models/network_create.rb', line 239

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  advertise_validator = EnumAttributeValidator.new('String', ["enable", "disable"])
  return false unless advertise_validator.valid?(@advertise)
  arp_broadcast_validator = EnumAttributeValidator.new('String', ["enable", "disable"])
  return false unless arp_broadcast_validator.valid?(@arp_broadcast)
  return false if !@mtu.nil? && @mtu > 9000
  return false if !@mtu.nil? && @mtu < 1450
  return false if !@name.nil? && @name.to_s.length > 128
  return false if !@name.nil? && @name !~ Regexp.new(/^[a-zA-Z0-9\-_][a-zA-Z0-9\-_]*$/)
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["vlan", "pub-vlan"])
  return false unless type_validator.valid?(@type)
  return false if !@user_tags.nil? && @user_tags.length > 100
  true
end