Class: IbmCloudPower::NetworkSecurityGroup

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/network_security_group.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetworkSecurityGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkSecurityGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkSecurityGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  else
    self.crn = nil
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'members')
    if (value = attributes[:'members']).is_a?(Array)
      self.members = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end
end

Instance Attribute Details

#crnObject

The Network Security Group's crn



19
20
21
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 19

def crn
  @crn
end

#defaultObject

Indicates if the Network Security Group is the default Network Security Group in the workspace



22
23
24
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 22

def default
  @default
end

#idObject

The ID of the Network Security Group



25
26
27
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 25

def id
  @id
end

#membersObject

The list of IPv4 addresses and\or Network Interfaces in the Network Security Group



28
29
30
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 28

def members
  @members
end

#nameObject

The name of the Network Security Group



31
32
33
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 31

def name
  @name
end

#rulesObject

The list of rules in the Network Security Group



34
35
36
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 34

def rules
  @rules
end

#user_tagsObject

List of user tags



37
38
39
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 37

def user_tags
  @user_tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 40

def self.attribute_map
  {
    :'crn' => :'crn',
    :'default' => :'default',
    :'id' => :'id',
    :'members' => :'members',
    :'name' => :'name',
    :'rules' => :'rules',
    :'user_tags' => :'userTags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 246

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 63

def self.openapi_types
  {
    :'crn' => :'String',
    :'default' => :'Boolean',
    :'id' => :'String',
    :'members' => :'Array<NetworkSecurityGroupMember>',
    :'name' => :'String',
    :'rules' => :'Array<NetworkSecurityGroupRule>',
    :'user_tags' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
226
227
228
229
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      crn == o.crn &&
      default == o.default &&
      id == o.id &&
      members == o.members &&
      name == o.name &&
      rules == o.rules &&
      user_tags == o.user_tags
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 233

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



239
240
241
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 239

def hash
  [crn, default, id, members, name, rules, user_tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @crn.nil?
    invalid_properties.push('invalid value for "crn", crn cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if !@user_tags.nil? && @user_tags.length > 100
    invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
170
171
# File 'lib/ibm_cloud_power/models/network_security_group.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @crn.nil?
  return false if @id.nil?
  return false if @name.nil?
  return false if !@user_tags.nil? && @user_tags.length > 100
  true
end