Class: IbmCloudPower::NetworkSecurityGroupRule

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_power/models/network_security_group_rule.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetworkSecurityGroupRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkSecurityGroupRule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkSecurityGroupRule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = nil
  end

  if attributes.key?(:'destination_port')
    self.destination_port = attributes[:'destination_port']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'protocol')
    self.protocol = attributes[:'protocol']
  else
    self.protocol = nil
  end

  if attributes.key?(:'remote')
    self.remote = attributes[:'remote']
  else
    self.remote = nil
  end

  if attributes.key?(:'source_port')
    self.source_port = attributes[:'source_port']
  end
end

Instance Attribute Details

#actionObject

The action to take if the rule matches network traffic



19
20
21
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 19

def action
  @action
end

#destination_portObject

Returns the value of attribute destination_port.



21
22
23
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 21

def destination_port
  @destination_port
end

#idObject

The ID of the rule in a Network Security Group



24
25
26
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 24

def id
  @id
end

#protocolObject

Returns the value of attribute protocol.



26
27
28
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 26

def protocol
  @protocol
end

#remoteObject

Returns the value of attribute remote.



28
29
30
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 28

def remote
  @remote
end

#source_portObject

Returns the value of attribute source_port.



30
31
32
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 30

def source_port
  @source_port
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 55

def self.attribute_map
  {
    :'action' => :'action',
    :'destination_port' => :'destinationPort',
    :'id' => :'id',
    :'protocol' => :'protocol',
    :'remote' => :'remote',
    :'source_port' => :'sourcePort'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 248

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 77

def self.openapi_types
  {
    :'action' => :'String',
    :'destination_port' => :'NetworkSecurityGroupRulePort',
    :'id' => :'String',
    :'protocol' => :'NetworkSecurityGroupRuleProtocol',
    :'remote' => :'NetworkSecurityGroupRuleRemote',
    :'source_port' => :'NetworkSecurityGroupRulePort'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
231
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      destination_port == o.destination_port &&
      id == o.id &&
      protocol == o.protocol &&
      remote == o.remote &&
      source_port == o.source_port
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


235
236
237
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 235

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



241
242
243
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 241

def hash
  [action, destination_port, id, protocol, remote, source_port].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 145

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @protocol.nil?
    invalid_properties.push('invalid value for "protocol", protocol cannot be nil.')
  end

  if @remote.nil?
    invalid_properties.push('invalid value for "remote", remote cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 270

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
174
175
176
177
178
# File 'lib/ibm_cloud_power/models/network_security_group_rule.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @action.nil?
  action_validator = EnumAttributeValidator.new('String', ["allow", "deny"])
  return false unless action_validator.valid?(@action)
  return false if @id.nil?
  return false if @protocol.nil?
  return false if @remote.nil?
  true
end