Class: IbmCloudPower::NetworkSecurityGroupRulePort
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::NetworkSecurityGroupRulePort
- Defined in:
- lib/ibm_cloud_power/models/network_security_group_rule_port.rb
Instance Attribute Summary collapse
-
#maximum ⇒ Object
The end of the port range, if applicable.
-
#minimum ⇒ Object
The start of the port range, if applicable.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkSecurityGroupRulePort
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NetworkSecurityGroupRulePort
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkSecurityGroupRulePort` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkSecurityGroupRulePort`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'maximum') self.maximum = attributes[:'maximum'] end if attributes.key?(:'minimum') self.minimum = attributes[:'minimum'] end end |
Instance Attribute Details
#maximum ⇒ Object
The end of the port range, if applicable. If the value is not present then the default value of 65535 will be the maximum port number.
19 20 21 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 19 def maximum @maximum end |
#minimum ⇒ Object
The start of the port range, if applicable. If the value is not present then the default value of 1 will be the minimum port number.
22 23 24 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 22 def minimum @minimum end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 25 def self.attribute_map { :'maximum' => :'maximum', :'minimum' => :'minimum' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 158 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 43 def self.openapi_types { :'maximum' => :'Integer', :'minimum' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 136 def ==(o) return true if self.equal?(o) self.class == o.class && maximum == o.maximum && minimum == o.minimum end |
#eql?(o) ⇒ Boolean
145 146 147 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 145 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 151 def hash [maximum, minimum].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 83 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@maximum.nil? && @maximum > 65535 invalid_properties.push('invalid value for "maximum", must be smaller than or equal to 65535.') end if !@minimum.nil? && @minimum < 1 invalid_properties.push('invalid value for "minimum", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
99 100 101 102 103 104 |
# File 'lib/ibm_cloud_power/models/network_security_group_rule_port.rb', line 99 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@maximum.nil? && @maximum > 65535 return false if !@minimum.nil? && @minimum < 1 true end |