Class: IbmCloudPower::NetworkSecurityGroupRuleProtocol

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetworkSecurityGroupRuleProtocol

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkSecurityGroupRuleProtocol` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkSecurityGroupRuleProtocol`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'icmp_type')
    self.icmp_type = attributes[:'icmp_type']
  end

  if attributes.key?(:'tcp_flags')
    if (value = attributes[:'tcp_flags']).is_a?(Array)
      self.tcp_flags = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#icmp_typeObject

If icmp type, a ICMP packet type affected by ICMP rules and if not present then all types are matched



19
20
21
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 19

def icmp_type
  @icmp_type
end

#tcp_flagsObject

If tcp type, the list of TCP flags and if not present then all flags are matched



22
23
24
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 22

def tcp_flags
  @tcp_flags
end

#typeObject

The protocol of the network traffic



25
26
27
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 25

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 50

def self.attribute_map
  {
    :'icmp_type' => :'icmpType',
    :'tcp_flags' => :'tcpFlags',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 178

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 69

def self.openapi_types
  {
    :'icmp_type' => :'String',
    :'tcp_flags' => :'Array<NetworkSecurityGroupRuleProtocolTcpFlag>',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      icmp_type == o.icmp_type &&
      tcp_flags == o.tcp_flags &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 171

def hash
  [icmp_type, tcp_flags, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
128
129
130
131
# File 'lib/ibm_cloud_power/models/network_security_group_rule_protocol.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  icmp_type_validator = EnumAttributeValidator.new('String', ["all", "echo", "echo-reply", "source-quench", "time-exceeded", "destination-unreach"])
  return false unless icmp_type_validator.valid?(@icmp_type)
  type_validator = EnumAttributeValidator.new('String', ["icmp", "tcp", "udp", "all"])
  return false unless type_validator.valid?(@type)
  true
end