Class: IbmCloudPower::NetworkUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/network_update.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetworkUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/ibm_cloud_power/models/network_update.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'advertise')
    self.advertise = attributes[:'advertise']
  end

  if attributes.key?(:'arp_broadcast')
    self.arp_broadcast = attributes[:'arp_broadcast']
  end

  if attributes.key?(:'dns_servers')
    if (value = attributes[:'dns_servers']).is_a?(Array)
      self.dns_servers = value
    end
  end

  if attributes.key?(:'gateway')
    self.gateway = attributes[:'gateway']
  end

  if attributes.key?(:'ip_address_ranges')
    if (value = attributes[:'ip_address_ranges']).is_a?(Array)
      self.ip_address_ranges = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end
end

Instance Attribute Details

Indicates if the network is advertised externally of the workspace to PER and\or peer networks



19
20
21
# File 'lib/ibm_cloud_power/models/network_update.rb', line 19

def advertise
  @advertise
end

#arp_broadcastObject

Indicates if the ARP broadcast is enabled



22
23
24
# File 'lib/ibm_cloud_power/models/network_update.rb', line 22

def arp_broadcast
  @arp_broadcast
end

#dns_serversObject

Replaces the current DNS Servers



25
26
27
# File 'lib/ibm_cloud_power/models/network_update.rb', line 25

def dns_servers
  @dns_servers
end

#gatewayObject

Replaces the current Gateway IP Address



28
29
30
# File 'lib/ibm_cloud_power/models/network_update.rb', line 28

def gateway
  @gateway
end

#ip_address_rangesObject

Replaces the current IP Address Ranges



31
32
33
# File 'lib/ibm_cloud_power/models/network_update.rb', line 31

def ip_address_ranges
  @ip_address_ranges
end

#nameObject

Replaces the current Network Name



34
35
36
# File 'lib/ibm_cloud_power/models/network_update.rb', line 34

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/ibm_cloud_power/models/network_update.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/ibm_cloud_power/models/network_update.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/ibm_cloud_power/models/network_update.rb', line 59

def self.attribute_map
  {
    :'advertise' => :'advertise',
    :'arp_broadcast' => :'arpBroadcast',
    :'dns_servers' => :'dnsServers',
    :'gateway' => :'gateway',
    :'ip_address_ranges' => :'ipAddressRanges',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/ibm_cloud_power/models/network_update.rb', line 210

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/ibm_cloud_power/models/network_update.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/ibm_cloud_power/models/network_update.rb', line 81

def self.openapi_types
  {
    :'advertise' => :'String',
    :'arp_broadcast' => :'String',
    :'dns_servers' => :'Array<String>',
    :'gateway' => :'String',
    :'ip_address_ranges' => :'Array<IPAddressRange>',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
192
193
# File 'lib/ibm_cloud_power/models/network_update.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      advertise == o.advertise &&
      arp_broadcast == o.arp_broadcast &&
      dns_servers == o.dns_servers &&
      gateway == o.gateway &&
      ip_address_ranges == o.ip_address_ranges &&
      name == o.name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/ibm_cloud_power/models/network_update.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/ibm_cloud_power/models/network_update.rb', line 203

def hash
  [advertise, arp_broadcast, dns_servers, gateway, ip_address_ranges, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
149
# File 'lib/ibm_cloud_power/models/network_update.rb', line 145

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/ibm_cloud_power/models/network_update.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
160
# File 'lib/ibm_cloud_power/models/network_update.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  advertise_validator = EnumAttributeValidator.new('String', ["enable", "disable"])
  return false unless advertise_validator.valid?(@advertise)
  arp_broadcast_validator = EnumAttributeValidator.new('String', ["enable", "disable"])
  return false unless arp_broadcast_validator.valid?(@arp_broadcast)
  true
end