Class: IbmCloudPower::PCloudPodCapacityApi
- Inherits:
-
Object
- Object
- IbmCloudPower::PCloudPodCapacityApi
- Defined in:
- lib/ibm_cloud_power/api/p_cloud_pod_capacity_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ PCloudPodCapacityApi
constructor
A new instance of PCloudPodCapacityApi.
-
#pcloud_podcapacity_get(cloud_instance_id, opts = {}) ⇒ PodCapacity
List of available resources within a particular Pod Applicable to satellite locations only.
-
#pcloud_podcapacity_get_with_http_info(cloud_instance_id, opts = {}) ⇒ Array<(PodCapacity, Integer, Hash)>
List of available resources within a particular Pod Applicable to satellite locations only.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PCloudPodCapacityApi
Returns a new instance of PCloudPodCapacityApi.
19 20 21 |
# File 'lib/ibm_cloud_power/api/p_cloud_pod_capacity_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ibm_cloud_power/api/p_cloud_pod_capacity_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#pcloud_podcapacity_get(cloud_instance_id, opts = {}) ⇒ PodCapacity
List of available resources within a particular Pod Applicable to satellite locations only.
27 28 29 30 |
# File 'lib/ibm_cloud_power/api/p_cloud_pod_capacity_api.rb', line 27 def pcloud_podcapacity_get(cloud_instance_id, opts = {}) data, _status_code, _headers = pcloud_podcapacity_get_with_http_info(cloud_instance_id, opts) data end |
#pcloud_podcapacity_get_with_http_info(cloud_instance_id, opts = {}) ⇒ Array<(PodCapacity, Integer, Hash)>
List of available resources within a particular Pod Applicable to satellite locations only.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ibm_cloud_power/api/p_cloud_pod_capacity_api.rb', line 37 def pcloud_podcapacity_get_with_http_info(cloud_instance_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudPodCapacityApi.pcloud_podcapacity_get ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudPodCapacityApi.pcloud_podcapacity_get" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/pod-capacity'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PodCapacity' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudPodCapacityApi.pcloud_podcapacity_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudPodCapacityApi#pcloud_podcapacity_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |