Class: IbmCloudPower::PVMInstanceCapture
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::PVMInstanceCapture
- Defined in:
- lib/ibm_cloud_power/models/pvm_instance_capture.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#capture_destination ⇒ Object
Destination for the deployable image.
-
#capture_name ⇒ Object
Name of the deployable image created for the captured PVMInstance.
-
#capture_volume_ids ⇒ Object
List of Data volume IDs to include in the captured PVMInstance.
-
#cloud_storage_access_key ⇒ Object
Cloud Storage Access key.
-
#cloud_storage_image_path ⇒ Object
Cloud Storage Image Path (bucket-name [/folder/../..]).
-
#cloud_storage_region ⇒ Object
Cloud Storage Region.
-
#cloud_storage_secret_key ⇒ Object
Cloud Storage Secret key.
-
#user_tags ⇒ Object
List of user tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PVMInstanceCapture
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PVMInstanceCapture
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::PVMInstanceCapture` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::PVMInstanceCapture`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'capture_destination') self.capture_destination = attributes[:'capture_destination'] else self.capture_destination = 'cloud-storage' end if attributes.key?(:'capture_name') self.capture_name = attributes[:'capture_name'] else self.capture_name = nil end if attributes.key?(:'capture_volume_ids') if (value = attributes[:'capture_volume_ids']).is_a?(Array) self.capture_volume_ids = value end end if attributes.key?(:'cloud_storage_access_key') self.cloud_storage_access_key = attributes[:'cloud_storage_access_key'] end if attributes.key?(:'cloud_storage_image_path') self.cloud_storage_image_path = attributes[:'cloud_storage_image_path'] end if attributes.key?(:'cloud_storage_region') self.cloud_storage_region = attributes[:'cloud_storage_region'] end if attributes.key?(:'cloud_storage_secret_key') self.cloud_storage_secret_key = attributes[:'cloud_storage_secret_key'] end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#capture_destination ⇒ Object
Destination for the deployable image
19 20 21 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 19 def capture_destination @capture_destination end |
#capture_name ⇒ Object
Name of the deployable image created for the captured PVMInstance
22 23 24 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 22 def capture_name @capture_name end |
#capture_volume_ids ⇒ Object
List of Data volume IDs to include in the captured PVMInstance
25 26 27 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 25 def capture_volume_ids @capture_volume_ids end |
#cloud_storage_access_key ⇒ Object
Cloud Storage Access key
28 29 30 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 28 def cloud_storage_access_key @cloud_storage_access_key end |
#cloud_storage_image_path ⇒ Object
Cloud Storage Image Path (bucket-name [/folder/../..])
31 32 33 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 31 def cloud_storage_image_path @cloud_storage_image_path end |
#cloud_storage_region ⇒ Object
Cloud Storage Region
34 35 36 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 34 def cloud_storage_region @cloud_storage_region end |
#cloud_storage_secret_key ⇒ Object
Cloud Storage Secret key
37 38 39 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 37 def cloud_storage_secret_key @cloud_storage_secret_key end |
#user_tags ⇒ Object
List of user tags
40 41 42 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 40 def @user_tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 65 def self.attribute_map { :'capture_destination' => :'captureDestination', :'capture_name' => :'captureName', :'capture_volume_ids' => :'captureVolumeIDs', :'cloud_storage_access_key' => :'cloudStorageAccessKey', :'cloud_storage_image_path' => :'cloudStorageImagePath', :'cloud_storage_region' => :'cloudStorageRegion', :'cloud_storage_secret_key' => :'cloudStorageSecretKey', :'user_tags' => :'userTags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 89 def self.openapi_types { :'capture_destination' => :'String', :'capture_name' => :'String', :'capture_volume_ids' => :'Array<String>', :'cloud_storage_access_key' => :'String', :'cloud_storage_image_path' => :'String', :'cloud_storage_region' => :'String', :'cloud_storage_secret_key' => :'String', :'user_tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 233 def ==(o) return true if self.equal?(o) self.class == o.class && capture_destination == o.capture_destination && capture_name == o.capture_name && capture_volume_ids == o.capture_volume_ids && cloud_storage_access_key == o.cloud_storage_access_key && cloud_storage_image_path == o.cloud_storage_image_path && cloud_storage_region == o.cloud_storage_region && cloud_storage_secret_key == o.cloud_storage_secret_key && == o. end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 254 def hash [capture_destination, capture_name, capture_volume_ids, cloud_storage_access_key, cloud_storage_image_path, cloud_storage_region, cloud_storage_secret_key, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @capture_destination.nil? invalid_properties.push('invalid value for "capture_destination", capture_destination cannot be nil.') end if @capture_name.nil? invalid_properties.push('invalid value for "capture_name", capture_name cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 193 194 195 |
# File 'lib/ibm_cloud_power/models/pvm_instance_capture.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @capture_destination.nil? capture_destination_validator = EnumAttributeValidator.new('String', ["image-catalog", "cloud-storage", "both"]) return false unless capture_destination_validator.valid?(@capture_destination) return false if @capture_name.nil? return false if !@user_tags.nil? && @user_tags.length > 100 true end |