Class: IbmCloudPower::PVMInstanceNetwork

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/pvm_instance_network.rb

Overview

A map containing information about a network address

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PVMInstanceNetwork

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::PVMInstanceNetwork` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::PVMInstanceNetwork`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'external_ip')
    self.external_ip = attributes[:'external_ip']
  end

  if attributes.key?(:'href')
    self.href = attributes[:'href']
  end

  if attributes.key?(:'ip')
    self.ip = attributes[:'ip']
  end

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'mac_address')
    self.mac_address = attributes[:'mac_address']
  end

  if attributes.key?(:'network_id')
    self.network_id = attributes[:'network_id']
  end

  if attributes.key?(:'network_interface_id')
    self.network_interface_id = attributes[:'network_interface_id']
  end

  if attributes.key?(:'network_name')
    self.network_name = attributes[:'network_name']
  end

  if attributes.key?(:'network_security_group_ids')
    if (value = attributes[:'network_security_group_ids']).is_a?(Array)
      self.network_security_group_ids = value
    end
  end

  if attributes.key?(:'network_security_groups_href')
    if (value = attributes[:'network_security_groups_href']).is_a?(Array)
      self.network_security_groups_href = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#external_ipObject

The external ip address (for pub-vlan networks)



20
21
22
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 20

def external_ip
  @external_ip
end

#hrefObject

Link to PVM Instance Network



23
24
25
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 23

def href
  @href
end

#ipObject

(deprecated - replaced by ipAddress)



26
27
28
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 26

def ip
  @ip
end

#ip_addressObject

The ip address of this network interface



29
30
31
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 29

def ip_address
  @ip_address
end

#mac_addressObject

The mac address of the network interface



32
33
34
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 32

def mac_address
  @mac_address
end

#network_idObject

ID of the network



35
36
37
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 35

def network_id
  @network_id
end

#network_interface_idObject

ID of the network interface



38
39
40
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 38

def network_interface_id
  @network_interface_id
end

#network_nameObject

The name of the network the address is on



41
42
43
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 41

def network_name
  @network_name
end

#network_security_group_idsObject

IDs of the network necurity groups that the network interface is a member of



44
45
46
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 44

def network_security_group_ids
  @network_security_group_ids
end

#network_security_groups_hrefObject

Links to the network security groups that the network interface is a member of



47
48
49
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 47

def network_security_groups_href
  @network_security_groups_href
end

#typeObject

The address type (fixed or dynamic)



50
51
52
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 50

def type
  @type
end

#versionObject

The version of the information provided



53
54
55
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 53

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 56

def self.attribute_map
  {
    :'external_ip' => :'externalIP',
    :'href' => :'href',
    :'ip' => :'ip',
    :'ip_address' => :'ipAddress',
    :'mac_address' => :'macAddress',
    :'network_id' => :'networkID',
    :'network_interface_id' => :'networkInterfaceID',
    :'network_name' => :'networkName',
    :'network_security_group_ids' => :'networkSecurityGroupIDs',
    :'network_security_groups_href' => :'networkSecurityGroupsHref',
    :'type' => :'type',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 225

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 84

def self.openapi_types
  {
    :'external_ip' => :'String',
    :'href' => :'String',
    :'ip' => :'String',
    :'ip_address' => :'String',
    :'mac_address' => :'String',
    :'network_id' => :'String',
    :'network_interface_id' => :'String',
    :'network_name' => :'String',
    :'network_security_group_ids' => :'Array<String>',
    :'network_security_groups_href' => :'Array<String>',
    :'type' => :'String',
    :'version' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      external_ip == o.external_ip &&
      href == o.href &&
      ip == o.ip &&
      ip_address == o.ip_address &&
      mac_address == o.mac_address &&
      network_id == o.network_id &&
      network_interface_id == o.network_interface_id &&
      network_name == o.network_name &&
      network_security_group_ids == o.network_security_group_ids &&
      network_security_groups_href == o.network_security_groups_href &&
      type == o.type &&
      version == o.version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 218

def hash
  [external_ip, href, ip, ip_address, mac_address, network_id, network_interface_id, network_name, network_security_group_ids, network_security_groups_href, type, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



178
179
180
181
182
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 178

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 247

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
# File 'lib/ibm_cloud_power/models/pvm_instance_network.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end