Class: IbmCloudPower::PVMInstanceV2NetworkPort

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb

Overview

PVM's Port information

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PVMInstanceV2NetworkPort

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::PVMInstanceV2NetworkPort` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::PVMInstanceV2NetworkPort`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'ip_protocol')
    self.ip_protocol = attributes[:'ip_protocol']
  end

  if attributes.key?(:'mac_address')
    self.mac_address = attributes[:'mac_address']
  end

  if attributes.key?(:'private_ip')
    self.private_ip = attributes[:'private_ip']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#idObject

Unique Port ID



20
21
22
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 20

def id
  @id
end

#ip_protocolObject

Dynamic Host Configuration Protocol IPv6



23
24
25
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 23

def ip_protocol
  @ip_protocol
end

#mac_addressObject

The mac address of the network interface



26
27
28
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 26

def mac_address
  @mac_address
end

#private_ipObject

The private ip address



29
30
31
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 29

def private_ip
  @private_ip
end

#typeObject

The type of ip allocation static



32
33
34
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 32

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 57

def self.attribute_map
  {
    :'id' => :'id',
    :'ip_protocol' => :'ipProtocol',
    :'mac_address' => :'macAddress',
    :'private_ip' => :'privateIP',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 78

def self.openapi_types
  {
    :'id' => :'String',
    :'ip_protocol' => :'String',
    :'mac_address' => :'String',
    :'private_ip' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
180
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      ip_protocol == o.ip_protocol &&
      mac_address == o.mac_address &&
      private_ip == o.private_ip &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 190

def hash
  [id, ip_protocol, mac_address, private_ip, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
148
# File 'lib/ibm_cloud_power/models/pvm_instance_v2_network_port.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  ip_protocol_validator = EnumAttributeValidator.new('String', ["IPv4", "IPv6"])
  return false unless ip_protocol_validator.valid?(@ip_protocol)
  type_validator = EnumAttributeValidator.new('String', ["dhcp", "static"])
  return false unless type_validator.valid?(@type)
  true
end