Class: IbmCloudPower::RemoteCopyRelationship

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/remote_copy_relationship.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RemoteCopyRelationship

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::RemoteCopyRelationship` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::RemoteCopyRelationship`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aux_changed_volume_name')
    self.aux_changed_volume_name = attributes[:'aux_changed_volume_name']
  end

  if attributes.key?(:'aux_volume_name')
    self.aux_volume_name = attributes[:'aux_volume_name']
  end

  if attributes.key?(:'consistency_group_name')
    self.consistency_group_name = attributes[:'consistency_group_name']
  end

  if attributes.key?(:'copy_type')
    self.copy_type = attributes[:'copy_type']
  end

  if attributes.key?(:'cycling_mode')
    self.cycling_mode = attributes[:'cycling_mode']
  end

  if attributes.key?(:'freeze_time')
    self.freeze_time = attributes[:'freeze_time']
  end

  if attributes.key?(:'master_changed_volume_name')
    self.master_changed_volume_name = attributes[:'master_changed_volume_name']
  end

  if attributes.key?(:'master_volume_name')
    self.master_volume_name = attributes[:'master_volume_name']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'primary_role')
    self.primary_role = attributes[:'primary_role']
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  end

  if attributes.key?(:'remote_copy_id')
    self.remote_copy_id = attributes[:'remote_copy_id']
  else
    self.remote_copy_id = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'sync')
    self.sync = attributes[:'sync']
  end
end

Instance Attribute Details

#aux_changed_volume_nameObject

Name of the volume that is acting as the auxiliary change volume for the relationship



19
20
21
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 19

def aux_changed_volume_name
  @aux_changed_volume_name
end

#aux_volume_nameObject

Auxiliary volume name at storage host level



22
23
24
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 22

def aux_volume_name
  @aux_volume_name
end

#consistency_group_nameObject

Consistency Group Name if volume is a part of volume group



25
26
27
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 25

def consistency_group_name
  @consistency_group_name
end

#copy_typeObject

Indicates the copy type.



28
29
30
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 28

def copy_type
  @copy_type
end

#cycling_modeObject

Indicates the type of cycling mode used.



31
32
33
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 31

def cycling_mode
  @cycling_mode
end

#freeze_timeObject

Freeze time of remote copy relationship



34
35
36
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 34

def freeze_time
  @freeze_time
end

#master_changed_volume_nameObject

Name of the volume that is acting as the master change volume for the relationship



37
38
39
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 37

def master_changed_volume_name
  @master_changed_volume_name
end

#master_volume_nameObject

Master volume name at storage host level



40
41
42
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 40

def master_volume_name
  @master_volume_name
end

#nameObject

Remote copy relationship name



43
44
45
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 43

def name
  @name
end

#primary_roleObject

Indicates whether master/aux volume is playing the primary role



46
47
48
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 46

def primary_role
  @primary_role
end

#progressObject

Indicates the relationship progress



49
50
51
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 49

def progress
  @progress
end

#remote_copy_idObject

Remote copy relationship ID



52
53
54
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 52

def remote_copy_id
  @remote_copy_id
end

#stateObject

Indicates the relationship state



55
56
57
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 55

def state
  @state
end

#syncObject

Indicates whether the relationship is synchronized



58
59
60
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 58

def sync
  @sync
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 61

def self.attribute_map
  {
    :'aux_changed_volume_name' => :'auxChangedVolumeName',
    :'aux_volume_name' => :'auxVolumeName',
    :'consistency_group_name' => :'consistencyGroupName',
    :'copy_type' => :'copyType',
    :'cycling_mode' => :'cyclingMode',
    :'freeze_time' => :'freezeTime',
    :'master_changed_volume_name' => :'masterChangedVolumeName',
    :'master_volume_name' => :'masterVolumeName',
    :'name' => :'name',
    :'primary_role' => :'primaryRole',
    :'progress' => :'progress',
    :'remote_copy_id' => :'remoteCopyID',
    :'state' => :'state',
    :'sync' => :'sync'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 91

def self.openapi_types
  {
    :'aux_changed_volume_name' => :'String',
    :'aux_volume_name' => :'String',
    :'consistency_group_name' => :'String',
    :'copy_type' => :'String',
    :'cycling_mode' => :'String',
    :'freeze_time' => :'Time',
    :'master_changed_volume_name' => :'String',
    :'master_volume_name' => :'String',
    :'name' => :'String',
    :'primary_role' => :'String',
    :'progress' => :'Integer',
    :'remote_copy_id' => :'String',
    :'state' => :'String',
    :'sync' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aux_changed_volume_name == o.aux_changed_volume_name &&
      aux_volume_name == o.aux_volume_name &&
      consistency_group_name == o.consistency_group_name &&
      copy_type == o.copy_type &&
      cycling_mode == o.cycling_mode &&
      freeze_time == o.freeze_time &&
      master_changed_volume_name == o.master_changed_volume_name &&
      master_volume_name == o.master_volume_name &&
      name == o.name &&
      primary_role == o.primary_role &&
      progress == o.progress &&
      remote_copy_id == o.remote_copy_id &&
      state == o.state &&
      sync == o.sync
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



267
268
269
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 267

def hash
  [aux_changed_volume_name, aux_volume_name, consistency_group_name, copy_type, cycling_mode, freeze_time, master_changed_volume_name, master_volume_name, name, primary_role, progress, remote_copy_id, state, sync].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @remote_copy_id.nil?
    invalid_properties.push('invalid value for "remote_copy_id", remote_copy_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
214
215
216
# File 'lib/ibm_cloud_power/models/remote_copy_relationship.rb', line 211

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @remote_copy_id.nil?
  true
end