Class: IbmCloudPower::Route
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::Route
- Defined in:
- lib/ibm_cloud_power/models/route.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
The route action.
-
#advertise ⇒ Object
Indicates if the route is advertised externally of the workspace to PER and\or peer networks.
-
#crn ⇒ Object
The route's crn.
-
#destination ⇒ Object
The route destination.
-
#destination_type ⇒ Object
The destination type.
-
#enabled ⇒ Object
Indicates if the route should be enabled in the fabric.
-
#id ⇒ Object
The unique route ID.
-
#name ⇒ Object
Name of the route.
-
#next_hop ⇒ Object
The next hop.
-
#next_hop_type ⇒ Object
The next hop type.
-
#state ⇒ Object
The state of the route.
-
#user_tags ⇒ Object
List of user tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Route
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Route
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/ibm_cloud_power/models/route.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Route` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Route`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'advertise') self.advertise = attributes[:'advertise'] else self.advertise = nil end if attributes.key?(:'crn') self.crn = attributes[:'crn'] else self.crn = nil end if attributes.key?(:'destination') self.destination = attributes[:'destination'] else self.destination = nil end if attributes.key?(:'destination_type') self.destination_type = attributes[:'destination_type'] else self.destination_type = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'next_hop') self.next_hop = attributes[:'next_hop'] else self.next_hop = nil end if attributes.key?(:'next_hop_type') self.next_hop_type = attributes[:'next_hop_type'] else self.next_hop_type = nil end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#action ⇒ Object
The route action
19 20 21 |
# File 'lib/ibm_cloud_power/models/route.rb', line 19 def action @action end |
#advertise ⇒ Object
Indicates if the route is advertised externally of the workspace to PER and\or peer networks
22 23 24 |
# File 'lib/ibm_cloud_power/models/route.rb', line 22 def advertise @advertise end |
#crn ⇒ Object
The route's crn
25 26 27 |
# File 'lib/ibm_cloud_power/models/route.rb', line 25 def crn @crn end |
#destination ⇒ Object
The route destination
28 29 30 |
# File 'lib/ibm_cloud_power/models/route.rb', line 28 def destination @destination end |
#destination_type ⇒ Object
The destination type
31 32 33 |
# File 'lib/ibm_cloud_power/models/route.rb', line 31 def destination_type @destination_type end |
#enabled ⇒ Object
Indicates if the route should be enabled in the fabric
34 35 36 |
# File 'lib/ibm_cloud_power/models/route.rb', line 34 def enabled @enabled end |
#id ⇒ Object
The unique route ID
37 38 39 |
# File 'lib/ibm_cloud_power/models/route.rb', line 37 def id @id end |
#name ⇒ Object
Name of the route
40 41 42 |
# File 'lib/ibm_cloud_power/models/route.rb', line 40 def name @name end |
#next_hop ⇒ Object
The next hop
43 44 45 |
# File 'lib/ibm_cloud_power/models/route.rb', line 43 def next_hop @next_hop end |
#next_hop_type ⇒ Object
The next hop type
46 47 48 |
# File 'lib/ibm_cloud_power/models/route.rb', line 46 def next_hop_type @next_hop_type end |
#state ⇒ Object
The state of the route
49 50 51 |
# File 'lib/ibm_cloud_power/models/route.rb', line 49 def state @state end |
#user_tags ⇒ Object
List of user tags
52 53 54 |
# File 'lib/ibm_cloud_power/models/route.rb', line 52 def @user_tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
95 96 97 |
# File 'lib/ibm_cloud_power/models/route.rb', line 95 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
100 101 102 |
# File 'lib/ibm_cloud_power/models/route.rb', line 100 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/ibm_cloud_power/models/route.rb', line 77 def self.attribute_map { :'action' => :'action', :'advertise' => :'advertise', :'crn' => :'crn', :'destination' => :'destination', :'destination_type' => :'destinationType', :'enabled' => :'enabled', :'id' => :'id', :'name' => :'name', :'next_hop' => :'nextHop', :'next_hop_type' => :'nextHopType', :'state' => :'state', :'user_tags' => :'userTags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/ibm_cloud_power/models/route.rb', line 480 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/ibm_cloud_power/models/route.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/ibm_cloud_power/models/route.rb', line 105 def self.openapi_types { :'action' => :'String', :'advertise' => :'String', :'crn' => :'String', :'destination' => :'String', :'destination_type' => :'String', :'enabled' => :'Boolean', :'id' => :'String', :'name' => :'String', :'next_hop' => :'String', :'next_hop_type' => :'String', :'state' => :'String', :'user_tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/ibm_cloud_power/models/route.rb', line 448 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && advertise == o.advertise && crn == o.crn && destination == o.destination && destination_type == o.destination_type && enabled == o.enabled && id == o.id && name == o.name && next_hop == o.next_hop && next_hop_type == o.next_hop_type && state == o.state && == o. end |
#eql?(o) ⇒ Boolean
467 468 469 |
# File 'lib/ibm_cloud_power/models/route.rb', line 467 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
473 474 475 |
# File 'lib/ibm_cloud_power/models/route.rb', line 473 def hash [action, advertise, crn, destination, destination_type, enabled, id, name, next_hop, next_hop_type, state, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/ibm_cloud_power/models/route.rb', line 219 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @advertise.nil? invalid_properties.push('invalid value for "advertise", advertise cannot be nil.') end if @crn.nil? invalid_properties.push('invalid value for "crn", crn cannot be nil.') end if @destination.nil? invalid_properties.push('invalid value for "destination", destination cannot be nil.') end if @destination_type.nil? invalid_properties.push('invalid value for "destination_type", destination_type cannot be nil.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end pattern = Regexp.new(/^[\s]*[A-Za-z0-9:_.\-][A-Za-z0-9\s:_.\-]*$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @next_hop.nil? invalid_properties.push('invalid value for "next_hop", next_hop cannot be nil.') end if @next_hop_type.nil? invalid_properties.push('invalid value for "next_hop_type", next_hop_type cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
502 503 504 505 506 507 508 509 510 511 512 513 514 |
# File 'lib/ibm_cloud_power/models/route.rb', line 502 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/ibm_cloud_power/models/route.rb', line 284 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @action.nil? action_validator = EnumAttributeValidator.new('String', ["deliver"]) return false unless action_validator.valid?(@action) return false if @advertise.nil? advertise_validator = EnumAttributeValidator.new('String', ["enable", "disable"]) return false unless advertise_validator.valid?(@advertise) return false if @crn.nil? return false if @destination.nil? return false if @destination_type.nil? destination_type_validator = EnumAttributeValidator.new('String', ["ipv4-address"]) return false unless destination_type_validator.valid?(@destination_type) return false if @enabled.nil? return false if @id.nil? return false if @name.nil? return false if @name.to_s.length > 128 return false if @name !~ Regexp.new(/^[\s]*[A-Za-z0-9:_.\-][A-Za-z0-9\s:_.\-]*$/) return false if @next_hop.nil? return false if @next_hop_type.nil? next_hop_type_validator = EnumAttributeValidator.new('String', ["ipv4-address"]) return false unless next_hop_type_validator.valid?(@next_hop_type) return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["defined", "deployed", "disabled", "error", "deploying", "undeploying", "deleting"]) return false unless state_validator.valid?(@state) return false if !@user_tags.nil? && @user_tags.length > 100 true end |