Class: IbmCloudPower::RouteCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::RouteCreate
- Defined in:
- lib/ibm_cloud_power/models/route_create.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Action.
-
#advertise ⇒ Object
Indicates if the route is advertised externally of the workspace to PER and\or peer networks.
-
#destination ⇒ Object
The route destination.
-
#destination_type ⇒ Object
The destination type.
-
#enabled ⇒ Object
Indicates if the route should be enabled in the fabric.
-
#name ⇒ Object
Name of the route.
-
#next_hop ⇒ Object
The next hop.
-
#next_hop_type ⇒ Object
The next hop type.
-
#user_tags ⇒ Object
List of user tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RouteCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RouteCreate
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::RouteCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::RouteCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = 'deliver' end if attributes.key?(:'advertise') self.advertise = attributes[:'advertise'] else self.advertise = 'enable' end if attributes.key?(:'destination') self.destination = attributes[:'destination'] else self.destination = nil end if attributes.key?(:'destination_type') self.destination_type = attributes[:'destination_type'] else self.destination_type = 'ipv4-address' end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'next_hop') self.next_hop = attributes[:'next_hop'] else self.next_hop = nil end if attributes.key?(:'next_hop_type') self.next_hop_type = attributes[:'next_hop_type'] else self.next_hop_type = 'ipv4-address' end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#action ⇒ Object
Action
19 20 21 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 19 def action @action end |
#advertise ⇒ Object
Indicates if the route is advertised externally of the workspace to PER and\or peer networks
22 23 24 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 22 def advertise @advertise end |
#destination ⇒ Object
The route destination
25 26 27 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 25 def destination @destination end |
#destination_type ⇒ Object
The destination type
28 29 30 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 28 def destination_type @destination_type end |
#enabled ⇒ Object
Indicates if the route should be enabled in the fabric
31 32 33 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 31 def enabled @enabled end |
#name ⇒ Object
Name of the route
34 35 36 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 34 def name @name end |
#next_hop ⇒ Object
The next hop
37 38 39 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 37 def next_hop @next_hop end |
#next_hop_type ⇒ Object
The next hop type
40 41 42 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 40 def next_hop_type @next_hop_type end |
#user_tags ⇒ Object
List of user tags
43 44 45 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 43 def @user_tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 68 def self.attribute_map { :'action' => :'action', :'advertise' => :'advertise', :'destination' => :'destination', :'destination_type' => :'destinationType', :'enabled' => :'enabled', :'name' => :'name', :'next_hop' => :'nextHop', :'next_hop_type' => :'nextHopType', :'user_tags' => :'userTags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 362 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 93 def self.openapi_types { :'action' => :'String', :'advertise' => :'String', :'destination' => :'String', :'destination_type' => :'String', :'enabled' => :'Boolean', :'name' => :'String', :'next_hop' => :'String', :'next_hop_type' => :'String', :'user_tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 333 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && advertise == o.advertise && destination == o.destination && destination_type == o.destination_type && enabled == o.enabled && name == o.name && next_hop == o.next_hop && next_hop_type == o.next_hop_type && == o. end |
#eql?(o) ⇒ Boolean
349 350 351 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 349 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
355 356 357 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 355 def hash [action, advertise, destination, destination_type, enabled, name, next_hop, next_hop_type, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 186 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @destination.nil? invalid_properties.push('invalid value for "destination", destination cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end pattern = Regexp.new(/^[\s]*[A-Za-z0-9:_.\-][A-Za-z0-9\s:_.\-]*$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @next_hop.nil? invalid_properties.push('invalid value for "next_hop", next_hop cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 384 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/ibm_cloud_power/models/route_create.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' action_validator = EnumAttributeValidator.new('String', ["deliver"]) return false unless action_validator.valid?(@action) advertise_validator = EnumAttributeValidator.new('String', ["enable", "disable"]) return false unless advertise_validator.valid?(@advertise) return false if @destination.nil? destination_type_validator = EnumAttributeValidator.new('String', ["ipv4-address"]) return false unless destination_type_validator.valid?(@destination_type) return false if @name.nil? return false if @name.to_s.length > 128 return false if @name !~ Regexp.new(/^[\s]*[A-Za-z0-9:_.\-][A-Za-z0-9\s:_.\-]*$/) return false if @next_hop.nil? next_hop_type_validator = EnumAttributeValidator.new('String', ["ipv4-address"]) return false unless next_hop_type_validator.valid?(@next_hop_type) return false if !@user_tags.nil? && @user_tags.length > 100 true end |