Class: IbmCloudPower::RouteFilter
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::RouteFilter
- Defined in:
- lib/ibm_cloud_power/models/route_filter.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
action of the filter * allow: allow * deny: deny.
-
#creation_date ⇒ Object
time stamp for create route filter.
-
#direction ⇒ Object
direction of the filter * import - import the routes * export - export the routes.
-
#error ⇒ Object
error description.
-
#ge ⇒ Object
The minimum matching length of the prefix-set(1 ≤ value ≤ 32 value ≤ GE).
-
#index ⇒ Object
priority or order of the filter.
-
#le ⇒ Object
The maximum matching length of the prefix-set( 1 ≤ value ≤ 32 value >= GE).
-
#prefix ⇒ Object
IP prefix representing an address and mask length of the prefix-set.
-
#route_filter_id ⇒ Object
route filter ID.
-
#state ⇒ Object
status of the route filter.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RouteFilter
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RouteFilter
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::RouteFilter` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::RouteFilter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ge') self.ge = attributes[:'ge'] end if attributes.key?(:'le') self.le = attributes[:'le'] end if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = 'allow' end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'direction') self.direction = attributes[:'direction'] else self.direction = nil end if attributes.key?(:'error') self.error = attributes[:'error'] else self.error = nil end if attributes.key?(:'index') self.index = attributes[:'index'] else self.index = nil end if attributes.key?(:'prefix') self.prefix = attributes[:'prefix'] else self.prefix = nil end if attributes.key?(:'route_filter_id') self.route_filter_id = attributes[:'route_filter_id'] else self.route_filter_id = nil end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end end |
Instance Attribute Details
#action ⇒ Object
action of the filter * allow: allow * deny: deny
25 26 27 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 25 def action @action end |
#creation_date ⇒ Object
time stamp for create route filter
28 29 30 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 28 def creation_date @creation_date end |
#direction ⇒ Object
direction of the filter * import - import the routes * export - export the routes
31 32 33 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 31 def direction @direction end |
#error ⇒ Object
error description
34 35 36 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 34 def error @error end |
#ge ⇒ Object
The minimum matching length of the prefix-set(1 ≤ value ≤ 32 value ≤ GE)
19 20 21 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 19 def ge @ge end |
#index ⇒ Object
priority or order of the filter
37 38 39 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 37 def index @index end |
#le ⇒ Object
The maximum matching length of the prefix-set( 1 ≤ value ≤ 32 value >= GE)
22 23 24 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 22 def le @le end |
#prefix ⇒ Object
IP prefix representing an address and mask length of the prefix-set
40 41 42 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 40 def prefix @prefix end |
#route_filter_id ⇒ Object
route filter ID
43 44 45 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 43 def route_filter_id @route_filter_id end |
#state ⇒ Object
status of the route filter
46 47 48 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 46 def state @state end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 71 def self.attribute_map { :'ge' => :'GE', :'le' => :'LE', :'action' => :'action', :'creation_date' => :'creationDate', :'direction' => :'direction', :'error' => :'error', :'index' => :'index', :'prefix' => :'prefix', :'route_filter_id' => :'routeFilterID', :'state' => :'state' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 414 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 117 118 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 113 def self.openapi_nullable Set.new([ :'ge', :'le', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 97 def self.openapi_types { :'ge' => :'Integer', :'le' => :'Integer', :'action' => :'String', :'creation_date' => :'String', :'direction' => :'String', :'error' => :'String', :'index' => :'Integer', :'prefix' => :'String', :'route_filter_id' => :'String', :'state' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 384 def ==(o) return true if self.equal?(o) self.class == o.class && ge == o.ge && le == o.le && action == o.action && creation_date == o.creation_date && direction == o.direction && error == o.error && index == o.index && prefix == o.prefix && route_filter_id == o.route_filter_id && state == o.state end |
#eql?(o) ⇒ Boolean
401 402 403 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 401 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
407 408 409 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 407 def hash [ge, le, action, creation_date, direction, error, index, prefix, route_filter_id, state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@ge.nil? && @ge > 32 invalid_properties.push('invalid value for "ge", must be smaller than or equal to 32.') end if !@ge.nil? && @ge < 1 invalid_properties.push('invalid value for "ge", must be greater than or equal to 1.') end if !@le.nil? && @le > 32 invalid_properties.push('invalid value for "le", must be smaller than or equal to 32.') end if !@le.nil? && @le < 1 invalid_properties.push('invalid value for "le", must be greater than or equal to 1.') end if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end if @direction.nil? invalid_properties.push('invalid value for "direction", direction cannot be nil.') end if @error.nil? invalid_properties.push('invalid value for "error", error cannot be nil.') end if @index.nil? invalid_properties.push('invalid value for "index", index cannot be nil.') end if @prefix.nil? invalid_properties.push('invalid value for "prefix", prefix cannot be nil.') end if @route_filter_id.nil? invalid_properties.push('invalid value for "route_filter_id", route_filter_id cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
436 437 438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 436 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/ibm_cloud_power/models/route_filter.rb', line 251 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ge.nil? && @ge > 32 return false if !@ge.nil? && @ge < 1 return false if !@le.nil? && @le > 32 return false if !@le.nil? && @le < 1 return false if @action.nil? action_validator = EnumAttributeValidator.new('String', ["allow", "deny"]) return false unless action_validator.valid?(@action) return false if @creation_date.nil? return false if @direction.nil? direction_validator = EnumAttributeValidator.new('String', ["import", "export"]) return false unless direction_validator.valid?(@direction) return false if @error.nil? return false if @index.nil? return false if @prefix.nil? return false if @route_filter_id.nil? return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["active", "configuring", "removing", "error", "updating"]) return false unless state_validator.valid?(@state) true end |