Class: IbmCloudPower::RouteFilterCreate

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/route_filter_create.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RouteFilterCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::RouteFilterCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::RouteFilterCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ge')
    self.ge = attributes[:'ge']
  end

  if attributes.key?(:'le')
    self.le = attributes[:'le']
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = 'allow'
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  else
    self.direction = nil
  end

  if attributes.key?(:'index')
    self.index = attributes[:'index']
  else
    self.index = nil
  end

  if attributes.key?(:'prefix')
    self.prefix = attributes[:'prefix']
  else
    self.prefix = nil
  end
end

Instance Attribute Details

#actionObject

action of the filter * allow: allow * deny: deny



25
26
27
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 25

def action
  @action
end

#directionObject

direction of the filter * import - import the routes * export - export the routes



28
29
30
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 28

def direction
  @direction
end

#geObject

The minimum matching length of the prefix-set(1 ≤ value ≤ 32 & value ≤ LE)



19
20
21
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 19

def ge
  @ge
end

#indexObject

priority or order of the filter



31
32
33
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 31

def index
  @index
end

#leObject

The maximum matching length of the prefix-set( 1 ≤ value ≤ 32 & value >= GE)



22
23
24
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 22

def le
  @le
end

#prefixObject

IP prefix representing an address and mask length of the prefix-set



34
35
36
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 34

def prefix
  @prefix
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 59

def self.attribute_map
  {
    :'ge' => :'GE',
    :'le' => :'LE',
    :'action' => :'action',
    :'direction' => :'direction',
    :'index' => :'index',
    :'prefix' => :'prefix'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 323

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 81

def self.openapi_types
  {
    :'ge' => :'Integer',
    :'le' => :'Integer',
    :'action' => :'String',
    :'direction' => :'String',
    :'index' => :'Integer',
    :'prefix' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



297
298
299
300
301
302
303
304
305
306
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 297

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ge == o.ge &&
      le == o.le &&
      action == o.action &&
      direction == o.direction &&
      index == o.index &&
      prefix == o.prefix
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 310

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



316
317
318
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 316

def hash
  [ge, le, action, direction, index, prefix].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@ge.nil? && @ge > 32
    invalid_properties.push('invalid value for "ge", must be smaller than or equal to 32.')
  end

  if !@ge.nil? && @ge < 1
    invalid_properties.push('invalid value for "ge", must be greater than or equal to 1.')
  end

  if !@le.nil? && @le > 32
    invalid_properties.push('invalid value for "le", must be smaller than or equal to 32.')
  end

  if !@le.nil? && @le < 1
    invalid_properties.push('invalid value for "le", must be greater than or equal to 1.')
  end

  if @direction.nil?
    invalid_properties.push('invalid value for "direction", direction cannot be nil.')
  end

  if @index.nil?
    invalid_properties.push('invalid value for "index", index cannot be nil.')
  end

  if @index > 10000000
    invalid_properties.push('invalid value for "index", must be smaller than or equal to 10000000.')
  end

  if @index < 1
    invalid_properties.push('invalid value for "index", must be greater than or equal to 1.')
  end

  if @prefix.nil?
    invalid_properties.push('invalid value for "prefix", prefix cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 345

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/ibm_cloud_power/models/route_filter_create.rb', line 193

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@ge.nil? && @ge > 32
  return false if !@ge.nil? && @ge < 1
  return false if !@le.nil? && @le > 32
  return false if !@le.nil? && @le < 1
  action_validator = EnumAttributeValidator.new('String', ["allow", "deny"])
  return false unless action_validator.valid?(@action)
  return false if @direction.nil?
  direction_validator = EnumAttributeValidator.new('String', ["import", "export"])
  return false unless direction_validator.valid?(@direction)
  return false if @index.nil?
  return false if @index > 10000000
  return false if @index < 1
  return false if @prefix.nil?
  true
end