Class: IbmCloudPower::SharedProcessorPoolCreate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_power/models/shared_processor_pool_create.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SharedProcessorPoolCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::SharedProcessorPoolCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::SharedProcessorPoolCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'host_group')
    self.host_group = attributes[:'host_group']
  else
    self.host_group = nil
  end

  if attributes.key?(:'host_id')
    self.host_id = attributes[:'host_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'placement_group_id')
    self.placement_group_id = attributes[:'placement_group_id']
  end

  if attributes.key?(:'reserved_cores')
    self.reserved_cores = attributes[:'reserved_cores']
  else
    self.reserved_cores = nil
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end
end

Instance Attribute Details

#host_groupObject

The host group; a host from the group will be automatically selected based on available resources



19
20
21
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 19

def host_group
  @host_group
end

#host_idObject

The host id of a host in a host group (only available for dedicated hosts)



22
23
24
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 22

def host_id
  @host_id
end

#nameObject

The name of the Shared Processor Pool; minumum of 2 characters, maximum of 12, the only special character allowed is the underscore '_'.



25
26
27
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 25

def name
  @name
end

#placement_group_idObject

The ID of the placement group



28
29
30
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 28

def placement_group_id
  @placement_group_id
end

#reserved_coresObject

The amount of reserved processor cores for the Shared Processor Pool; only integers allowed, no fractional values



31
32
33
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 31

def reserved_cores
  @reserved_cores
end

#user_tagsObject

List of user tags



34
35
36
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 34

def user_tags
  @user_tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 37

def self.attribute_map
  {
    :'host_group' => :'hostGroup',
    :'host_id' => :'hostID',
    :'name' => :'name',
    :'placement_group_id' => :'placementGroupID',
    :'reserved_cores' => :'reservedCores',
    :'user_tags' => :'userTags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
75
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 71

def self.openapi_nullable
  Set.new([
    :'reserved_cores',
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 59

def self.openapi_types
  {
    :'host_group' => :'String',
    :'host_id' => :'String',
    :'name' => :'String',
    :'placement_group_id' => :'String',
    :'reserved_cores' => :'Integer',
    :'user_tags' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
201
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      host_group == o.host_group &&
      host_id == o.host_id &&
      name == o.name &&
      placement_group_id == o.placement_group_id &&
      reserved_cores == o.reserved_cores &&
      user_tags == o.user_tags
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 211

def hash
  [host_group, host_id, name, placement_group_id, reserved_cores, user_tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @host_group.nil?
    invalid_properties.push('invalid value for "host_group", host_group cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if !@user_tags.nil? && @user_tags.length > 100
    invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
153
154
# File 'lib/ibm_cloud_power/models/shared_processor_pool_create.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @host_group.nil?
  return false if @name.nil?
  return false if !@user_tags.nil? && @user_tags.length > 100
  true
end