Class: IbmCloudPower::SharedProcessorPoolServer
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::SharedProcessorPoolServer
- Defined in:
- lib/ibm_cloud_power/models/shared_processor_pool_server.rb
Instance Attribute Summary collapse
-
#availability_zone ⇒ Object
Availability zone for the server.
-
#cpus ⇒ Object
The amount of cpus for the server.
-
#id ⇒ Object
The server ID.
-
#memory ⇒ Object
The amount of memory for the server.
-
#name ⇒ Object
The server name.
-
#status ⇒ Object
Status of the server.
-
#uncapped ⇒ Object
Identifies if uncapped or not.
-
#vcpus ⇒ Object
The amout of vcpus for the server.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SharedProcessorPoolServer
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SharedProcessorPoolServer
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::SharedProcessorPoolServer` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::SharedProcessorPoolServer`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cpus') self.cpus = attributes[:'cpus'] end if attributes.key?(:'uncapped') self.uncapped = attributes[:'uncapped'] end if attributes.key?(:'availability_zone') self.availability_zone = attributes[:'availability_zone'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'memory') self.memory = attributes[:'memory'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'vcpus') self.vcpus = attributes[:'vcpus'] end end |
Instance Attribute Details
#availability_zone ⇒ Object
Availability zone for the server
25 26 27 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 25 def availability_zone @availability_zone end |
#cpus ⇒ Object
The amount of cpus for the server
19 20 21 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 19 def cpus @cpus end |
#id ⇒ Object
The server ID
28 29 30 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 28 def id @id end |
#memory ⇒ Object
The amount of memory for the server
31 32 33 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 31 def memory @memory end |
#name ⇒ Object
The server name
34 35 36 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 34 def name @name end |
#status ⇒ Object
Status of the server
37 38 39 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 37 def status @status end |
#uncapped ⇒ Object
Identifies if uncapped or not
22 23 24 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 22 def uncapped @uncapped end |
#vcpus ⇒ Object
The amout of vcpus for the server
40 41 42 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 40 def vcpus @vcpus end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 43 def self.attribute_map { :'cpus' => :'Cpus', :'uncapped' => :'Uncapped', :'availability_zone' => :'availabilityZone', :'id' => :'id', :'memory' => :'memory', :'name' => :'name', :'status' => :'status', :'vcpus' => :'vcpus' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 180 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 67 def self.openapi_types { :'cpus' => :'Float', :'uncapped' => :'Boolean', :'availability_zone' => :'String', :'id' => :'String', :'memory' => :'Integer', :'name' => :'String', :'status' => :'String', :'vcpus' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 152 def ==(o) return true if self.equal?(o) self.class == o.class && cpus == o.cpus && uncapped == o.uncapped && availability_zone == o.availability_zone && id == o.id && memory == o.memory && name == o.name && status == o.status && vcpus == o.vcpus end |
#eql?(o) ⇒ Boolean
167 168 169 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 167 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 173 def hash [cpus, uncapped, availability_zone, id, memory, name, status, vcpus].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 |
# File 'lib/ibm_cloud_power/models/shared_processor_pool_server.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |