Class: IbmCloudPower::StorageAffinity

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/storage_affinity.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StorageAffinity

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::StorageAffinity` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::StorageAffinity`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'affinity_pvm_instance')
    self.affinity_pvm_instance = attributes[:'affinity_pvm_instance']
  end

  if attributes.key?(:'affinity_policy')
    self.affinity_policy = attributes[:'affinity_policy']
  end

  if attributes.key?(:'affinity_volume')
    self.affinity_volume = attributes[:'affinity_volume']
  end

  if attributes.key?(:'anti_affinity_pvm_instances')
    if (value = attributes[:'anti_affinity_pvm_instances']).is_a?(Array)
      self.anti_affinity_pvm_instances = value
    end
  end

  if attributes.key?(:'anti_affinity_volumes')
    if (value = attributes[:'anti_affinity_volumes']).is_a?(Array)
      self.anti_affinity_volumes = value
    end
  end
end

Instance Attribute Details

#affinity_policyObject

Affinity policy for storage pool selection; ignored if storagePool provided; for policy 'affinity' requires one of affinityPVMInstance or affinityVolume to be specified; for policy 'anti-affinity' requires one of antiAffinityPVMInstances or antiAffinityVolumes to be specified



22
23
24
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 22

def affinity_policy
  @affinity_policy
end

#affinity_pvm_instanceObject

PVM Instance (ID or Name) to base storage affinity policy against; required if requesting storage affinity and affinityVolume is not provided



19
20
21
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 19

def affinity_pvm_instance
  @affinity_pvm_instance
end

#affinity_volumeObject

Volume (ID or Name) to base storage affinity policy against; required if requesting storage affinity and affinityPVMInstance is not provided



25
26
27
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 25

def affinity_volume
  @affinity_volume
end

#anti_affinity_pvm_instancesObject

List of pvmInstances to base storage anti-affinity policy against; required if requesting storage anti-affinity and antiAffinityVolumes is not provided



28
29
30
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 28

def anti_affinity_pvm_instances
  @anti_affinity_pvm_instances
end

#anti_affinity_volumesObject

List of volumes to base storage anti-affinity policy against; required if requesting storage anti-affinity and antiAffinityPVMInstances is not provided



31
32
33
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 31

def anti_affinity_volumes
  @anti_affinity_volumes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 56

def self.attribute_map
  {
    :'affinity_pvm_instance' => :'affinityPVMInstance',
    :'affinity_policy' => :'affinityPolicy',
    :'affinity_volume' => :'affinityVolume',
    :'anti_affinity_pvm_instances' => :'antiAffinityPVMInstances',
    :'anti_affinity_volumes' => :'antiAffinityVolumes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 77

def self.openapi_types
  {
    :'affinity_pvm_instance' => :'String',
    :'affinity_policy' => :'String',
    :'affinity_volume' => :'String',
    :'anti_affinity_pvm_instances' => :'Array<String>',
    :'anti_affinity_volumes' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
170
171
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      affinity_pvm_instance == o.affinity_pvm_instance &&
      affinity_policy == o.affinity_policy &&
      affinity_volume == o.affinity_volume &&
      anti_affinity_pvm_instances == o.anti_affinity_pvm_instances &&
      anti_affinity_volumes == o.anti_affinity_volumes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 181

def hash
  [affinity_pvm_instance, affinity_policy, affinity_volume, anti_affinity_pvm_instances, anti_affinity_volumes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
149
# File 'lib/ibm_cloud_power/models/storage_affinity.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  affinity_policy_validator = EnumAttributeValidator.new('String', ["affinity", "anti-affinity"])
  return false unless affinity_policy_validator.valid?(@affinity_policy)
  true
end