Class: IbmCloudPower::StoragePoolsCapacityMaximumStorageAllocation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::StoragePoolsCapacityMaximumStorageAllocation
- Defined in:
- lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb
Instance Attribute Summary collapse
-
#max_allocation_size ⇒ Object
Maximum allocation storage size (GiB).
-
#storage_pool ⇒ Object
Storage pool.
-
#storage_type ⇒ Object
Storage type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StoragePoolsCapacityMaximumStorageAllocation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StoragePoolsCapacityMaximumStorageAllocation
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 70 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::StoragePoolsCapacityMaximumStorageAllocation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::StoragePoolsCapacityMaximumStorageAllocation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'max_allocation_size') self.max_allocation_size = attributes[:'max_allocation_size'] else self.max_allocation_size = nil end if attributes.key?(:'storage_pool') self.storage_pool = attributes[:'storage_pool'] else self.storage_pool = nil end if attributes.key?(:'storage_type') self.storage_type = attributes[:'storage_type'] else self.storage_type = nil end end |
Instance Attribute Details
#max_allocation_size ⇒ Object
Maximum allocation storage size (GiB)
19 20 21 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 19 def max_allocation_size @max_allocation_size end |
#storage_pool ⇒ Object
Storage pool
22 23 24 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 22 def storage_pool @storage_pool end |
#storage_type ⇒ Object
Storage type
25 26 27 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 25 def storage_type @storage_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 28 def self.attribute_map { :'max_allocation_size' => :'maxAllocationSize', :'storage_pool' => :'storagePool', :'storage_type' => :'storageType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 188 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
62 63 64 65 66 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 62 def self.openapi_all_of [ :'MaximumStorageAllocation' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 47 def self.openapi_types { :'max_allocation_size' => :'Integer', :'storage_pool' => :'String', :'storage_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
165 166 167 168 169 170 171 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 165 def ==(o) return true if self.equal?(o) self.class == o.class && max_allocation_size == o.max_allocation_size && storage_pool == o.storage_pool && storage_type == o.storage_type end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 181 def hash [max_allocation_size, storage_pool, storage_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @max_allocation_size.nil? invalid_properties.push('invalid value for "max_allocation_size", max_allocation_size cannot be nil.') end if @storage_pool.nil? invalid_properties.push('invalid value for "storage_pool", storage_pool cannot be nil.') end if @storage_type.nil? invalid_properties.push('invalid value for "storage_type", storage_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 129 130 131 |
# File 'lib/ibm_cloud_power/models/storage_pools_capacity_maximum_storage_allocation.rb', line 125 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @max_allocation_size.nil? return false if @storage_pool.nil? return false if @storage_type.nil? true end |