Class: IbmCloudPower::SystemPool

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/system_pool.rb

Overview

Hardware platform detailing its limits and statistics

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SystemPool

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::SystemPool` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::SystemPool`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'capacity')
    self.capacity = attributes[:'capacity']
  end

  if attributes.key?(:'core_increment')
    self.core_increment = attributes[:'core_increment']
  end

  if attributes.key?(:'core_memory_ratio')
    self.core_memory_ratio = attributes[:'core_memory_ratio']
  end

  if attributes.key?(:'max_available')
    self.max_available = attributes[:'max_available']
  end

  if attributes.key?(:'max_cores_available')
    self.max_cores_available = attributes[:'max_cores_available']
  end

  if attributes.key?(:'max_memory_available')
    self.max_memory_available = attributes[:'max_memory_available']
  end

  if attributes.key?(:'shared_core_ratio')
    self.shared_core_ratio = attributes[:'shared_core_ratio']
  end

  if attributes.key?(:'systems')
    if (value = attributes[:'systems']).is_a?(Array)
      self.systems = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#capacityObject

Returns the value of attribute capacity.



19
20
21
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 19

def capacity
  @capacity
end

#core_incrementObject

Core allocation increment



22
23
24
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 22

def core_increment
  @core_increment
end

#core_memory_ratioObject

Processor to Memory (GiB) Ratio



25
26
27
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 25

def core_memory_ratio
  @core_memory_ratio
end

#max_availableObject

Returns the value of attribute max_available.



27
28
29
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 27

def max_available
  @max_available
end

#max_cores_availableObject

Returns the value of attribute max_cores_available.



29
30
31
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 29

def max_cores_available
  @max_cores_available
end

#max_memory_availableObject

Returns the value of attribute max_memory_available.



31
32
33
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 31

def max_memory_available
  @max_memory_available
end

#shared_core_ratioObject

Returns the value of attribute shared_core_ratio.



33
34
35
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 33

def shared_core_ratio
  @shared_core_ratio
end

#systemsObject

The DataCenter list of servers and their available resources



36
37
38
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 36

def systems
  @systems
end

#typeObject

Type of system hardware



39
40
41
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 39

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 42

def self.attribute_map
  {
    :'capacity' => :'capacity',
    :'core_increment' => :'coreIncrement',
    :'core_memory_ratio' => :'coreMemoryRatio',
    :'max_available' => :'maxAvailable',
    :'max_cores_available' => :'maxCoresAvailable',
    :'max_memory_available' => :'maxMemoryAvailable',
    :'shared_core_ratio' => :'sharedCoreRatio',
    :'systems' => :'systems',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 67

def self.openapi_types
  {
    :'capacity' => :'SystemPoolCapacity',
    :'core_increment' => :'Float',
    :'core_memory_ratio' => :'Float',
    :'max_available' => :'SystemPoolCapacity',
    :'max_cores_available' => :'SystemPoolCapacity',
    :'max_memory_available' => :'SystemPoolCapacity',
    :'shared_core_ratio' => :'SystemPoolSharedCoreRatio',
    :'systems' => :'Array<System>',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 159

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      capacity == o.capacity &&
      core_increment == o.core_increment &&
      core_memory_ratio == o.core_memory_ratio &&
      max_available == o.max_available &&
      max_cores_available == o.max_cores_available &&
      max_memory_available == o.max_memory_available &&
      shared_core_ratio == o.shared_core_ratio &&
      systems == o.systems &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 181

def hash
  [capacity, core_increment, core_memory_ratio, max_available, max_cores_available, max_memory_available, shared_core_ratio, systems, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
# File 'lib/ibm_cloud_power/models/system_pool.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end