Class: IbmCloudPower::SystemPoolCapacity

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/system_pool_capacity.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SystemPoolCapacity

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::SystemPoolCapacity` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::SystemPoolCapacity`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'available_cores')
    self.available_cores = attributes[:'available_cores']
  end

  if attributes.key?(:'available_memory')
    self.available_memory = attributes[:'available_memory']
  end

  if attributes.key?(:'cores')
    self.cores = attributes[:'cores']
  else
    self.cores = nil
  end

  if attributes.key?(:'host_mtms_name')
    self.host_mtms_name = attributes[:'host_mtms_name']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'memory')
    self.memory = attributes[:'memory']
  else
    self.memory = nil
  end

  if attributes.key?(:'total_cores')
    self.total_cores = attributes[:'total_cores']
  end

  if attributes.key?(:'total_memory')
    self.total_memory = attributes[:'total_memory']
  end

  if attributes.key?(:'total_phys_cores')
    self.total_phys_cores = attributes[:'total_phys_cores']
  end

  if attributes.key?(:'total_phys_memory')
    self.total_phys_memory = attributes[:'total_phys_memory']
  end
end

Instance Attribute Details

#available_coresObject

The host available Processor units



19
20
21
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 19

def available_cores
  @available_cores
end

#available_memoryObject

The host available RAM memory in GiB



22
23
24
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 22

def available_memory
  @available_memory
end

#coresObject

The host available Processor units



25
26
27
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 25

def cores
  @cores
end

#host_mtms_nameObject

The host MTMS name



28
29
30
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 28

def host_mtms_name
  @host_mtms_name
end

#idObject

The host identifier



31
32
33
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 31

def id
  @id
end

#memoryObject

The host total RAM memory in GiB



34
35
36
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 34

def memory
  @memory
end

#total_coresObject

The host total usable Processor units



37
38
39
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 37

def total_cores
  @total_cores
end

#total_memoryObject

The host total usable RAM memory in GiB



40
41
42
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 40

def total_memory
  @total_memory
end

#total_phys_coresObject

Total number of physical cores in the Pod



43
44
45
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 43

def total_phys_cores
  @total_phys_cores
end

#total_phys_memoryObject

Total amount of physical memory in the Pod (GiB)



46
47
48
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 46

def total_phys_memory
  @total_phys_memory
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 49

def self.attribute_map
  {
    :'available_cores' => :'availableCores',
    :'available_memory' => :'availableMemory',
    :'cores' => :'cores',
    :'host_mtms_name' => :'hostMTMSName',
    :'id' => :'id',
    :'memory' => :'memory',
    :'total_cores' => :'totalCores',
    :'total_memory' => :'totalMemory',
    :'total_phys_cores' => :'totalPhysCores',
    :'total_phys_memory' => :'totalPhysMemory'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 241

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



97
98
99
100
101
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 97

def self.openapi_all_of
  [
  :'System'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 75

def self.openapi_types
  {
    :'available_cores' => :'Float',
    :'available_memory' => :'Integer',
    :'cores' => :'Float',
    :'host_mtms_name' => :'String',
    :'id' => :'Integer',
    :'memory' => :'Integer',
    :'total_cores' => :'Float',
    :'total_memory' => :'Integer',
    :'total_phys_cores' => :'Float',
    :'total_phys_memory' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      available_cores == o.available_cores &&
      available_memory == o.available_memory &&
      cores == o.cores &&
      host_mtms_name == o.host_mtms_name &&
      id == o.id &&
      memory == o.memory &&
      total_cores == o.total_cores &&
      total_memory == o.total_memory &&
      total_phys_cores == o.total_phys_cores &&
      total_phys_memory == o.total_phys_memory
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


228
229
230
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 228

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



234
235
236
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 234

def hash
  [available_cores, available_memory, cores, host_mtms_name, id, memory, total_cores, total_memory, total_phys_cores, total_phys_memory].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @cores.nil?
    invalid_properties.push('invalid value for "cores", cores cannot be nil.')
  end

  if @memory.nil?
    invalid_properties.push('invalid value for "memory", memory cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 263

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
# File 'lib/ibm_cloud_power/models/system_pool_capacity.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @cores.nil?
  return false if @memory.nil?
  true
end