Class: IbmCloudPower::TargetTrustedProfile
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::TargetTrustedProfile
- Defined in:
- lib/ibm_cloud_power/models/target_trusted_profile.rb
Overview
trusted profile associated with the VM. Specify one of crn, id or name
Instance Attribute Summary collapse
-
#crn ⇒ Object
The CRN for the trusted profile.
-
#id ⇒ Object
Unique identifier for the trusted profile.
-
#name ⇒ Object
name of the trusted profile (requires the trusted profile read IAM action when used with autolink).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetTrustedProfile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TargetTrustedProfile
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::TargetTrustedProfile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::TargetTrustedProfile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'crn') self.crn = attributes[:'crn'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end end |
Instance Attribute Details
#crn ⇒ Object
The CRN for the trusted profile
20 21 22 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 20 def crn @crn end |
#id ⇒ Object
Unique identifier for the trusted profile
23 24 25 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 23 def id @id end |
#name ⇒ Object
name of the trusted profile (requires the trusted profile read IAM action when used with autolink)
26 27 28 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 26 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 29 def self.attribute_map { :'crn' => :'crn', :'id' => :'id', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 48 def self.openapi_types { :'crn' => :'String', :'id' => :'String', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && crn == o.crn && id == o.id && name == o.name end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 184 def hash [crn, id, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@crn.nil? && @crn.to_s.length > 512 invalid_properties.push('invalid value for "crn", the character length must be smaller than or equal to 512.') end pattern = Regexp.new(/^(crn:v[0-9]+:[a-z0-9-]+:[a-z0-9-]+:[a-z0-9-]+:[a-z0-9-]*:([a-z]\/[a-z0-9-]+)?:[a-z0-9-]*:[a-z0-9-]*:[a-zA-Z0-9\-_\.\/]*)?$/) if !@crn.nil? && @crn !~ pattern invalid_properties.push("invalid value for \"crn\", must conform to the pattern #{pattern}.") end if !@id.nil? && @id.to_s.length > 64 invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 64.') end pattern = Regexp.new(/^(Profile-[-0-9a-z_]+)?$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 122 123 124 125 126 |
# File 'lib/ibm_cloud_power/models/target_trusted_profile.rb', line 119 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@crn.nil? && @crn.to_s.length > 512 return false if !@crn.nil? && @crn !~ Regexp.new(/^(crn:v[0-9]+:[a-z0-9-]+:[a-z0-9-]+:[a-z0-9-]+:[a-z0-9-]*:([a-z]\/[a-z0-9-]+)?:[a-z0-9-]*:[a-z0-9-]*:[a-zA-Z0-9\-_\.\/]*)?$/) return false if !@id.nil? && @id.to_s.length > 64 return false if !@id.nil? && @id !~ Regexp.new(/^(Profile-[-0-9a-z_]+)?$/) true end |