Class: IbmCloudPower::Task

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/task.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Task

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/ibm_cloud_power/models/task.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Task` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Task`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cloud_instance_id')
    self.cloud_instance_id = attributes[:'cloud_instance_id']
  else
    self.cloud_instance_id = nil
  end

  if attributes.key?(:'component_id')
    self.component_id = attributes[:'component_id']
  else
    self.component_id = nil
  end

  if attributes.key?(:'component_type')
    self.component_type = attributes[:'component_type']
  else
    self.component_type = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'last_update_date')
    self.last_update_date = attributes[:'last_update_date']
  else
    self.last_update_date = nil
  end

  if attributes.key?(:'operation')
    self.operation = attributes[:'operation']
  else
    self.operation = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'status_detail')
    self.status_detail = attributes[:'status_detail']
  else
    self.status_detail = nil
  end

  if attributes.key?(:'task_id')
    self.task_id = attributes[:'task_id']
  else
    self.task_id = nil
  end
end

Instance Attribute Details

#cloud_instance_idObject

Cloud Instance ID of task owner



19
20
21
# File 'lib/ibm_cloud_power/models/task.rb', line 19

def cloud_instance_id
  @cloud_instance_id
end

#component_idObject

the component id of the task



22
23
24
# File 'lib/ibm_cloud_power/models/task.rb', line 22

def component_id
  @component_id
end

#component_typeObject

the component type of the task



25
26
27
# File 'lib/ibm_cloud_power/models/task.rb', line 25

def component_type
  @component_type
end

#creation_dateObject

Creation Date



28
29
30
# File 'lib/ibm_cloud_power/models/task.rb', line 28

def creation_date
  @creation_date
end

#last_update_dateObject

Last Update Date



31
32
33
# File 'lib/ibm_cloud_power/models/task.rb', line 31

def last_update_date
  @last_update_date
end

#operationObject

Task Operation



34
35
36
# File 'lib/ibm_cloud_power/models/task.rb', line 34

def operation
  @operation
end

#statusObject

status code of the task



37
38
39
# File 'lib/ibm_cloud_power/models/task.rb', line 37

def status
  @status
end

#status_detailObject

status detail of the task



40
41
42
# File 'lib/ibm_cloud_power/models/task.rb', line 40

def status_detail
  @status_detail
end

#task_idObject

Pcloud Task ID



43
44
45
# File 'lib/ibm_cloud_power/models/task.rb', line 43

def task_id
  @task_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/ibm_cloud_power/models/task.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/ibm_cloud_power/models/task.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/ibm_cloud_power/models/task.rb', line 46

def self.attribute_map
  {
    :'cloud_instance_id' => :'cloudInstanceID',
    :'component_id' => :'componentID',
    :'component_type' => :'componentType',
    :'creation_date' => :'creationDate',
    :'last_update_date' => :'lastUpdateDate',
    :'operation' => :'operation',
    :'status' => :'status',
    :'status_detail' => :'statusDetail',
    :'task_id' => :'taskID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/ibm_cloud_power/models/task.rb', line 343

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/ibm_cloud_power/models/task.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/ibm_cloud_power/models/task.rb', line 71

def self.openapi_types
  {
    :'cloud_instance_id' => :'String',
    :'component_id' => :'String',
    :'component_type' => :'String',
    :'creation_date' => :'Time',
    :'last_update_date' => :'Time',
    :'operation' => :'String',
    :'status' => :'String',
    :'status_detail' => :'String',
    :'task_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/ibm_cloud_power/models/task.rb', line 314

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cloud_instance_id == o.cloud_instance_id &&
      component_id == o.component_id &&
      component_type == o.component_type &&
      creation_date == o.creation_date &&
      last_update_date == o.last_update_date &&
      operation == o.operation &&
      status == o.status &&
      status_detail == o.status_detail &&
      task_id == o.task_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


330
331
332
# File 'lib/ibm_cloud_power/models/task.rb', line 330

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



336
337
338
# File 'lib/ibm_cloud_power/models/task.rb', line 336

def hash
  [cloud_instance_id, component_id, component_type, creation_date, last_update_date, operation, status, status_detail, task_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/ibm_cloud_power/models/task.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @cloud_instance_id.nil?
    invalid_properties.push('invalid value for "cloud_instance_id", cloud_instance_id cannot be nil.')
  end

  if @component_id.nil?
    invalid_properties.push('invalid value for "component_id", component_id cannot be nil.')
  end

  if @component_type.nil?
    invalid_properties.push('invalid value for "component_type", component_type cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @last_update_date.nil?
    invalid_properties.push('invalid value for "last_update_date", last_update_date cannot be nil.')
  end

  if @operation.nil?
    invalid_properties.push('invalid value for "operation", operation cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @status_detail.nil?
    invalid_properties.push('invalid value for "status_detail", status_detail cannot be nil.')
  end

  if @task_id.nil?
    invalid_properties.push('invalid value for "task_id", task_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/ibm_cloud_power/models/task.rb', line 365

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/ibm_cloud_power/models/task.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @cloud_instance_id.nil?
  return false if @component_id.nil?
  return false if @component_type.nil?
  return false if @creation_date.nil?
  return false if @last_update_date.nil?
  return false if @operation.nil?
  return false if @status.nil?
  return false if @status_detail.nil?
  return false if @task_id.nil?
  true
end