Class: IbmCloudPower::Tenant

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/tenant.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Tenant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ibm_cloud_power/models/tenant.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Tenant` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Tenant`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cloud_instances')
    if (value = attributes[:'cloud_instances']).is_a?(Array)
      self.cloud_instances = value
    end
  else
    self.cloud_instances = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'icn')
    self.icn = attributes[:'icn']
  end

  if attributes.key?(:'peering_networks')
    if (value = attributes[:'peering_networks']).is_a?(Array)
      self.peering_networks = value
    end
  end

  if attributes.key?(:'ssh_keys')
    if (value = attributes[:'ssh_keys']).is_a?(Array)
      self.ssh_keys = value
    end
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end
end

Instance Attribute Details

#cloud_instancesObject

Cloud Instances owned by the Tenant



19
20
21
# File 'lib/ibm_cloud_power/models/tenant.rb', line 19

def cloud_instances
  @cloud_instances
end

#creation_dateObject

Date of Tenant creation



22
23
24
# File 'lib/ibm_cloud_power/models/tenant.rb', line 22

def creation_date
  @creation_date
end

#enabledObject

Indicates if the tenant is enabled



25
26
27
# File 'lib/ibm_cloud_power/models/tenant.rb', line 25

def enabled
  @enabled
end

#icnObject

IBM Customer Number



28
29
30
# File 'lib/ibm_cloud_power/models/tenant.rb', line 28

def icn
  @icn
end

#peering_networksObject

Peering Network Information (optional)



31
32
33
# File 'lib/ibm_cloud_power/models/tenant.rb', line 31

def peering_networks
  @peering_networks
end

#ssh_keysObject

Tenant SSH Keys



34
35
36
# File 'lib/ibm_cloud_power/models/tenant.rb', line 34

def ssh_keys
  @ssh_keys
end

#tenant_idObject

Tenant ID



37
38
39
# File 'lib/ibm_cloud_power/models/tenant.rb', line 37

def tenant_id
  @tenant_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/ibm_cloud_power/models/tenant.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/ibm_cloud_power/models/tenant.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/ibm_cloud_power/models/tenant.rb', line 40

def self.attribute_map
  {
    :'cloud_instances' => :'cloudInstances',
    :'creation_date' => :'creationDate',
    :'enabled' => :'enabled',
    :'icn' => :'icn',
    :'peering_networks' => :'peeringNetworks',
    :'ssh_keys' => :'sshKeys',
    :'tenant_id' => :'tenantID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/ibm_cloud_power/models/tenant.rb', line 244

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/ibm_cloud_power/models/tenant.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/ibm_cloud_power/models/tenant.rb', line 63

def self.openapi_types
  {
    :'cloud_instances' => :'Array<CloudInstanceReference>',
    :'creation_date' => :'Time',
    :'enabled' => :'Boolean',
    :'icn' => :'String',
    :'peering_networks' => :'Array<PeeringNetwork>',
    :'ssh_keys' => :'Array<SSHKey>',
    :'tenant_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
# File 'lib/ibm_cloud_power/models/tenant.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cloud_instances == o.cloud_instances &&
      creation_date == o.creation_date &&
      enabled == o.enabled &&
      icn == o.icn &&
      peering_networks == o.peering_networks &&
      ssh_keys == o.ssh_keys &&
      tenant_id == o.tenant_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/ibm_cloud_power/models/tenant.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/ibm_cloud_power/models/tenant.rb', line 237

def hash
  [cloud_instances, creation_date, enabled, icn, peering_networks, ssh_keys, tenant_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/ibm_cloud_power/models/tenant.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @cloud_instances.nil?
    invalid_properties.push('invalid value for "cloud_instances", cloud_instances cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/ibm_cloud_power/models/tenant.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
170
171
172
173
# File 'lib/ibm_cloud_power/models/tenant.rb', line 166

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @cloud_instances.nil?
  return false if @creation_date.nil?
  return false if @enabled.nil?
  return false if @tenant_id.nil?
  true
end