Class: IbmCloudPower::UpdateWorkspaceSSHKey

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/update_workspace_ssh_key.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateWorkspaceSSHKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::UpdateWorkspaceSSHKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::UpdateWorkspaceSSHKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'ssh_key')
    self.ssh_key = attributes[:'ssh_key']
  end

  if attributes.key?(:'visibility')
    self.visibility = attributes[:'visibility']
  else
    self.visibility = 'workspace'
  end
end

Instance Attribute Details

#descriptionObject

Description of the sshkey



19
20
21
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 19

def description
  @description
end

#nameObject

User defined name for the SSH key



22
23
24
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 22

def name
  @name
end

#ssh_keyObject

SSH RSA key



25
26
27
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 25

def ssh_key
  @ssh_key
end

#visibilityObject

Visibility of the sshkey; workspace suggests ssh-key is only accessible in a workspace, account suggests ssh-key is accessible throughout an account



28
29
30
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 28

def visibility
  @visibility
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 53

def self.attribute_map
  {
    :'description' => :'description',
    :'name' => :'name',
    :'ssh_key' => :'sshKey',
    :'visibility' => :'visibility'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 206

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 73

def self.openapi_types
  {
    :'description' => :'String',
    :'name' => :'String',
    :'ssh_key' => :'String',
    :'visibility' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      name == o.name &&
      ssh_key == o.ssh_key &&
      visibility == o.visibility
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


193
194
195
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 193

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



199
200
201
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 199

def hash
  [description, name, ssh_key, visibility].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9\-_][a-zA-Z0-9\-_]*$/)
  if !@name.nil? && @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
148
149
# File 'lib/ibm_cloud_power/models/update_workspace_ssh_key.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length > 128
  return false if !@name.nil? && @name !~ Regexp.new(/^[a-zA-Z0-9\-_][a-zA-Z0-9\-_]*$/)
  visibility_validator = EnumAttributeValidator.new('String', ["account", "workspace"])
  return false unless visibility_validator.valid?(@visibility)
  true
end