Class: IbmCloudPower::VPMemVolumeAttach
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::VPMemVolumeAttach
- Defined in:
- lib/ibm_cloud_power/models/vp_mem_volume_attach.rb
Instance Attribute Summary collapse
-
#user_tags ⇒ Object
List of user tags.
-
#vpmem_volumes ⇒ Object
Description of volumes to create.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VPMemVolumeAttach
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VPMemVolumeAttach
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VPMemVolumeAttach` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VPMemVolumeAttach`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end if attributes.key?(:'vpmem_volumes') if (value = attributes[:'vpmem_volumes']).is_a?(Array) self.vpmem_volumes = value end else self.vpmem_volumes = nil end end |
Instance Attribute Details
#user_tags ⇒ Object
List of user tags
19 20 21 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 19 def @user_tags end |
#vpmem_volumes ⇒ Object
Description of volumes to create
22 23 24 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 22 def vpmem_volumes @vpmem_volumes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 25 def self.attribute_map { :'user_tags' => :'userTags', :'vpmem_volumes' => :'vpmemVolumes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 43 def self.openapi_types { :'user_tags' => :'Array<String>', :'vpmem_volumes' => :'Array<VPMemVolumeCreate>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && vpmem_volumes == o.vpmem_volumes end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 153 def hash [, vpmem_volumes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 89 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end if @vpmem_volumes.nil? invalid_properties.push('invalid value for "vpmem_volumes", vpmem_volumes cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
105 106 107 108 109 110 |
# File 'lib/ibm_cloud_power/models/vp_mem_volume_attach.rb', line 105 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@user_tags.nil? && @user_tags.length > 100 return false if @vpmem_volumes.nil? true end |