Class: IbmCloudPower::VPNConnectionCreate

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/vpn_connection_create.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VPNConnectionCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VPNConnectionCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VPNConnectionCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ike_policy')
    self.ike_policy = attributes[:'ike_policy']
  else
    self.ike_policy = nil
  end

  if attributes.key?(:'ip_sec_policy')
    self.ip_sec_policy = attributes[:'ip_sec_policy']
  else
    self.ip_sec_policy = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'networks')
    if (value = attributes[:'networks']).is_a?(Array)
      self.networks = value
    end
  else
    self.networks = nil
  end

  if attributes.key?(:'peer_gateway_address')
    self.peer_gateway_address = attributes[:'peer_gateway_address']
  else
    self.peer_gateway_address = nil
  end

  if attributes.key?(:'peer_subnets')
    if (value = attributes[:'peer_subnets']).is_a?(Array)
      self.peer_subnets = value
    end
  else
    self.peer_subnets = nil
  end
end

Instance Attribute Details

#ike_policyObject

unique identifier of IKEPolicy selected for this VPNConnection



19
20
21
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 19

def ike_policy
  @ike_policy
end

#ip_sec_policyObject

unique identifier of IPSecPolicy selected for this VPNConnection



22
23
24
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 22

def ip_sec_policy
  @ip_sec_policy
end

#modeObject

Mode used by this VPNConnection, either policy-based, or route-based, this attribute is set at the creation and cannot be updated later.



25
26
27
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 25

def mode
  @mode
end

#nameObject

VPN Connection name



28
29
30
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 28

def name
  @name
end

#networksObject

an array of network IDs to attach to this VPNConnection



31
32
33
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 31

def networks
  @networks
end

#peer_gateway_addressObject

IP address of the Peer Gateway attached to this VPNConnection



34
35
36
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 34

def peer_gateway_address
  @peer_gateway_address
end

#peer_subnetsObject

an array of strings containing CIDR of peer subnets



37
38
39
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 37

def peer_subnets
  @peer_subnets
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 62

def self.attribute_map
  {
    :'ike_policy' => :'ikePolicy',
    :'ip_sec_policy' => :'ipSecPolicy',
    :'mode' => :'mode',
    :'name' => :'name',
    :'networks' => :'networks',
    :'peer_gateway_address' => :'peerGatewayAddress',
    :'peer_subnets' => :'peerSubnets'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 317

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 85

def self.openapi_types
  {
    :'ike_policy' => :'String',
    :'ip_sec_policy' => :'String',
    :'mode' => :'String',
    :'name' => :'String',
    :'networks' => :'Array<String>',
    :'peer_gateway_address' => :'String',
    :'peer_subnets' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
300
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ike_policy == o.ike_policy &&
      ip_sec_policy == o.ip_sec_policy &&
      mode == o.mode &&
      name == o.name &&
      networks == o.networks &&
      peer_gateway_address == o.peer_gateway_address &&
      peer_subnets == o.peer_subnets
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 304

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



310
311
312
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 310

def hash
  [ike_policy, ip_sec_policy, mode, name, networks, peer_gateway_address, peer_subnets].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ike_policy.nil?
    invalid_properties.push('invalid value for "ike_policy", ike_policy cannot be nil.')
  end

  if @ip_sec_policy.nil?
    invalid_properties.push('invalid value for "ip_sec_policy", ip_sec_policy cannot be nil.')
  end

  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @networks.nil?
    invalid_properties.push('invalid value for "networks", networks cannot be nil.')
  end

  if @peer_gateway_address.nil?
    invalid_properties.push('invalid value for "peer_gateway_address", peer_gateway_address cannot be nil.')
  end

  if @peer_subnets.nil?
    invalid_properties.push('invalid value for "peer_subnets", peer_subnets cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/ibm_cloud_power/models/vpn_connection_create.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ike_policy.nil?
  return false if @ip_sec_policy.nil?
  return false if @mode.nil?
  mode_validator = EnumAttributeValidator.new('String', ["policy", "route"])
  return false unless mode_validator.valid?(@mode)
  return false if @name.nil?
  return false if @networks.nil?
  return false if @peer_gateway_address.nil?
  return false if @peer_subnets.nil?
  true
end