Class: IbmCloudPower::VPNConnectionCreateResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_power/models/vpn_connection_create_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VPNConnectionCreateResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 138

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VPNConnectionCreateResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VPNConnectionCreateResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'dead_peer_detection')
    self.dead_peer_detection = attributes[:'dead_peer_detection']
  else
    self.dead_peer_detection = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'ike_policy')
    self.ike_policy = attributes[:'ike_policy']
  else
    self.ike_policy = nil
  end

  if attributes.key?(:'ip_sec_policy')
    self.ip_sec_policy = attributes[:'ip_sec_policy']
  else
    self.ip_sec_policy = nil
  end

  if attributes.key?(:'local_gateway_address')
    self.local_gateway_address = attributes[:'local_gateway_address']
  else
    self.local_gateway_address = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'network_ids')
    if (value = attributes[:'network_ids']).is_a?(Array)
      self.network_ids = value
    end
  else
    self.network_ids = nil
  end

  if attributes.key?(:'peer_gateway_address')
    self.peer_gateway_address = attributes[:'peer_gateway_address']
  else
    self.peer_gateway_address = nil
  end

  if attributes.key?(:'peer_subnets')
    if (value = attributes[:'peer_subnets']).is_a?(Array)
      self.peer_subnets = value
    end
  else
    self.peer_subnets = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'vpn_gateway_address')
    self.vpn_gateway_address = attributes[:'vpn_gateway_address']
  else
    self.vpn_gateway_address = nil
  end

  if attributes.key?(:'job_ref')
    self.job_ref = attributes[:'job_ref']
  end
end

Instance Attribute Details

#dead_peer_detectionObject

Returns the value of attribute dead_peer_detection.



18
19
20
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 18

def dead_peer_detection
  @dead_peer_detection
end

#idObject

unique identifier for VPN Connection



21
22
23
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 21

def id
  @id
end

#ike_policyObject

Returns the value of attribute ike_policy.



23
24
25
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 23

def ike_policy
  @ike_policy
end

#ip_sec_policyObject

Returns the value of attribute ip_sec_policy.



25
26
27
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 25

def ip_sec_policy
  @ip_sec_policy
end

#job_refObject

Returns the value of attribute job_ref.



51
52
53
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 51

def job_ref
  @job_ref
end

#local_gateway_addressObject

local Gateway address, only in 'route' mode.



28
29
30
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 28

def local_gateway_address
  @local_gateway_address
end

#modeObject

Mode used by this VPNConnection, either policy-based, or route-based, this attribute is set at the creation and cannot be updated later.



31
32
33
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 31

def mode
  @mode
end

#nameObject

VPN Connection name



34
35
36
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 34

def name
  @name
end

#network_idsObject

an array of network IDs



37
38
39
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 37

def network_ids
  @network_ids
end

#peer_gateway_addressObject

IP address of the Peer Gateway attached to this VPNConnection



40
41
42
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 40

def peer_gateway_address
  @peer_gateway_address
end

#peer_subnetsObject

an array of strings containing CIDR of peer subnets



43
44
45
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 43

def peer_subnets
  @peer_subnets
end

#statusObject

status of the VPN connection



46
47
48
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 46

def status
  @status
end

#vpn_gateway_addressObject

public IP address of the VPN Gateway (vSRX) attached to this VPNConnection



49
50
51
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 49

def vpn_gateway_address
  @vpn_gateway_address
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 76

def self.attribute_map
  {
    :'dead_peer_detection' => :'deadPeerDetection',
    :'id' => :'id',
    :'ike_policy' => :'ikePolicy',
    :'ip_sec_policy' => :'ipSecPolicy',
    :'local_gateway_address' => :'localGatewayAddress',
    :'mode' => :'mode',
    :'name' => :'name',
    :'network_ids' => :'networkIDs',
    :'peer_gateway_address' => :'peerGatewayAddress',
    :'peer_subnets' => :'peerSubnets',
    :'status' => :'status',
    :'vpn_gateway_address' => :'vpnGatewayAddress',
    :'job_ref' => :'jobRef'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 467

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



130
131
132
133
134
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 130

def self.openapi_all_of
  [
  :'VPNConnection'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 124

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 105

def self.openapi_types
  {
    :'dead_peer_detection' => :'DeadPeerDetection',
    :'id' => :'String',
    :'ike_policy' => :'IKEPolicyRef',
    :'ip_sec_policy' => :'IPSecPolicyRef',
    :'local_gateway_address' => :'String',
    :'mode' => :'String',
    :'name' => :'String',
    :'network_ids' => :'Array<String>',
    :'peer_gateway_address' => :'String',
    :'peer_subnets' => :'Array<String>',
    :'status' => :'String',
    :'vpn_gateway_address' => :'String',
    :'job_ref' => :'JobReference'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 434

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      dead_peer_detection == o.dead_peer_detection &&
      id == o.id &&
      ike_policy == o.ike_policy &&
      ip_sec_policy == o.ip_sec_policy &&
      local_gateway_address == o.local_gateway_address &&
      mode == o.mode &&
      name == o.name &&
      network_ids == o.network_ids &&
      peer_gateway_address == o.peer_gateway_address &&
      peer_subnets == o.peer_subnets &&
      status == o.status &&
      vpn_gateway_address == o.vpn_gateway_address &&
      job_ref == o.job_ref
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


454
455
456
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 454

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



460
461
462
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 460

def hash
  [dead_peer_detection, id, ike_policy, ip_sec_policy, local_gateway_address, mode, name, network_ids, peer_gateway_address, peer_subnets, status, vpn_gateway_address, job_ref].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 235

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @dead_peer_detection.nil?
    invalid_properties.push('invalid value for "dead_peer_detection", dead_peer_detection cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @ike_policy.nil?
    invalid_properties.push('invalid value for "ike_policy", ike_policy cannot be nil.')
  end

  if @ip_sec_policy.nil?
    invalid_properties.push('invalid value for "ip_sec_policy", ip_sec_policy cannot be nil.')
  end

  if @local_gateway_address.nil?
    invalid_properties.push('invalid value for "local_gateway_address", local_gateway_address cannot be nil.')
  end

  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @network_ids.nil?
    invalid_properties.push('invalid value for "network_ids", network_ids cannot be nil.')
  end

  if @peer_gateway_address.nil?
    invalid_properties.push('invalid value for "peer_gateway_address", peer_gateway_address cannot be nil.')
  end

  if @peer_subnets.nil?
    invalid_properties.push('invalid value for "peer_subnets", peer_subnets cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @vpn_gateway_address.nil?
    invalid_properties.push('invalid value for "vpn_gateway_address", vpn_gateway_address cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 489

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/ibm_cloud_power/models/vpn_connection_create_response.rb', line 291

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @dead_peer_detection.nil?
  return false if @id.nil?
  return false if @ike_policy.nil?
  return false if @ip_sec_policy.nil?
  return false if @local_gateway_address.nil?
  return false if @mode.nil?
  mode_validator = EnumAttributeValidator.new('String', ["policy", "route"])
  return false unless mode_validator.valid?(@mode)
  return false if @name.nil?
  return false if @network_ids.nil?
  return false if @peer_gateway_address.nil?
  return false if @peer_subnets.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["active", "warning", "disabled"])
  return false unless status_validator.valid?(@status)
  return false if @vpn_gateway_address.nil?
  true
end