Class: IbmCloudPower::Volume

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/volume.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Volume

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/ibm_cloud_power/models/volume.rb', line 215

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Volume` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Volume`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aux_volume_name')
    self.aux_volume_name = attributes[:'aux_volume_name']
  end

  if attributes.key?(:'auxiliary')
    self.auxiliary = attributes[:'auxiliary']
  end

  if attributes.key?(:'boot_volume')
    self.boot_volume = attributes[:'boot_volume']
  end

  if attributes.key?(:'bootable')
    self.bootable = attributes[:'bootable']
  end

  if attributes.key?(:'consistency_group_name')
    self.consistency_group_name = attributes[:'consistency_group_name']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  end

  if attributes.key?(:'disk_type')
    self.disk_type = attributes[:'disk_type']
  end

  if attributes.key?(:'freeze_time')
    self.freeze_time = attributes[:'freeze_time']
  end

  if attributes.key?(:'group_id')
    self.group_id = attributes[:'group_id']
  end

  if attributes.key?(:'io_throttle_rate')
    self.io_throttle_rate = attributes[:'io_throttle_rate']
  end

  if attributes.key?(:'last_update_date')
    self.last_update_date = attributes[:'last_update_date']
  else
    self.last_update_date = nil
  end

  if attributes.key?(:'master_volume_name')
    self.master_volume_name = attributes[:'master_volume_name']
  end

  if attributes.key?(:'mirroring_state')
    self.mirroring_state = attributes[:'mirroring_state']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'out_of_band_deleted')
    self.out_of_band_deleted = attributes[:'out_of_band_deleted']
  end

  if attributes.key?(:'primary_role')
    self.primary_role = attributes[:'primary_role']
  end

  if attributes.key?(:'pvm_instance_ids')
    if (value = attributes[:'pvm_instance_ids']).is_a?(Array)
      self.pvm_instance_ids = value
    end
  end

  if attributes.key?(:'replication_enabled')
    self.replication_enabled = attributes[:'replication_enabled']
  end

  if attributes.key?(:'replication_status')
    self.replication_status = attributes[:'replication_status']
  end

  if attributes.key?(:'replication_type')
    self.replication_type = attributes[:'replication_type']
  end

  if attributes.key?(:'shareable')
    self.shareable = attributes[:'shareable']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end

  if attributes.key?(:'volume_id')
    self.volume_id = attributes[:'volume_id']
  else
    self.volume_id = nil
  end

  if attributes.key?(:'volume_pool')
    self.volume_pool = attributes[:'volume_pool']
  end

  if attributes.key?(:'volume_type')
    self.volume_type = attributes[:'volume_type']
  end

  if attributes.key?(:'wwn')
    self.wwn = attributes[:'wwn']
  end
end

Instance Attribute Details

#aux_volume_nameObject

Auxiliary volume name at storage host level



19
20
21
# File 'lib/ibm_cloud_power/models/volume.rb', line 19

def aux_volume_name
  @aux_volume_name
end

#auxiliaryObject

true if volume is auxiliary otherwise false



22
23
24
# File 'lib/ibm_cloud_power/models/volume.rb', line 22

def auxiliary
  @auxiliary
end

#boot_volumeObject

Indicates if the volume is the server's boot volume. Only returned when querying a server's attached volumes



25
26
27
# File 'lib/ibm_cloud_power/models/volume.rb', line 25

def boot_volume
  @boot_volume
end

#bootableObject

Indicates if the volume is boot capable



28
29
30
# File 'lib/ibm_cloud_power/models/volume.rb', line 28

def bootable
  @bootable
end

#consistency_group_nameObject

Consistency Group Name if volume is a part of volume group



31
32
33
# File 'lib/ibm_cloud_power/models/volume.rb', line 31

def consistency_group_name
  @consistency_group_name
end

#creation_dateObject

Creation Date



34
35
36
# File 'lib/ibm_cloud_power/models/volume.rb', line 34

def creation_date
  @creation_date
end

#crnObject

The CRN for this resource



37
38
39
# File 'lib/ibm_cloud_power/models/volume.rb', line 37

def crn
  @crn
end

#disk_typeObject

Type of Disk



40
41
42
# File 'lib/ibm_cloud_power/models/volume.rb', line 40

def disk_type
  @disk_type
end

#freeze_timeObject

Freeze time of remote copy relationship



43
44
45
# File 'lib/ibm_cloud_power/models/volume.rb', line 43

def freeze_time
  @freeze_time
end

#group_idObject

Volume Group ID



46
47
48
# File 'lib/ibm_cloud_power/models/volume.rb', line 46

def group_id
  @group_id
end

#io_throttle_rateObject

Amount of iops assigned to the volume



49
50
51
# File 'lib/ibm_cloud_power/models/volume.rb', line 49

def io_throttle_rate
  @io_throttle_rate
end

#last_update_dateObject

Last Update Date



52
53
54
# File 'lib/ibm_cloud_power/models/volume.rb', line 52

def last_update_date
  @last_update_date
end

#master_volume_nameObject

Master volume name at storage host level



55
56
57
# File 'lib/ibm_cloud_power/models/volume.rb', line 55

def master_volume_name
  @master_volume_name
end

#mirroring_stateObject

Mirroring state for replication enabled volume



58
59
60
# File 'lib/ibm_cloud_power/models/volume.rb', line 58

def mirroring_state
  @mirroring_state
end

#nameObject

Volume Name



61
62
63
# File 'lib/ibm_cloud_power/models/volume.rb', line 61

def name
  @name
end

#out_of_band_deletedObject

true if volume does not exist on storage controller, as volume has been deleted by deleting its paired volume from the mapped replication site.



64
65
66
# File 'lib/ibm_cloud_power/models/volume.rb', line 64

def out_of_band_deleted
  @out_of_band_deleted
end

#primary_roleObject

indicates whether master/aux volume is playing the primary role



67
68
69
# File 'lib/ibm_cloud_power/models/volume.rb', line 67

def primary_role
  @primary_role
end

#pvm_instance_idsObject

List of PCloud PVM Instance attached to the volume



70
71
72
# File 'lib/ibm_cloud_power/models/volume.rb', line 70

def pvm_instance_ids
  @pvm_instance_ids
end

#replication_enabledObject

True if volume is replication enabled otherwise false



73
74
75
# File 'lib/ibm_cloud_power/models/volume.rb', line 73

def replication_enabled
  @replication_enabled
end

#replication_statusObject

Replication status of a volume



76
77
78
# File 'lib/ibm_cloud_power/models/volume.rb', line 76

def replication_status
  @replication_status
end

#replication_typeObject

type of replication(metro,global)



79
80
81
# File 'lib/ibm_cloud_power/models/volume.rb', line 79

def replication_type
  @replication_type
end

#shareableObject

Indicates if the volume is shareable between VMs



82
83
84
# File 'lib/ibm_cloud_power/models/volume.rb', line 82

def shareable
  @shareable
end

#sizeObject

Volume Size



85
86
87
# File 'lib/ibm_cloud_power/models/volume.rb', line 85

def size
  @size
end

#stateObject

Volume State



88
89
90
# File 'lib/ibm_cloud_power/models/volume.rb', line 88

def state
  @state
end

#user_tagsObject

List of user tags



91
92
93
# File 'lib/ibm_cloud_power/models/volume.rb', line 91

def user_tags
  @user_tags
end

#volume_idObject

Volume ID



94
95
96
# File 'lib/ibm_cloud_power/models/volume.rb', line 94

def volume_id
  @volume_id
end

#volume_poolObject

Volume pool, name of storage pool where the volume is located



97
98
99
# File 'lib/ibm_cloud_power/models/volume.rb', line 97

def volume_pool
  @volume_pool
end

#volume_typeObject

Volume type, name of storage template used to create the volume



100
101
102
# File 'lib/ibm_cloud_power/models/volume.rb', line 100

def volume_type
  @volume_type
end

#wwnObject

Volume world wide name



103
104
105
# File 'lib/ibm_cloud_power/models/volume.rb', line 103

def wwn
  @wwn
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



163
164
165
# File 'lib/ibm_cloud_power/models/volume.rb', line 163

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



168
169
170
# File 'lib/ibm_cloud_power/models/volume.rb', line 168

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/ibm_cloud_power/models/volume.rb', line 128

def self.attribute_map
  {
    :'aux_volume_name' => :'auxVolumeName',
    :'auxiliary' => :'auxiliary',
    :'boot_volume' => :'bootVolume',
    :'bootable' => :'bootable',
    :'consistency_group_name' => :'consistencyGroupName',
    :'creation_date' => :'creationDate',
    :'crn' => :'crn',
    :'disk_type' => :'diskType',
    :'freeze_time' => :'freezeTime',
    :'group_id' => :'groupID',
    :'io_throttle_rate' => :'ioThrottleRate',
    :'last_update_date' => :'lastUpdateDate',
    :'master_volume_name' => :'masterVolumeName',
    :'mirroring_state' => :'mirroringState',
    :'name' => :'name',
    :'out_of_band_deleted' => :'outOfBandDeleted',
    :'primary_role' => :'primaryRole',
    :'pvm_instance_ids' => :'pvmInstanceIDs',
    :'replication_enabled' => :'replicationEnabled',
    :'replication_status' => :'replicationStatus',
    :'replication_type' => :'replicationType',
    :'shareable' => :'shareable',
    :'size' => :'size',
    :'state' => :'state',
    :'user_tags' => :'userTags',
    :'volume_id' => :'volumeID',
    :'volume_pool' => :'volumePool',
    :'volume_type' => :'volumeType',
    :'wwn' => :'wwn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'lib/ibm_cloud_power/models/volume.rb', line 532

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



208
209
210
211
# File 'lib/ibm_cloud_power/models/volume.rb', line 208

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/ibm_cloud_power/models/volume.rb', line 173

def self.openapi_types
  {
    :'aux_volume_name' => :'String',
    :'auxiliary' => :'Boolean',
    :'boot_volume' => :'Boolean',
    :'bootable' => :'Boolean',
    :'consistency_group_name' => :'String',
    :'creation_date' => :'Time',
    :'crn' => :'String',
    :'disk_type' => :'String',
    :'freeze_time' => :'Time',
    :'group_id' => :'String',
    :'io_throttle_rate' => :'String',
    :'last_update_date' => :'Time',
    :'master_volume_name' => :'String',
    :'mirroring_state' => :'String',
    :'name' => :'String',
    :'out_of_band_deleted' => :'Boolean',
    :'primary_role' => :'String',
    :'pvm_instance_ids' => :'Array<String>',
    :'replication_enabled' => :'Boolean',
    :'replication_status' => :'String',
    :'replication_type' => :'String',
    :'shareable' => :'Boolean',
    :'size' => :'Float',
    :'state' => :'String',
    :'user_tags' => :'Array<String>',
    :'volume_id' => :'String',
    :'volume_pool' => :'String',
    :'volume_type' => :'String',
    :'wwn' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'lib/ibm_cloud_power/models/volume.rb', line 483

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aux_volume_name == o.aux_volume_name &&
      auxiliary == o.auxiliary &&
      boot_volume == o.boot_volume &&
      bootable == o.bootable &&
      consistency_group_name == o.consistency_group_name &&
      creation_date == o.creation_date &&
      crn == o.crn &&
      disk_type == o.disk_type &&
      freeze_time == o.freeze_time &&
      group_id == o.group_id &&
      io_throttle_rate == o.io_throttle_rate &&
      last_update_date == o.last_update_date &&
      master_volume_name == o.master_volume_name &&
      mirroring_state == o.mirroring_state &&
      name == o.name &&
      out_of_band_deleted == o.out_of_band_deleted &&
      primary_role == o.primary_role &&
      pvm_instance_ids == o.pvm_instance_ids &&
      replication_enabled == o.replication_enabled &&
      replication_status == o.replication_status &&
      replication_type == o.replication_type &&
      shareable == o.shareable &&
      size == o.size &&
      state == o.state &&
      user_tags == o.user_tags &&
      volume_id == o.volume_id &&
      volume_pool == o.volume_pool &&
      volume_type == o.volume_type &&
      wwn == o.wwn
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


519
520
521
# File 'lib/ibm_cloud_power/models/volume.rb', line 519

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



525
526
527
# File 'lib/ibm_cloud_power/models/volume.rb', line 525

def hash
  [aux_volume_name, auxiliary, boot_volume, bootable, consistency_group_name, creation_date, crn, disk_type, freeze_time, group_id, io_throttle_rate, last_update_date, master_volume_name, mirroring_state, name, out_of_band_deleted, primary_role, pvm_instance_ids, replication_enabled, replication_status, replication_type, shareable, size, state, user_tags, volume_id, volume_pool, volume_type, wwn].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/ibm_cloud_power/models/volume.rb', line 362

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @last_update_date.nil?
    invalid_properties.push('invalid value for "last_update_date", last_update_date cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  if !@user_tags.nil? && @user_tags.length > 100
    invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.')
  end

  if @volume_id.nil?
    invalid_properties.push('invalid value for "volume_id", volume_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/ibm_cloud_power/models/volume.rb', line 554

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/ibm_cloud_power/models/volume.rb', line 394

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @creation_date.nil?
  return false if @last_update_date.nil?
  return false if @name.nil?
  primary_role_validator = EnumAttributeValidator.new('String', ["master", "aux"])
  return false unless primary_role_validator.valid?(@primary_role)
  return false if @size.nil?
  return false if !@user_tags.nil? && @user_tags.length > 100
  return false if @volume_id.nil?
  true
end