Class: IbmCloudPower::VolumeGroupDetails

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/volume_group_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VolumeGroupDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VolumeGroupDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VolumeGroupDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auxiliary')
    self.auxiliary = attributes[:'auxiliary']
  end

  if attributes.key?(:'consistency_group_name')
    self.consistency_group_name = attributes[:'consistency_group_name']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'replication_sites')
    if (value = attributes[:'replication_sites']).is_a?(Array)
      self.replication_sites = value
    end
  end

  if attributes.key?(:'replication_status')
    self.replication_status = attributes[:'replication_status']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'status_description')
    self.status_description = attributes[:'status_description']
  end

  if attributes.key?(:'storage_pool')
    self.storage_pool = attributes[:'storage_pool']
  end

  if attributes.key?(:'volume_ids')
    if (value = attributes[:'volume_ids']).is_a?(Array)
      self.volume_ids = value
    end
  end
end

Instance Attribute Details

#auxiliaryObject

Indicates whether the volume group is for auxiliary volumes or master volumes



19
20
21
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 19

def auxiliary
  @auxiliary
end

#consistency_group_nameObject

The name of volume group at storage host level



22
23
24
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 22

def consistency_group_name
  @consistency_group_name
end

#idObject

The ID of the volume group



25
26
27
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 25

def id
  @id
end

#nameObject

The name of the volume group



28
29
30
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 28

def name
  @name
end

#replication_sitesObject

Indicates the replication site of the volume group



31
32
33
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 31

def replication_sites
  @replication_sites
end

#replication_statusObject

Replication status of volume group



34
35
36
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 34

def replication_status
  @replication_status
end

#statusObject

Status of the volume group



37
38
39
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 37

def status
  @status
end

#status_descriptionObject

Status details of the volume group



40
41
42
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 40

def status_description
  @status_description
end

#storage_poolObject

Indicates the storage pool of the volume group



43
44
45
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 43

def storage_pool
  @storage_pool
end

#volume_idsObject

List of volume IDs,member of VolumeGroup



46
47
48
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 46

def volume_ids
  @volume_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 49

def self.attribute_map
  {
    :'auxiliary' => :'auxiliary',
    :'consistency_group_name' => :'consistencyGroupName',
    :'id' => :'id',
    :'name' => :'name',
    :'replication_sites' => :'replicationSites',
    :'replication_status' => :'replicationStatus',
    :'status' => :'status',
    :'status_description' => :'statusDescription',
    :'storage_pool' => :'storagePool',
    :'volume_ids' => :'volumeIDs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 75

def self.openapi_types
  {
    :'auxiliary' => :'Boolean',
    :'consistency_group_name' => :'String',
    :'id' => :'String',
    :'name' => :'String',
    :'replication_sites' => :'Array<String>',
    :'replication_status' => :'String',
    :'status' => :'String',
    :'status_description' => :'StatusDescription',
    :'storage_pool' => :'String',
    :'volume_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auxiliary == o.auxiliary &&
      consistency_group_name == o.consistency_group_name &&
      id == o.id &&
      name == o.name &&
      replication_sites == o.replication_sites &&
      replication_status == o.replication_status &&
      status == o.status &&
      status_description == o.status_description &&
      storage_pool == o.storage_pool &&
      volume_ids == o.volume_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 231

def hash
  [auxiliary, consistency_group_name, id, name, replication_sites, replication_status, status, status_description, storage_pool, volume_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
# File 'lib/ibm_cloud_power/models/volume_group_details.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  true
end