Class: IbmCloudPower::VolumeGroupStorageDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::VolumeGroupStorageDetails
- Defined in:
- lib/ibm_cloud_power/models/volume_group_storage_details.rb
Instance Attribute Summary collapse
-
#consistency_group_name ⇒ Object
The name of consistency group at storage controller level.
-
#cycle_period_seconds ⇒ Object
Indicates the minimum period in seconds between multiple cycles.
-
#cycling_mode ⇒ Object
Indicates the type of cycling mode used.
-
#num_ofvols ⇒ Object
Number of volumes in volume group.
-
#primary_role ⇒ Object
Indicates whether master/aux volume is playing the primary role.
-
#remote_copy_relationship_names ⇒ Object
List of remote-copy relationship names in a volume group.
-
#replication_type ⇒ Object
Type of replication(metro,global).
-
#state ⇒ Object
Indicates the relationship state.
-
#sync ⇒ Object
Indicates whether the relationship is synchronized.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeGroupStorageDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumeGroupStorageDetails
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VolumeGroupStorageDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VolumeGroupStorageDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'consistency_group_name') self.consistency_group_name = attributes[:'consistency_group_name'] else self.consistency_group_name = nil end if attributes.key?(:'cycle_period_seconds') self.cycle_period_seconds = attributes[:'cycle_period_seconds'] end if attributes.key?(:'cycling_mode') self.cycling_mode = attributes[:'cycling_mode'] end if attributes.key?(:'num_ofvols') self.num_ofvols = attributes[:'num_ofvols'] end if attributes.key?(:'primary_role') self.primary_role = attributes[:'primary_role'] end if attributes.key?(:'remote_copy_relationship_names') if (value = attributes[:'remote_copy_relationship_names']).is_a?(Array) self.remote_copy_relationship_names = value end end if attributes.key?(:'replication_type') self.replication_type = attributes[:'replication_type'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'sync') self.sync = attributes[:'sync'] end end |
Instance Attribute Details
#consistency_group_name ⇒ Object
The name of consistency group at storage controller level
19 20 21 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 19 def consistency_group_name @consistency_group_name end |
#cycle_period_seconds ⇒ Object
Indicates the minimum period in seconds between multiple cycles
22 23 24 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 22 def cycle_period_seconds @cycle_period_seconds end |
#cycling_mode ⇒ Object
Indicates the type of cycling mode used
25 26 27 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 25 def cycling_mode @cycling_mode end |
#num_ofvols ⇒ Object
Number of volumes in volume group
28 29 30 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 28 def num_ofvols @num_ofvols end |
#primary_role ⇒ Object
Indicates whether master/aux volume is playing the primary role
31 32 33 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 31 def primary_role @primary_role end |
#remote_copy_relationship_names ⇒ Object
List of remote-copy relationship names in a volume group
34 35 36 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 34 def remote_copy_relationship_names @remote_copy_relationship_names end |
#replication_type ⇒ Object
Type of replication(metro,global)
37 38 39 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 37 def replication_type @replication_type end |
#state ⇒ Object
Indicates the relationship state
40 41 42 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 40 def state @state end |
#sync ⇒ Object
Indicates whether the relationship is synchronized
43 44 45 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 43 def sync @sync end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 46 def self.attribute_map { :'consistency_group_name' => :'consistencyGroupName', :'cycle_period_seconds' => :'cyclePeriodSeconds', :'cycling_mode' => :'cyclingMode', :'num_ofvols' => :'numOfvols', :'primary_role' => :'primaryRole', :'remote_copy_relationship_names' => :'remoteCopyRelationshipNames', :'replication_type' => :'replicationType', :'state' => :'state', :'sync' => :'sync' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 209 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 71 def self.openapi_types { :'consistency_group_name' => :'String', :'cycle_period_seconds' => :'Integer', :'cycling_mode' => :'String', :'num_ofvols' => :'Integer', :'primary_role' => :'String', :'remote_copy_relationship_names' => :'Array<String>', :'replication_type' => :'String', :'state' => :'String', :'sync' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && consistency_group_name == o.consistency_group_name && cycle_period_seconds == o.cycle_period_seconds && cycling_mode == o.cycling_mode && num_ofvols == o.num_ofvols && primary_role == o.primary_role && remote_copy_relationship_names == o.remote_copy_relationship_names && replication_type == o.replication_type && state == o.state && sync == o.sync end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 202 def hash [consistency_group_name, cycle_period_seconds, cycling_mode, num_ofvols, primary_role, remote_copy_relationship_names, replication_type, state, sync].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 155 156 157 158 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 150 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @consistency_group_name.nil? invalid_properties.push('invalid value for "consistency_group_name", consistency_group_name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 231 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 |
# File 'lib/ibm_cloud_power/models/volume_group_storage_details.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @consistency_group_name.nil? true end |