Class: IbmCloudPower::VolumeOnboardingCreate

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/volume_onboarding_create.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VolumeOnboardingCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VolumeOnboardingCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VolumeOnboardingCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'volumes')
    if (value = attributes[:'volumes']).is_a?(Array)
      self.volumes = value
    end
  else
    self.volumes = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'user_tags')
    if (value = attributes[:'user_tags']).is_a?(Array)
      self.user_tags = value
    end
  end
end

Instance Attribute Details

#descriptionObject

Description of the volume onboarding operation



21
22
23
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 21

def description
  @description
end

#user_tagsObject

List of user tags



24
25
26
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 24

def user_tags
  @user_tags
end

#volumesObject

Returns the value of attribute volumes.



18
19
20
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 18

def volumes
  @volumes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



36
37
38
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 36

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 41

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 27

def self.attribute_map
  {
    :'volumes' => :'Volumes',
    :'description' => :'description',
    :'user_tags' => :'userTags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



55
56
57
58
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 46

def self.openapi_types
  {
    :'volumes' => :'Array<VolumeOnboardingCreateVolumesInner>',
    :'description' => :'String',
    :'user_tags' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      volumes == o.volumes &&
      description == o.description &&
      user_tags == o.user_tags
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 162

def hash
  [volumes, description, user_tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @volumes.nil?
    invalid_properties.push('invalid value for "volumes", volumes cannot be nil.')
  end

  if !@user_tags.nil? && @user_tags.length > 100
    invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



113
114
115
116
117
118
# File 'lib/ibm_cloud_power/models/volume_onboarding_create.rb', line 113

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @volumes.nil?
  return false if !@user_tags.nil? && @user_tags.length > 100
  true
end