Class: IbmCloudPower::VolumesClone
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::VolumesClone
- Defined in:
- lib/ibm_cloud_power/models/volumes_clone.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
Current action performed for the volumes-clone request.
-
#creation_date ⇒ Object
Creation Date.
-
#failure_message ⇒ Object
Failure reason for a failed volumes-clone request.
-
#last_update_date ⇒ Object
Last Update Date.
-
#name ⇒ Object
Name assigned to a volumes-clone request.
-
#percent_complete ⇒ Object
The percent completion for the current action.
-
#status ⇒ Object
Current status of the volumes-clone request.
-
#volumes_clone_id ⇒ Object
ID assigned to a volumes-clone request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumesClone
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumesClone
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VolumesClone` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VolumesClone`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'failure_message') self. = attributes[:'failure_message'] end if attributes.key?(:'last_update_date') self.last_update_date = attributes[:'last_update_date'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] else self.percent_complete = nil end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'volumes_clone_id') self.volumes_clone_id = attributes[:'volumes_clone_id'] end end |
Instance Attribute Details
#action ⇒ Object
Current action performed for the volumes-clone request
19 20 21 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 19 def action @action end |
#creation_date ⇒ Object
Creation Date
22 23 24 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 22 def creation_date @creation_date end |
#failure_message ⇒ Object
Failure reason for a failed volumes-clone request
25 26 27 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 25 def @failure_message end |
#last_update_date ⇒ Object
Last Update Date
28 29 30 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 28 def last_update_date @last_update_date end |
#name ⇒ Object
Name assigned to a volumes-clone request
31 32 33 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 31 def name @name end |
#percent_complete ⇒ Object
The percent completion for the current action
34 35 36 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 34 def percent_complete @percent_complete end |
#status ⇒ Object
Current status of the volumes-clone request
37 38 39 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 37 def status @status end |
#volumes_clone_id ⇒ Object
ID assigned to a volumes-clone request
40 41 42 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 40 def volumes_clone_id @volumes_clone_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 43 def self.attribute_map { :'action' => :'action', :'creation_date' => :'creationDate', :'failure_message' => :'failureMessage', :'last_update_date' => :'lastUpdateDate', :'name' => :'name', :'percent_complete' => :'percentComplete', :'status' => :'status', :'volumes_clone_id' => :'volumesCloneID' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 197 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 67 def self.openapi_types { :'action' => :'String', :'creation_date' => :'Time', :'failure_message' => :'String', :'last_update_date' => :'Time', :'name' => :'String', :'percent_complete' => :'Integer', :'status' => :'String', :'volumes_clone_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && creation_date == o.creation_date && == o. && last_update_date == o.last_update_date && name == o.name && percent_complete == o.percent_complete && status == o.status && volumes_clone_id == o.volumes_clone_id end |
#eql?(o) ⇒ Boolean
184 185 186 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 184 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 190 def hash [action, creation_date, , last_update_date, name, percent_complete, status, volumes_clone_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 144 145 146 147 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @percent_complete.nil? invalid_properties.push('invalid value for "percent_complete", percent_complete cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 219 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 |
# File 'lib/ibm_cloud_power/models/volumes_clone.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @percent_complete.nil? true end |