Class: IbmCloudPower::VolumesCloneAsyncRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::VolumesCloneAsyncRequest
- Defined in:
- lib/ibm_cloud_power/models/volumes_clone_async_request.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
Base name of the new cloned volume(s).
-
#target_replication_enabled ⇒ Object
Cloned volume will be non replication enabled if it is set to false.
-
#target_storage_tier ⇒ Object
Target storage tier for the cloned volumes.
-
#user_tags ⇒ Object
List of user tags.
-
#volume_ids ⇒ Object
List of volumes to be cloned.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumesCloneAsyncRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumesCloneAsyncRequest
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VolumesCloneAsyncRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VolumesCloneAsyncRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'target_replication_enabled') self.target_replication_enabled = attributes[:'target_replication_enabled'] end if attributes.key?(:'target_storage_tier') self.target_storage_tier = attributes[:'target_storage_tier'] end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end if attributes.key?(:'volume_ids') if (value = attributes[:'volume_ids']).is_a?(Array) self.volume_ids = value end else self.volume_ids = nil end end |
Instance Attribute Details
#name ⇒ Object
Base name of the new cloned volume(s). Cloned Volume names will be prefixed with 'clone-' and suffixed with '-#####' (where ##### is a 5 digit random number) If multiple volumes cloned they will be further suffixed with an incremental number starting with 1. Example volume names using name="volume-abcdef" single volume clone will be named "clone-volume-abcdef-83081" multi volume clone will be named "clone-volume-abcdef-73721-1", "clone-volume-abcdef-73721-2", ... For multiple volume clone, the provided name will be truncated to the first 20 characters.
19 20 21 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 19 def name @name end |
#target_replication_enabled ⇒ Object
Cloned volume will be non replication enabled if it is set to false. By default, the replication property of the source volume will be used to determine the replication property of the cloned target volume.
22 23 24 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 22 def target_replication_enabled @target_replication_enabled end |
#target_storage_tier ⇒ Object
Target storage tier for the cloned volumes. Use to clone a set of volumes from one storage tier to a different storage tier. Cloned volumes must remain in the same storage pool as the source volumes.
25 26 27 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 25 def target_storage_tier @target_storage_tier end |
#user_tags ⇒ Object
List of user tags
28 29 30 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 28 def @user_tags end |
#volume_ids ⇒ Object
List of volumes to be cloned
31 32 33 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 31 def volume_ids @volume_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 34 def self.attribute_map { :'name' => :'name', :'target_replication_enabled' => :'targetReplicationEnabled', :'target_storage_tier' => :'targetStorageTier', :'user_tags' => :'userTags', :'volume_ids' => :'volumeIDs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 55 def self.openapi_types { :'name' => :'String', :'target_replication_enabled' => :'Boolean', :'target_storage_tier' => :'String', :'user_tags' => :'Array<String>', :'volume_ids' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 182 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && target_replication_enabled == o.target_replication_enabled && target_storage_tier == o.target_storage_tier && == o. && volume_ids == o.volume_ids end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 200 def hash [name, target_replication_enabled, target_storage_tier, , volume_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end if @volume_ids.nil? invalid_properties.push('invalid value for "volume_ids", volume_ids cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 229 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 143 144 |
# File 'lib/ibm_cloud_power/models/volumes_clone_async_request.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if !@user_tags.nil? && @user_tags.length > 100 return false if @volume_ids.nil? true end |