Class: IbmCloudPower::VolumesDetach

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/volumes_detach.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VolumesDetach

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VolumesDetach` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VolumesDetach`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'detach_all_volumes')
    self.detach_all_volumes = attributes[:'detach_all_volumes']
  else
    self.detach_all_volumes = false
  end

  if attributes.key?(:'detach_primary_boot_volume')
    self.detach_primary_boot_volume = attributes[:'detach_primary_boot_volume']
  else
    self.detach_primary_boot_volume = false
  end

  if attributes.key?(:'volume_ids')
    if (value = attributes[:'volume_ids']).is_a?(Array)
      self.volume_ids = value
    end
  end
end

Instance Attribute Details

#detach_all_volumesObject

Indicates if all volumes, except primary boot volume, attached to the PVMInstance should be detached (default=false); required if volumeIDs is not provided



19
20
21
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 19

def detach_all_volumes
  @detach_all_volumes
end

#detach_primary_boot_volumeObject

Indicates if primary boot volume attached to the PVMInstance should be detached (default=false)



22
23
24
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 22

def detach_primary_boot_volume
  @detach_primary_boot_volume
end

#volume_idsObject

List of volumes to be detached from a PVM instance; required if detachAllVolumes is not provided



25
26
27
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 25

def volume_ids
  @volume_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 28

def self.attribute_map
  {
    :'detach_all_volumes' => :'detachAllVolumes',
    :'detach_primary_boot_volume' => :'detachPrimaryBootVolume',
    :'volume_ids' => :'volumeIDs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 136

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 47

def self.openapi_types
  {
    :'detach_all_volumes' => :'Boolean',
    :'detach_primary_boot_volume' => :'Boolean',
    :'volume_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



113
114
115
116
117
118
119
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 113

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      detach_all_volumes == o.detach_all_volumes &&
      detach_primary_boot_volume == o.detach_primary_boot_volume &&
      volume_ids == o.volume_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


123
124
125
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 123

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



129
130
131
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 129

def hash
  [detach_all_volumes, detach_primary_boot_volume, volume_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



98
99
100
101
102
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 98

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 158

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



106
107
108
109
# File 'lib/ibm_cloud_power/models/volumes_detach.rb', line 106

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end