Class: IbmCloudPower::Workspace
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::Workspace
- Defined in:
- lib/ibm_cloud_power/models/workspace.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
Workspace Capabilities.
-
#details ⇒ Object
The Workspace information.
-
#id ⇒ Object
Workspace ID.
-
#location ⇒ Object
The Workspace location.
-
#name ⇒ Object
The Workspace name.
-
#status ⇒ Object
The Workspace status.
-
#type ⇒ Object
The Workspace type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Workspace
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Workspace
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Workspace` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Workspace`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'capabilities') if (value = attributes[:'capabilities']).is_a?(Hash) self.capabilities = value end else self.capabilities = nil end if attributes.key?(:'details') self.details = attributes[:'details'] else self.details = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'location') self.location = attributes[:'location'] else self.location = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#capabilities ⇒ Object
Workspace Capabilities
19 20 21 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 19 def capabilities @capabilities end |
#details ⇒ Object
The Workspace information
22 23 24 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 22 def details @details end |
#id ⇒ Object
Workspace ID
25 26 27 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 25 def id @id end |
#location ⇒ Object
The Workspace location
28 29 30 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 28 def location @location end |
#name ⇒ Object
The Workspace name
31 32 33 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 31 def name @name end |
#status ⇒ Object
The Workspace status
34 35 36 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 34 def status @status end |
#type ⇒ Object
The Workspace type
37 38 39 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 37 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 62 def self.attribute_map { :'capabilities' => :'capabilities', :'details' => :'details', :'id' => :'id', :'location' => :'location', :'name' => :'name', :'status' => :'status', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 315 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 85 def self.openapi_types { :'capabilities' => :'Hash<String, Boolean>', :'details' => :'WorkspaceDetails', :'id' => :'String', :'location' => :'WorkspaceLocation', :'name' => :'String', :'status' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 288 def ==(o) return true if self.equal?(o) self.class == o.class && capabilities == o.capabilities && details == o.details && id == o.id && location == o.location && name == o.name && status == o.status && type == o.type end |
#eql?(o) ⇒ Boolean
302 303 304 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 302 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 308 def hash [capabilities, details, id, location, name, status, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @capabilities.nil? invalid_properties.push('invalid value for "capabilities", capabilities cannot be nil.') end if @details.nil? invalid_properties.push('invalid value for "details", details cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @location.nil? invalid_properties.push('invalid value for "location", location cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/ibm_cloud_power/models/workspace.rb', line 202 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @capabilities.nil? return false if @details.nil? return false if @id.nil? return false if @location.nil? return false if @name.nil? return false if @status.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["off-premises", "on-premises"]) return false unless type_validator.valid?(@type) true end |