Class: IbmCloudPower::WorkspaceDetails

Inherits:
ApiModelBase show all
Defined in:
lib/ibm_cloud_power/models/workspace_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WorkspaceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::WorkspaceDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::WorkspaceDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'crn')
    self.crn = attributes[:'crn']
  else
    self.crn = nil
  end

  if attributes.key?(:'href')
    self.href = attributes[:'href']
  end

  if attributes.key?(:'network_security_groups')
    self.network_security_groups = attributes[:'network_security_groups']
  end

  if attributes.key?(:'power_edge_router')
    self.power_edge_router = attributes[:'power_edge_router']
  end
end

Instance Attribute Details

#creation_dateObject

Workspace creation date



19
20
21
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 19

def creation_date
  @creation_date
end

#crnObject

The Workspace crn



22
23
24
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 22

def crn
  @crn
end

#hrefObject

Link to Workspace Resource



25
26
27
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 25

def href
  @href
end

#network_security_groupsObject

The Workspace Network Security Groups information



28
29
30
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 28

def network_security_groups
  @network_security_groups
end

#power_edge_routerObject

The Workspace Power Edge Router information



31
32
33
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 31

def power_edge_router
  @power_edge_router
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 34

def self.attribute_map
  {
    :'creation_date' => :'creationDate',
    :'crn' => :'crn',
    :'href' => :'href',
    :'network_security_groups' => :'networkSecurityGroups',
    :'power_edge_router' => :'powerEdgeRouter'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 184

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 55

def self.openapi_types
  {
    :'creation_date' => :'Time',
    :'crn' => :'String',
    :'href' => :'String',
    :'network_security_groups' => :'WorkspaceNetworkSecurityGroupsDetails',
    :'power_edge_router' => :'WorkspacePowerEdgeRouterDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



159
160
161
162
163
164
165
166
167
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 159

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      creation_date == o.creation_date &&
      crn == o.crn &&
      href == o.href &&
      network_security_groups == o.network_security_groups &&
      power_edge_router == o.power_edge_router
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


171
172
173
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 171

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



177
178
179
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 177

def hash
  [creation_date, crn, href, network_security_groups, power_edge_router].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @crn.nil?
    invalid_properties.push('invalid value for "crn", crn cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
135
# File 'lib/ibm_cloud_power/models/workspace_details.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @creation_date.nil?
  return false if @crn.nil?
  true
end