Class: IbmCloudPower::WorkspaceSSHKey
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::WorkspaceSSHKey
- Defined in:
- lib/ibm_cloud_power/models/workspace_ssh_key.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#creation_date ⇒ Object
Date/Time of sshkey creation.
-
#description ⇒ Object
Description of the sshkey.
-
#id ⇒ Object
Unique id of ssh-key.
-
#name ⇒ Object
User defined name for the SSH key.
-
#primary_workspace ⇒ Object
Indicates if the current workspace owns the ssh key or not.
-
#ssh_key ⇒ Object
SSH RSA key.
-
#visibility ⇒ Object
Visibility of the sshkey; workspace suggests ssh-key is only accessible in a workspace, account suggests ssh-key is accessible throughout an account.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkspaceSSHKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WorkspaceSSHKey
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::WorkspaceSSHKey` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::WorkspaceSSHKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'primary_workspace') self.primary_workspace = attributes[:'primary_workspace'] else self.primary_workspace = nil end if attributes.key?(:'ssh_key') self.ssh_key = attributes[:'ssh_key'] else self.ssh_key = nil end if attributes.key?(:'visibility') self.visibility = attributes[:'visibility'] else self.visibility = 'workspace' end end |
Instance Attribute Details
#creation_date ⇒ Object
Date/Time of sshkey creation
19 20 21 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 19 def creation_date @creation_date end |
#description ⇒ Object
Description of the sshkey
22 23 24 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 22 def description @description end |
#id ⇒ Object
Unique id of ssh-key
25 26 27 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 25 def id @id end |
#name ⇒ Object
User defined name for the SSH key
28 29 30 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 28 def name @name end |
#primary_workspace ⇒ Object
Indicates if the current workspace owns the ssh key or not
31 32 33 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 31 def primary_workspace @primary_workspace end |
#ssh_key ⇒ Object
SSH RSA key
34 35 36 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 34 def ssh_key @ssh_key end |
#visibility ⇒ Object
Visibility of the sshkey; workspace suggests ssh-key is only accessible in a workspace, account suggests ssh-key is accessible throughout an account
37 38 39 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 37 def visibility @visibility end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 62 def self.attribute_map { :'creation_date' => :'creationDate', :'description' => :'description', :'id' => :'id', :'name' => :'name', :'primary_workspace' => :'primaryWorkspace', :'ssh_key' => :'sshKey', :'visibility' => :'visibility' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 294 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 85 def self.openapi_types { :'creation_date' => :'Time', :'description' => :'String', :'id' => :'String', :'name' => :'String', :'primary_workspace' => :'Boolean', :'ssh_key' => :'String', :'visibility' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 267 def ==(o) return true if self.equal?(o) self.class == o.class && creation_date == o.creation_date && description == o.description && id == o.id && name == o.name && primary_workspace == o.primary_workspace && ssh_key == o.ssh_key && visibility == o.visibility end |
#eql?(o) ⇒ Boolean
281 282 283 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 281 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 287 def hash [creation_date, description, id, name, primary_workspace, ssh_key, visibility].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end pattern = Regexp.new(/^[a-zA-Z0-9\-_][a-zA-Z0-9\-_]*$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @primary_workspace.nil? invalid_properties.push('invalid value for "primary_workspace", primary_workspace cannot be nil.') end if @ssh_key.nil? invalid_properties.push('invalid value for "ssh_key", ssh_key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ibm_cloud_power/models/workspace_ssh_key.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @name.to_s.length > 128 return false if @name !~ Regexp.new(/^[a-zA-Z0-9\-_][a-zA-Z0-9\-_]*$/) return false if @primary_workspace.nil? return false if @ssh_key.nil? visibility_validator = EnumAttributeValidator.new('String', ["account", "workspace"]) return false unless visibility_validator.valid?(@visibility) true end |