Class: IbmCloudPower::CloudConnectionCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::CloudConnectionCreate
- Defined in:
- lib/ibm_cloud_power/models/cloud_connection_create.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#classic ⇒ Object
Returns the value of attribute classic.
-
#global_routing ⇒ Object
enable global routing for this cloud connection (default=false).
-
#metered ⇒ Object
enable metered for this cloud connection (default=false).
-
#name ⇒ Object
name of the cloud connection.
-
#speed ⇒ Object
speed of the cloud connection (speed in megabits per second).
-
#subnets ⇒ Object
list of subnets to attach to cloud connection.
-
#transit_enabled ⇒ Object
enable transit gateway for this cloud connection (default=false).
-
#vpc ⇒ Object
Returns the value of attribute vpc.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CloudConnectionCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CloudConnectionCreate
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CloudConnectionCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CloudConnectionCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'classic') self.classic = attributes[:'classic'] end if attributes.key?(:'global_routing') self.global_routing = attributes[:'global_routing'] end if attributes.key?(:'metered') self.metered = attributes[:'metered'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'speed') self.speed = attributes[:'speed'] else self.speed = nil end if attributes.key?(:'subnets') if (value = attributes[:'subnets']).is_a?(Array) self.subnets = value end end if attributes.key?(:'transit_enabled') self.transit_enabled = attributes[:'transit_enabled'] end if attributes.key?(:'vpc') self.vpc = attributes[:'vpc'] end end |
Instance Attribute Details
#classic ⇒ Object
Returns the value of attribute classic.
18 19 20 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 18 def classic @classic end |
#global_routing ⇒ Object
enable global routing for this cloud connection (default=false)
21 22 23 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 21 def global_routing @global_routing end |
#metered ⇒ Object
enable metered for this cloud connection (default=false)
24 25 26 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 24 def metered @metered end |
#name ⇒ Object
name of the cloud connection
27 28 29 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 27 def name @name end |
#speed ⇒ Object
speed of the cloud connection (speed in megabits per second)
30 31 32 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 30 def speed @speed end |
#subnets ⇒ Object
list of subnets to attach to cloud connection
33 34 35 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 33 def subnets @subnets end |
#transit_enabled ⇒ Object
enable transit gateway for this cloud connection (default=false)
36 37 38 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 36 def transit_enabled @transit_enabled end |
#vpc ⇒ Object
Returns the value of attribute vpc.
38 39 40 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 38 def vpc @vpc end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 63 def self.attribute_map { :'classic' => :'classic', :'global_routing' => :'globalRouting', :'metered' => :'metered', :'name' => :'name', :'speed' => :'speed', :'subnets' => :'subnets', :'transit_enabled' => :'transitEnabled', :'vpc' => :'vpc' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 238 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 87 def self.openapi_types { :'classic' => :'CloudConnectionCreateClassic', :'global_routing' => :'Boolean', :'metered' => :'Boolean', :'name' => :'String', :'speed' => :'Integer', :'subnets' => :'Array<String>', :'transit_enabled' => :'Boolean', :'vpc' => :'CloudConnectionVpc' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 210 def ==(o) return true if self.equal?(o) self.class == o.class && classic == o.classic && global_routing == o.global_routing && metered == o.metered && name == o.name && speed == o.speed && subnets == o.subnets && transit_enabled == o.transit_enabled && vpc == o.vpc end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 231 def hash [classic, global_routing, metered, name, speed, subnets, transit_enabled, vpc].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @speed.nil? invalid_properties.push('invalid value for "speed", speed cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @speed.nil? speed_validator = EnumAttributeValidator.new('Integer', [50, 100, 200, 500, 1000, 2000, 5000, 10000]) return false unless speed_validator.valid?(@speed) true end |