Class: IbmCloudPower::CloudConnectionCreateResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::CloudConnectionCreateResponse
- Defined in:
- lib/ibm_cloud_power/models/cloud_connection_create_response.rb
Instance Attribute Summary collapse
-
#classic ⇒ Object
Returns the value of attribute classic.
-
#cloud_connection_id ⇒ Object
cloud connection ID.
-
#connection_mode ⇒ Object
type of service the gateway is attached to.
-
#creation_date ⇒ Object
creation date.
-
#global_routing ⇒ Object
enable global routing for this cloud connection (default=false).
-
#ibm_ip_address ⇒ Object
IBM IP address.
-
#job_ref ⇒ Object
Returns the value of attribute job_ref.
-
#link_status ⇒ Object
link status.
-
#metered ⇒ Object
metered.
-
#name ⇒ Object
name of the cloud connection.
-
#networks ⇒ Object
Network References.
-
#port ⇒ Object
port.
-
#speed ⇒ Object
speed of the cloud connection (speed in megabits per second).
-
#user_ip_address ⇒ Object
user IP address.
-
#vpc ⇒ Object
Returns the value of attribute vpc.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CloudConnectionCreateResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CloudConnectionCreateResponse
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CloudConnectionCreateResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CloudConnectionCreateResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'classic') self.classic = attributes[:'classic'] end if attributes.key?(:'cloud_connection_id') self.cloud_connection_id = attributes[:'cloud_connection_id'] else self.cloud_connection_id = nil end if attributes.key?(:'connection_mode') self.connection_mode = attributes[:'connection_mode'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'global_routing') self.global_routing = attributes[:'global_routing'] else self.global_routing = nil end if attributes.key?(:'ibm_ip_address') self.ibm_ip_address = attributes[:'ibm_ip_address'] else self.ibm_ip_address = nil end if attributes.key?(:'link_status') self.link_status = attributes[:'link_status'] else self.link_status = nil end if attributes.key?(:'metered') self.metered = attributes[:'metered'] else self.metered = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'networks') if (value = attributes[:'networks']).is_a?(Array) self.networks = value end end if attributes.key?(:'port') self.port = attributes[:'port'] else self.port = nil end if attributes.key?(:'speed') self.speed = attributes[:'speed'] else self.speed = nil end if attributes.key?(:'user_ip_address') self.user_ip_address = attributes[:'user_ip_address'] else self.user_ip_address = nil end if attributes.key?(:'vpc') self.vpc = attributes[:'vpc'] end if attributes.key?(:'job_ref') self.job_ref = attributes[:'job_ref'] end end |
Instance Attribute Details
#classic ⇒ Object
Returns the value of attribute classic.
18 19 20 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 18 def classic @classic end |
#cloud_connection_id ⇒ Object
cloud connection ID
21 22 23 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 21 def cloud_connection_id @cloud_connection_id end |
#connection_mode ⇒ Object
type of service the gateway is attached to
24 25 26 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 24 def connection_mode @connection_mode end |
#creation_date ⇒ Object
creation date
27 28 29 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 27 def creation_date @creation_date end |
#global_routing ⇒ Object
enable global routing for this cloud connection (default=false)
30 31 32 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 30 def global_routing @global_routing end |
#ibm_ip_address ⇒ Object
IBM IP address
33 34 35 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 33 def ibm_ip_address @ibm_ip_address end |
#job_ref ⇒ Object
Returns the value of attribute job_ref.
58 59 60 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 58 def job_ref @job_ref end |
#link_status ⇒ Object
link status
36 37 38 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 36 def link_status @link_status end |
#metered ⇒ Object
metered
39 40 41 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 39 def metered @metered end |
#name ⇒ Object
name of the cloud connection
42 43 44 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 42 def name @name end |
#networks ⇒ Object
Network References
45 46 47 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 45 def networks @networks end |
#port ⇒ Object
port
48 49 50 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 48 def port @port end |
#speed ⇒ Object
speed of the cloud connection (speed in megabits per second)
51 52 53 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 51 def speed @speed end |
#user_ip_address ⇒ Object
user IP address
54 55 56 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 54 def user_ip_address @user_ip_address end |
#vpc ⇒ Object
Returns the value of attribute vpc.
56 57 58 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 56 def vpc @vpc end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 61 def self.attribute_map { :'classic' => :'classic', :'cloud_connection_id' => :'cloudConnectionID', :'connection_mode' => :'connectionMode', :'creation_date' => :'creationDate', :'global_routing' => :'globalRouting', :'ibm_ip_address' => :'ibmIPAddress', :'link_status' => :'linkStatus', :'metered' => :'metered', :'name' => :'name', :'networks' => :'networks', :'port' => :'port', :'speed' => :'speed', :'user_ip_address' => :'userIPAddress', :'vpc' => :'vpc', :'job_ref' => :'jobRef' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 426 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
119 120 121 122 123 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 119 def self.openapi_all_of [ :'CloudConnection' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 113 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 92 def self.openapi_types { :'classic' => :'CloudConnectionClassic', :'cloud_connection_id' => :'String', :'connection_mode' => :'String', :'creation_date' => :'Time', :'global_routing' => :'Boolean', :'ibm_ip_address' => :'String', :'link_status' => :'String', :'metered' => :'Boolean', :'name' => :'String', :'networks' => :'Array<NetworkReference>', :'port' => :'String', :'speed' => :'Integer', :'user_ip_address' => :'String', :'vpc' => :'CloudConnectionVpc', :'job_ref' => :'JobReference' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 391 def ==(o) return true if self.equal?(o) self.class == o.class && classic == o.classic && cloud_connection_id == o.cloud_connection_id && connection_mode == o.connection_mode && creation_date == o.creation_date && global_routing == o.global_routing && ibm_ip_address == o.ibm_ip_address && link_status == o.link_status && metered == o.metered && name == o.name && networks == o.networks && port == o.port && speed == o.speed && user_ip_address == o.user_ip_address && vpc == o.vpc && job_ref == o.job_ref end |
#eql?(o) ⇒ Boolean
413 414 415 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 413 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
419 420 421 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 419 def hash [classic, cloud_connection_id, connection_mode, creation_date, global_routing, ibm_ip_address, link_status, metered, name, networks, port, speed, user_ip_address, vpc, job_ref].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 226 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @cloud_connection_id.nil? invalid_properties.push('invalid value for "cloud_connection_id", cloud_connection_id cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end if @global_routing.nil? invalid_properties.push('invalid value for "global_routing", global_routing cannot be nil.') end if @ibm_ip_address.nil? invalid_properties.push('invalid value for "ibm_ip_address", ibm_ip_address cannot be nil.') end if @link_status.nil? invalid_properties.push('invalid value for "link_status", link_status cannot be nil.') end if @metered.nil? invalid_properties.push('invalid value for "metered", metered cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @port.nil? invalid_properties.push('invalid value for "port", port cannot be nil.') end if @speed.nil? invalid_properties.push('invalid value for "speed", speed cannot be nil.') end if @user_ip_address.nil? invalid_properties.push('invalid value for "user_ip_address", user_ip_address cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 448 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/ibm_cloud_power/models/cloud_connection_create_response.rb', line 274 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @cloud_connection_id.nil? return false if @creation_date.nil? return false if @global_routing.nil? return false if @ibm_ip_address.nil? return false if @link_status.nil? return false if @metered.nil? return false if @name.nil? return false if @port.nil? return false if @speed.nil? return false if @user_ip_address.nil? true end |