Class: IbmCloudPower::CloudInstance
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::CloudInstance
- Defined in:
- lib/ibm_cloud_power/models/cloud_instance.rb
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
Cloud Instance Capabilities.
-
#cloud_instance_id ⇒ Object
Cloud Instance ID.
-
#enabled ⇒ Object
Indicates if the cloud instance is enabled.
-
#initialized ⇒ Object
Indicates if the cloud instance is initialized and ready for use.
-
#limits ⇒ Object
Limits on the cloud instance.
-
#name ⇒ Object
Cloud Instance Name.
-
#openstack_id ⇒ Object
The open stack ID that controls this cloud instance.
-
#pvm_instances ⇒ Object
PVM instances owned by the Cloud Instance.
-
#region ⇒ Object
The region the cloud instance lives.
-
#tenant_id ⇒ Object
The tenant ID that owns this cloud instance.
-
#usage ⇒ Object
Current usage on the cloud instance.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CloudInstance
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CloudInstance
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CloudInstance` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CloudInstance`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'capabilities') if (value = attributes[:'capabilities']).is_a?(Array) self.capabilities = value end end if attributes.key?(:'cloud_instance_id') self.cloud_instance_id = attributes[:'cloud_instance_id'] else self.cloud_instance_id = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = nil end if attributes.key?(:'initialized') self.initialized = attributes[:'initialized'] else self.initialized = nil end if attributes.key?(:'limits') self.limits = attributes[:'limits'] else self.limits = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'openstack_id') self.openstack_id = attributes[:'openstack_id'] else self.openstack_id = nil end if attributes.key?(:'pvm_instances') if (value = attributes[:'pvm_instances']).is_a?(Array) self.pvm_instances = value end else self.pvm_instances = nil end if attributes.key?(:'region') self.region = attributes[:'region'] else self.region = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'usage') self.usage = attributes[:'usage'] else self.usage = nil end end |
Instance Attribute Details
#capabilities ⇒ Object
Cloud Instance Capabilities
19 20 21 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 19 def capabilities @capabilities end |
#cloud_instance_id ⇒ Object
Cloud Instance ID
22 23 24 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 22 def cloud_instance_id @cloud_instance_id end |
#enabled ⇒ Object
Indicates if the cloud instance is enabled
25 26 27 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 25 def enabled @enabled end |
#initialized ⇒ Object
Indicates if the cloud instance is initialized and ready for use
28 29 30 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 28 def initialized @initialized end |
#limits ⇒ Object
Limits on the cloud instance
31 32 33 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 31 def limits @limits end |
#name ⇒ Object
Cloud Instance Name
34 35 36 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 34 def name @name end |
#openstack_id ⇒ Object
The open stack ID that controls this cloud instance
37 38 39 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 37 def openstack_id @openstack_id end |
#pvm_instances ⇒ Object
PVM instances owned by the Cloud Instance
40 41 42 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 40 def pvm_instances @pvm_instances end |
#region ⇒ Object
The region the cloud instance lives
43 44 45 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 43 def region @region end |
#tenant_id ⇒ Object
The tenant ID that owns this cloud instance
46 47 48 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 46 def tenant_id @tenant_id end |
#usage ⇒ Object
Current usage on the cloud instance
49 50 51 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 49 def usage @usage end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 52 def self.attribute_map { :'capabilities' => :'capabilities', :'cloud_instance_id' => :'cloudInstanceID', :'enabled' => :'enabled', :'initialized' => :'initialized', :'limits' => :'limits', :'name' => :'name', :'openstack_id' => :'openstackID', :'pvm_instances' => :'pvmInstances', :'region' => :'region', :'tenant_id' => :'tenantID', :'usage' => :'usage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 384 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 79 def self.openapi_types { :'capabilities' => :'Array<String>', :'cloud_instance_id' => :'String', :'enabled' => :'Boolean', :'initialized' => :'Boolean', :'limits' => :'CloudInstanceUsageLimits', :'name' => :'String', :'openstack_id' => :'String', :'pvm_instances' => :'Array<PVMInstanceReference>', :'region' => :'String', :'tenant_id' => :'String', :'usage' => :'CloudInstanceUsageLimits' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 353 def ==(o) return true if self.equal?(o) self.class == o.class && capabilities == o.capabilities && cloud_instance_id == o.cloud_instance_id && enabled == o.enabled && initialized == o.initialized && limits == o.limits && name == o.name && openstack_id == o.openstack_id && pvm_instances == o.pvm_instances && region == o.region && tenant_id == o.tenant_id && usage == o.usage end |
#eql?(o) ⇒ Boolean
371 372 373 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 371 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
377 378 379 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 377 def hash [capabilities, cloud_instance_id, enabled, initialized, limits, name, openstack_id, pvm_instances, region, tenant_id, usage].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 188 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @cloud_instance_id.nil? invalid_properties.push('invalid value for "cloud_instance_id", cloud_instance_id cannot be nil.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @initialized.nil? invalid_properties.push('invalid value for "initialized", initialized cannot be nil.') end if @limits.nil? invalid_properties.push('invalid value for "limits", limits cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @openstack_id.nil? invalid_properties.push('invalid value for "openstack_id", openstack_id cannot be nil.') end if @pvm_instances.nil? invalid_properties.push('invalid value for "pvm_instances", pvm_instances cannot be nil.') end if @region.nil? invalid_properties.push('invalid value for "region", region cannot be nil.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @usage.nil? invalid_properties.push('invalid value for "usage", usage cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 406 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/ibm_cloud_power/models/cloud_instance.rb', line 236 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @cloud_instance_id.nil? return false if @enabled.nil? return false if @initialized.nil? return false if @limits.nil? return false if @name.nil? return false if @openstack_id.nil? return false if @pvm_instances.nil? return false if @region.nil? return false if @tenant_id.nil? return false if @usage.nil? true end |