Class: IbmCloudPower::CreateCosImageImportJob
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::CreateCosImageImportJob
- Defined in:
- lib/ibm_cloud_power/models/create_cos_image_import_job.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Cloud Object Storage access key; required for buckets with private access.
-
#bucket_access ⇒ Object
indicates if the bucket has public or private access public access require no authentication keys private access requires hmac authentication keys (access,secret).
-
#bucket_name ⇒ Object
Cloud Object Storage bucket name; bucket-name.
-
#image_filename ⇒ Object
Cloud Object Storage image filename.
-
#image_name ⇒ Object
Name for the image that will be loaded into the boot image catalog.
-
#import_details ⇒ Object
Import details for SAP images.
-
#os_type ⇒ Object
Image OS Type, required if importing a raw image; raw images can only be imported using the command line interface.
-
#region ⇒ Object
Cloud Object Storage region.
-
#secret_key ⇒ Object
Cloud Object Storage secret key; required for buckets with private access.
-
#storage_affinity ⇒ Object
Storage affinity data used for storage pool selection.
-
#storage_pool ⇒ Object
Storage pool where the image will be loaded, if provided then storageAffinity will be ignored.
-
#storage_type ⇒ Object
Type of storage; If only using storageType for storage selection then the storage pool with the most available space will be selected if storageType is not provided the storage type will default to 'tier3'.
-
#user_tags ⇒ Object
List of user tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCosImageImportJob
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCosImageImportJob
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 135 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CreateCosImageImportJob` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CreateCosImageImportJob`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'access_key') self.access_key = attributes[:'access_key'] end if attributes.key?(:'bucket_access') self.bucket_access = attributes[:'bucket_access'] else self.bucket_access = 'private' end if attributes.key?(:'bucket_name') self.bucket_name = attributes[:'bucket_name'] else self.bucket_name = nil end if attributes.key?(:'image_filename') self.image_filename = attributes[:'image_filename'] else self.image_filename = nil end if attributes.key?(:'image_name') self.image_name = attributes[:'image_name'] else self.image_name = nil end if attributes.key?(:'import_details') self.import_details = attributes[:'import_details'] end if attributes.key?(:'os_type') self.os_type = attributes[:'os_type'] end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'secret_key') self.secret_key = attributes[:'secret_key'] end if attributes.key?(:'storage_affinity') self.storage_affinity = attributes[:'storage_affinity'] end if attributes.key?(:'storage_pool') self.storage_pool = attributes[:'storage_pool'] end if attributes.key?(:'storage_type') self.storage_type = attributes[:'storage_type'] end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#access_key ⇒ Object
Cloud Object Storage access key; required for buckets with private access
19 20 21 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 19 def access_key @access_key end |
#bucket_access ⇒ Object
indicates if the bucket has public or private access public access require no authentication keys private access requires hmac authentication keys (access,secret)
22 23 24 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 22 def bucket_access @bucket_access end |
#bucket_name ⇒ Object
Cloud Object Storage bucket name; bucket-name
25 26 27 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 25 def bucket_name @bucket_name end |
#image_filename ⇒ Object
Cloud Object Storage image filename
28 29 30 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 28 def image_filename @image_filename end |
#image_name ⇒ Object
Name for the image that will be loaded into the boot image catalog
31 32 33 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 31 def image_name @image_name end |
#import_details ⇒ Object
Import details for SAP images
34 35 36 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 34 def import_details @import_details end |
#os_type ⇒ Object
Image OS Type, required if importing a raw image; raw images can only be imported using the command line interface
37 38 39 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 37 def os_type @os_type end |
#region ⇒ Object
Cloud Object Storage region
40 41 42 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 40 def region @region end |
#secret_key ⇒ Object
Cloud Object Storage secret key; required for buckets with private access
43 44 45 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 43 def secret_key @secret_key end |
#storage_affinity ⇒ Object
Storage affinity data used for storage pool selection
46 47 48 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 46 def storage_affinity @storage_affinity end |
#storage_pool ⇒ Object
Storage pool where the image will be loaded, if provided then storageAffinity will be ignored
49 50 51 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 49 def storage_pool @storage_pool end |
#storage_type ⇒ Object
Type of storage; If only using storageType for storage selection then the storage pool with the most available space will be selected if storageType is not provided the storage type will default to 'tier3'.
52 53 54 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 52 def storage_type @storage_type end |
#user_tags ⇒ Object
List of user tags
55 56 57 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 55 def @user_tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
99 100 101 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 99 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 104 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 80 def self.attribute_map { :'access_key' => :'accessKey', :'bucket_access' => :'bucketAccess', :'bucket_name' => :'bucketName', :'image_filename' => :'imageFilename', :'image_name' => :'imageName', :'import_details' => :'importDetails', :'os_type' => :'osType', :'region' => :'region', :'secret_key' => :'secretKey', :'storage_affinity' => :'storageAffinity', :'storage_pool' => :'storagePool', :'storage_type' => :'storageType', :'user_tags' => :'userTags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 350 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 128 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 109 def self.openapi_types { :'access_key' => :'String', :'bucket_access' => :'String', :'bucket_name' => :'String', :'image_filename' => :'String', :'image_name' => :'String', :'import_details' => :'ImageImportDetails', :'os_type' => :'String', :'region' => :'String', :'secret_key' => :'String', :'storage_affinity' => :'StorageAffinity', :'storage_pool' => :'String', :'storage_type' => :'String', :'user_tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 317 def ==(o) return true if self.equal?(o) self.class == o.class && access_key == o.access_key && bucket_access == o.bucket_access && bucket_name == o.bucket_name && image_filename == o.image_filename && image_name == o.image_name && import_details == o.import_details && os_type == o.os_type && region == o.region && secret_key == o.secret_key && storage_affinity == o.storage_affinity && storage_pool == o.storage_pool && storage_type == o.storage_type && == o. end |
#eql?(o) ⇒ Boolean
337 338 339 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 337 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
343 344 345 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 343 def hash [access_key, bucket_access, bucket_name, image_filename, image_name, import_details, os_type, region, secret_key, storage_affinity, storage_pool, storage_type, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 214 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @bucket_name.nil? invalid_properties.push('invalid value for "bucket_name", bucket_name cannot be nil.') end if @image_filename.nil? invalid_properties.push('invalid value for "image_filename", image_filename cannot be nil.') end if @image_name.nil? invalid_properties.push('invalid value for "image_name", image_name cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 372 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/ibm_cloud_power/models/create_cos_image_import_job.rb', line 238 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' bucket_access_validator = EnumAttributeValidator.new('String', ["public", "private"]) return false unless bucket_access_validator.valid?(@bucket_access) return false if @bucket_name.nil? return false if @image_filename.nil? return false if @image_name.nil? os_type_validator = EnumAttributeValidator.new('String', ["aix", "ibmi", "rhel", "sles"]) return false unless os_type_validator.valid?(@os_type) return false if !@user_tags.nil? && @user_tags.length > 100 true end |