Class: IbmCloudPower::CreateDataVolume
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::CreateDataVolume
- Defined in:
- lib/ibm_cloud_power/models/create_data_volume.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#affinity_policy ⇒ Object
Affinity policy for data volume being created; ignored if volumePool provided; for policy 'affinity' requires one of affinityPVMInstance or affinityVolume to be specified; for policy 'anti-affinity' requires one of antiAffinityPVMInstances or antiAffinityVolumes to be specified.
-
#affinity_pvm_instance ⇒ Object
PVM Instance (ID or Name) to base volume affinity policy against; required if requesting affinity and affinityVolume is not provided.
-
#affinity_volume ⇒ Object
Volume (ID or Name) to base volume affinity policy against; required if requesting affinity and affinityPVMInstance is not provided.
-
#anti_affinity_pvm_instances ⇒ Object
List of pvmInstances to base volume anti-affinity policy against; required if requesting anti-affinity and antiAffinityVolumes is not provided.
-
#anti_affinity_volumes ⇒ Object
List of volumes to base volume anti-affinity policy against; required if requesting anti-affinity and antiAffinityPVMInstances is not provided.
-
#disk_type ⇒ Object
Type of Disk; if diskType is not provided the disk type will default to 'tier3'.
-
#name ⇒ Object
Volume Name.
-
#replication_enabled ⇒ Object
Indicates if the volume should be replication enabled or not.
-
#shareable ⇒ Object
Indicates if the volume is shareable between VMs.
-
#size ⇒ Object
Volume Size (GiB).
-
#user_tags ⇒ Object
List of user tags.
-
#volume_pool ⇒ Object
Volume pool where the volume will be created; if provided then affinityPolicy value will be ignored.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataVolume
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataVolume
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::CreateDataVolume` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::CreateDataVolume`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'affinity_pvm_instance') self.affinity_pvm_instance = attributes[:'affinity_pvm_instance'] end if attributes.key?(:'affinity_policy') self.affinity_policy = attributes[:'affinity_policy'] end if attributes.key?(:'affinity_volume') self.affinity_volume = attributes[:'affinity_volume'] end if attributes.key?(:'anti_affinity_pvm_instances') if (value = attributes[:'anti_affinity_pvm_instances']).is_a?(Array) self.anti_affinity_pvm_instances = value end end if attributes.key?(:'anti_affinity_volumes') if (value = attributes[:'anti_affinity_volumes']).is_a?(Array) self.anti_affinity_volumes = value end end if attributes.key?(:'disk_type') self.disk_type = attributes[:'disk_type'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'replication_enabled') self.replication_enabled = attributes[:'replication_enabled'] end if attributes.key?(:'shareable') self.shareable = attributes[:'shareable'] end if attributes.key?(:'size') self.size = attributes[:'size'] else self.size = nil end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end if attributes.key?(:'volume_pool') self.volume_pool = attributes[:'volume_pool'] end end |
Instance Attribute Details
#affinity_policy ⇒ Object
Affinity policy for data volume being created; ignored if volumePool provided; for policy 'affinity' requires one of affinityPVMInstance or affinityVolume to be specified; for policy 'anti-affinity' requires one of antiAffinityPVMInstances or antiAffinityVolumes to be specified
22 23 24 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 22 def affinity_policy @affinity_policy end |
#affinity_pvm_instance ⇒ Object
PVM Instance (ID or Name) to base volume affinity policy against; required if requesting affinity and affinityVolume is not provided
19 20 21 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 19 def affinity_pvm_instance @affinity_pvm_instance end |
#affinity_volume ⇒ Object
Volume (ID or Name) to base volume affinity policy against; required if requesting affinity and affinityPVMInstance is not provided
25 26 27 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 25 def affinity_volume @affinity_volume end |
#anti_affinity_pvm_instances ⇒ Object
List of pvmInstances to base volume anti-affinity policy against; required if requesting anti-affinity and antiAffinityVolumes is not provided
28 29 30 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 28 def anti_affinity_pvm_instances @anti_affinity_pvm_instances end |
#anti_affinity_volumes ⇒ Object
List of volumes to base volume anti-affinity policy against; required if requesting anti-affinity and antiAffinityPVMInstances is not provided
31 32 33 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 31 def anti_affinity_volumes @anti_affinity_volumes end |
#disk_type ⇒ Object
Type of Disk; if diskType is not provided the disk type will default to 'tier3'.
34 35 36 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 34 def disk_type @disk_type end |
#name ⇒ Object
Volume Name
37 38 39 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 37 def name @name end |
#replication_enabled ⇒ Object
Indicates if the volume should be replication enabled or not
40 41 42 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 40 def replication_enabled @replication_enabled end |
#shareable ⇒ Object
Indicates if the volume is shareable between VMs
43 44 45 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 43 def shareable @shareable end |
#size ⇒ Object
Volume Size (GiB)
46 47 48 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 46 def size @size end |
#user_tags ⇒ Object
List of user tags
49 50 51 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 49 def @user_tags end |
#volume_pool ⇒ Object
Volume pool where the volume will be created; if provided then affinityPolicy value will be ignored
52 53 54 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 52 def volume_pool @volume_pool end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
95 96 97 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 95 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
100 101 102 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 100 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 77 def self.attribute_map { :'affinity_pvm_instance' => :'affinityPVMInstance', :'affinity_policy' => :'affinityPolicy', :'affinity_volume' => :'affinityVolume', :'anti_affinity_pvm_instances' => :'antiAffinityPVMInstances', :'anti_affinity_volumes' => :'antiAffinityVolumes', :'disk_type' => :'diskType', :'name' => :'name', :'replication_enabled' => :'replicationEnabled', :'shareable' => :'shareable', :'size' => :'size', :'user_tags' => :'userTags', :'volume_pool' => :'volumePool' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 313 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 105 def self.openapi_types { :'affinity_pvm_instance' => :'String', :'affinity_policy' => :'String', :'affinity_volume' => :'String', :'anti_affinity_pvm_instances' => :'Array<String>', :'anti_affinity_volumes' => :'Array<String>', :'disk_type' => :'String', :'name' => :'String', :'replication_enabled' => :'Boolean', :'shareable' => :'Boolean', :'size' => :'Float', :'user_tags' => :'Array<String>', :'volume_pool' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && affinity_pvm_instance == o.affinity_pvm_instance && affinity_policy == o.affinity_policy && affinity_volume == o.affinity_volume && anti_affinity_pvm_instances == o.anti_affinity_pvm_instances && anti_affinity_volumes == o.anti_affinity_volumes && disk_type == o.disk_type && name == o.name && replication_enabled == o.replication_enabled && shareable == o.shareable && size == o.size && == o. && volume_pool == o.volume_pool end |
#eql?(o) ⇒ Boolean
300 301 302 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 300 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
306 307 308 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 306 def hash [affinity_pvm_instance, affinity_policy, affinity_volume, anti_affinity_pvm_instances, anti_affinity_volumes, disk_type, name, replication_enabled, shareable, size, , volume_pool].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @size.nil? invalid_properties.push('invalid value for "size", size cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
225 226 227 228 229 230 231 232 233 |
# File 'lib/ibm_cloud_power/models/create_data_volume.rb', line 225 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' affinity_policy_validator = EnumAttributeValidator.new('String', ["affinity", "anti-affinity"]) return false unless affinity_policy_validator.valid?(@affinity_policy) return false if @name.nil? return false if @size.nil? return false if !@user_tags.nil? && @user_tags.length > 100 true end |