Class: IbmCloudPower::Event
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::Event
- Defined in:
- lib/ibm_cloud_power/models/event.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Type of action for this event.
-
#event_id ⇒ Object
ID of the Activity.
-
#level ⇒ Object
Level of the event (notice, info, warning, error).
-
#message ⇒ Object
The (translated) message of the event.
-
#metadata ⇒ Object
Any metadata associated with the event.
-
#resource ⇒ Object
Type of resource for this event.
-
#time ⇒ Object
Time of activity in ISO 8601 - RFC3339.
-
#timestamp ⇒ Object
Time of activity in unix epoch.
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Event
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Event
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/ibm_cloud_power/models/event.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Event` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Event`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] else self.event_id = nil end if attributes.key?(:'level') self.level = attributes[:'level'] else self.level = nil end if attributes.key?(:'message') self. = attributes[:'message'] else self. = nil end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'resource') self.resource = attributes[:'resource'] else self.resource = nil end if attributes.key?(:'time') self.time = attributes[:'time'] else self.time = nil end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] else self. = nil end if attributes.key?(:'user') self.user = attributes[:'user'] end end |
Instance Attribute Details
#action ⇒ Object
Type of action for this event
19 20 21 |
# File 'lib/ibm_cloud_power/models/event.rb', line 19 def action @action end |
#event_id ⇒ Object
ID of the Activity
22 23 24 |
# File 'lib/ibm_cloud_power/models/event.rb', line 22 def event_id @event_id end |
#level ⇒ Object
Level of the event (notice, info, warning, error)
25 26 27 |
# File 'lib/ibm_cloud_power/models/event.rb', line 25 def level @level end |
#message ⇒ Object
The (translated) message of the event
28 29 30 |
# File 'lib/ibm_cloud_power/models/event.rb', line 28 def @message end |
#metadata ⇒ Object
Any metadata associated with the event
31 32 33 |
# File 'lib/ibm_cloud_power/models/event.rb', line 31 def @metadata end |
#resource ⇒ Object
Type of resource for this event
34 35 36 |
# File 'lib/ibm_cloud_power/models/event.rb', line 34 def resource @resource end |
#time ⇒ Object
Time of activity in ISO 8601 - RFC3339
37 38 39 |
# File 'lib/ibm_cloud_power/models/event.rb', line 37 def time @time end |
#timestamp ⇒ Object
Time of activity in unix epoch
40 41 42 |
# File 'lib/ibm_cloud_power/models/event.rb', line 40 def @timestamp end |
#user ⇒ Object
Returns the value of attribute user.
42 43 44 |
# File 'lib/ibm_cloud_power/models/event.rb', line 42 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/ibm_cloud_power/models/event.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/ibm_cloud_power/models/event.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ibm_cloud_power/models/event.rb', line 67 def self.attribute_map { :'action' => :'action', :'event_id' => :'eventID', :'level' => :'level', :'message' => :'message', :'metadata' => :'metadata', :'resource' => :'resource', :'time' => :'time', :'timestamp' => :'timestamp', :'user' => :'user' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/ibm_cloud_power/models/event.rb', line 332 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/ibm_cloud_power/models/event.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/ibm_cloud_power/models/event.rb', line 92 def self.openapi_types { :'action' => :'String', :'event_id' => :'String', :'level' => :'String', :'message' => :'String', :'metadata' => :'Object', :'resource' => :'String', :'time' => :'Time', :'timestamp' => :'Integer', :'user' => :'EventUser' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/ibm_cloud_power/models/event.rb', line 303 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && event_id == o.event_id && level == o.level && == o. && == o. && resource == o.resource && time == o.time && == o. && user == o.user end |
#eql?(o) ⇒ Boolean
319 320 321 |
# File 'lib/ibm_cloud_power/models/event.rb', line 319 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
325 326 327 |
# File 'lib/ibm_cloud_power/models/event.rb', line 325 def hash [action, event_id, level, , , resource, time, , user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/ibm_cloud_power/models/event.rb', line 181 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @event_id.nil? invalid_properties.push('invalid value for "event_id", event_id cannot be nil.') end if @level.nil? invalid_properties.push('invalid value for "level", level cannot be nil.') end if @message.nil? invalid_properties.push('invalid value for "message", message cannot be nil.') end if @resource.nil? invalid_properties.push('invalid value for "resource", resource cannot be nil.') end if @time.nil? invalid_properties.push('invalid value for "time", time cannot be nil.') end if @timestamp.nil? invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/ibm_cloud_power/models/event.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/ibm_cloud_power/models/event.rb', line 217 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @action.nil? return false if @event_id.nil? return false if @level.nil? level_validator = EnumAttributeValidator.new('String', ["notice", "info", "warning", "error"]) return false unless level_validator.valid?(@level) return false if @message.nil? return false if @resource.nil? return false if @time.nil? return false if @timestamp.nil? true end |