Class: IbmCloudPower::Host
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::Host
- Defined in:
- lib/ibm_cloud_power/models/host.rb
Overview
Host description
Instance Attribute Summary collapse
-
#capacity ⇒ Object
Returns the value of attribute capacity.
-
#crn ⇒ Object
The CRN for this resource.
-
#display_name ⇒ Object
Name of the host (chosen by the user).
-
#host_group ⇒ Object
Returns the value of attribute host_group.
-
#id ⇒ Object
ID of the host.
-
#state ⇒ Object
State of the host (up/down).
-
#status ⇒ Object
Status of the host (enabled/disabled).
-
#sys_type ⇒ Object
System type.
-
#user_tags ⇒ Object
List of user tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Host
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Host
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/ibm_cloud_power/models/host.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Host` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Host`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'capacity') self.capacity = attributes[:'capacity'] end if attributes.key?(:'crn') self.crn = attributes[:'crn'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'host_group') self.host_group = attributes[:'host_group'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'sys_type') self.sys_type = attributes[:'sys_type'] end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#capacity ⇒ Object
Returns the value of attribute capacity.
19 20 21 |
# File 'lib/ibm_cloud_power/models/host.rb', line 19 def capacity @capacity end |
#crn ⇒ Object
The CRN for this resource
22 23 24 |
# File 'lib/ibm_cloud_power/models/host.rb', line 22 def crn @crn end |
#display_name ⇒ Object
Name of the host (chosen by the user)
25 26 27 |
# File 'lib/ibm_cloud_power/models/host.rb', line 25 def display_name @display_name end |
#host_group ⇒ Object
Returns the value of attribute host_group.
27 28 29 |
# File 'lib/ibm_cloud_power/models/host.rb', line 27 def host_group @host_group end |
#id ⇒ Object
ID of the host
30 31 32 |
# File 'lib/ibm_cloud_power/models/host.rb', line 30 def id @id end |
#state ⇒ Object
State of the host (up/down)
33 34 35 |
# File 'lib/ibm_cloud_power/models/host.rb', line 33 def state @state end |
#status ⇒ Object
Status of the host (enabled/disabled)
36 37 38 |
# File 'lib/ibm_cloud_power/models/host.rb', line 36 def status @status end |
#sys_type ⇒ Object
System type
39 40 41 |
# File 'lib/ibm_cloud_power/models/host.rb', line 39 def sys_type @sys_type end |
#user_tags ⇒ Object
List of user tags
42 43 44 |
# File 'lib/ibm_cloud_power/models/host.rb', line 42 def @user_tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/ibm_cloud_power/models/host.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/ibm_cloud_power/models/host.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/ibm_cloud_power/models/host.rb', line 45 def self.attribute_map { :'capacity' => :'capacity', :'crn' => :'crn', :'display_name' => :'displayName', :'host_group' => :'hostGroup', :'id' => :'id', :'state' => :'state', :'status' => :'status', :'sys_type' => :'sysType', :'user_tags' => :'userTags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/ibm_cloud_power/models/host.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/ibm_cloud_power/models/host.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/ibm_cloud_power/models/host.rb', line 70 def self.openapi_types { :'capacity' => :'HostCapacity', :'crn' => :'String', :'display_name' => :'String', :'host_group' => :'HostHostGroup', :'id' => :'String', :'state' => :'String', :'status' => :'String', :'sys_type' => :'String', :'user_tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/ibm_cloud_power/models/host.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && capacity == o.capacity && crn == o.crn && display_name == o.display_name && host_group == o.host_group && id == o.id && state == o.state && status == o.status && sys_type == o.sys_type && == o. end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/ibm_cloud_power/models/host.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/ibm_cloud_power/models/host.rb', line 203 def hash [capacity, crn, display_name, host_group, id, state, status, sys_type, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 |
# File 'lib/ibm_cloud_power/models/host.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/ibm_cloud_power/models/host.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 163 |
# File 'lib/ibm_cloud_power/models/host.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@user_tags.nil? && @user_tags.length > 100 true end |