Class: IbmCloudPower::HostCapacityCores
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::HostCapacityCores
- Defined in:
- lib/ibm_cloud_power/models/host_capacity_cores.rb
Instance Attribute Summary collapse
-
#available ⇒ Object
Returns the value of attribute available.
-
#reserved ⇒ Object
Returns the value of attribute reserved.
-
#total ⇒ Object
Returns the value of attribute total.
-
#used ⇒ Object
Returns the value of attribute used.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostCapacityCores
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ HostCapacityCores
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::HostCapacityCores` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::HostCapacityCores`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'available') self.available = attributes[:'available'] else self.available = nil end if attributes.key?(:'reserved') self.reserved = attributes[:'reserved'] else self.reserved = nil end if attributes.key?(:'total') self.total = attributes[:'total'] else self.total = nil end if attributes.key?(:'used') self.used = attributes[:'used'] else self.used = nil end end |
Instance Attribute Details
#available ⇒ Object
Returns the value of attribute available.
18 19 20 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 18 def available @available end |
#reserved ⇒ Object
Returns the value of attribute reserved.
20 21 22 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 20 def reserved @reserved end |
#total ⇒ Object
Returns the value of attribute total.
22 23 24 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 22 def total @total end |
#used ⇒ Object
Returns the value of attribute used.
24 25 26 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 24 def used @used end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 27 def self.attribute_map { :'available' => :'available', :'reserved' => :'reserved', :'total' => :'total', :'used' => :'used' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
63 64 65 66 67 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 63 def self.openapi_all_of [ :'HostResourceCapacity' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 47 def self.openapi_types { :'available' => :'Float', :'reserved' => :'Float', :'total' => :'Float', :'used' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 187 def ==(o) return true if self.equal?(o) self.class == o.class && available == o.available && reserved == o.reserved && total == o.total && used == o.used end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 204 def hash [available, reserved, total, used].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @available.nil? invalid_properties.push('invalid value for "available", available cannot be nil.') end if @reserved.nil? invalid_properties.push('invalid value for "reserved", reserved cannot be nil.') end if @total.nil? invalid_properties.push('invalid value for "total", total cannot be nil.') end if @used.nil? invalid_properties.push('invalid value for "used", used cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 141 142 143 |
# File 'lib/ibm_cloud_power/models/host_capacity_cores.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @available.nil? return false if @reserved.nil? return false if @total.nil? return false if @used.nil? true end |