Class: IbmCloudPower::NetworkInterface
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::NetworkInterface
- Defined in:
- lib/ibm_cloud_power/models/network_interface.rb
Instance Attribute Summary collapse
-
#crn ⇒ Object
The Network Interface's crn.
-
#external_ip ⇒ Object
The external ip address (for pub-vlan networks).
-
#id ⇒ Object
The unique Network Interface ID.
-
#instance ⇒ Object
Returns the value of attribute instance.
-
#ip_address ⇒ Object
The ip address of this Network Interface.
-
#mac_address ⇒ Object
The mac address of the Network Interface.
-
#name ⇒ Object
Name of the Network Interface (not unique or indexable).
-
#network_security_group_id ⇒ Object
(deprecated - replaced by networkSecurityGroupIDs) ID of the Network Security Group the network interface will be added to.
-
#network_security_group_ids ⇒ Object
Network security groups that the network interface is a member of.
-
#status ⇒ Object
The status of the network address group.
-
#user_tags ⇒ Object
List of user tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkInterface
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NetworkInterface
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkInterface` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkInterface`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'crn') self.crn = attributes[:'crn'] else self.crn = nil end if attributes.key?(:'external_ip') self.external_ip = attributes[:'external_ip'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'instance') self.instance = attributes[:'instance'] end if attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] else self.ip_address = nil end if attributes.key?(:'mac_address') self.mac_address = attributes[:'mac_address'] else self.mac_address = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'network_security_group_id') self.network_security_group_id = attributes[:'network_security_group_id'] end if attributes.key?(:'network_security_group_ids') if (value = attributes[:'network_security_group_ids']).is_a?(Array) self.network_security_group_ids = value end end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#crn ⇒ Object
The Network Interface's crn
19 20 21 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 19 def crn @crn end |
#external_ip ⇒ Object
The external ip address (for pub-vlan networks)
22 23 24 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 22 def external_ip @external_ip end |
#id ⇒ Object
The unique Network Interface ID
25 26 27 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 25 def id @id end |
#instance ⇒ Object
Returns the value of attribute instance.
27 28 29 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 27 def instance @instance end |
#ip_address ⇒ Object
The ip address of this Network Interface
30 31 32 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 30 def ip_address @ip_address end |
#mac_address ⇒ Object
The mac address of the Network Interface
33 34 35 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 33 def mac_address @mac_address end |
#name ⇒ Object
Name of the Network Interface (not unique or indexable)
36 37 38 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 36 def name @name end |
#network_security_group_id ⇒ Object
(deprecated - replaced by networkSecurityGroupIDs) ID of the Network Security Group the network interface will be added to
39 40 41 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 39 def network_security_group_id @network_security_group_id end |
#network_security_group_ids ⇒ Object
Network security groups that the network interface is a member of.
42 43 44 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 42 def network_security_group_ids @network_security_group_ids end |
#status ⇒ Object
The status of the network address group
45 46 47 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 45 def status @status end |
#user_tags ⇒ Object
List of user tags
48 49 50 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 48 def @user_tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 51 def self.attribute_map { :'crn' => :'crn', :'external_ip' => :'externalIP', :'id' => :'id', :'instance' => :'instance', :'ip_address' => :'ipAddress', :'mac_address' => :'macAddress', :'name' => :'name', :'network_security_group_id' => :'networkSecurityGroupID', :'network_security_group_ids' => :'networkSecurityGroupIDs', :'status' => :'status', :'user_tags' => :'userTags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 334 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 78 def self.openapi_types { :'crn' => :'String', :'external_ip' => :'String', :'id' => :'String', :'instance' => :'NetworkInterfaceInstance', :'ip_address' => :'String', :'mac_address' => :'String', :'name' => :'String', :'network_security_group_id' => :'String', :'network_security_group_ids' => :'Array<String>', :'status' => :'String', :'user_tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 303 def ==(o) return true if self.equal?(o) self.class == o.class && crn == o.crn && external_ip == o.external_ip && id == o.id && instance == o.instance && ip_address == o.ip_address && mac_address == o.mac_address && name == o.name && network_security_group_id == o.network_security_group_id && network_security_group_ids == o.network_security_group_ids && status == o.status && == o. end |
#eql?(o) ⇒ Boolean
321 322 323 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 321 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
327 328 329 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 327 def hash [crn, external_ip, id, instance, ip_address, mac_address, name, network_security_group_id, network_security_group_ids, status, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @crn.nil? invalid_properties.push('invalid value for "crn", crn cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @ip_address.nil? invalid_properties.push('invalid value for "ip_address", ip_address cannot be nil.') end if @mac_address.nil? invalid_properties.push('invalid value for "mac_address", mac_address cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/ibm_cloud_power/models/network_interface.rb', line 215 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @crn.nil? return false if @id.nil? return false if @ip_address.nil? return false if @mac_address.nil? return false if @name.nil? return false if @status.nil? return false if !@user_tags.nil? && @user_tags.length > 100 true end |