Class: IbmCloudPower::NetworkPort
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::NetworkPort
- Defined in:
- lib/ibm_cloud_power/models/network_port.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Description of the port (not unique or indexable).
-
#external_ip ⇒ Object
The external ip address (for pub-vlan networks).
-
#href ⇒ Object
Link to port resource.
-
#ip_address ⇒ Object
The ip address of this port.
-
#mac_address ⇒ Object
The mac address of the network interface.
-
#port_id ⇒ Object
The unique Port ID.
-
#pvm_instance ⇒ Object
Returns the value of attribute pvm_instance.
-
#status ⇒ Object
Te.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkPort
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NetworkPort
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkPort` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkPort`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'external_ip') self.external_ip = attributes[:'external_ip'] end if attributes.key?(:'href') self.href = attributes[:'href'] end if attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] else self.ip_address = nil end if attributes.key?(:'mac_address') self.mac_address = attributes[:'mac_address'] else self.mac_address = nil end if attributes.key?(:'port_id') self.port_id = attributes[:'port_id'] else self.port_id = nil end if attributes.key?(:'pvm_instance') self.pvm_instance = attributes[:'pvm_instance'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end end |
Instance Attribute Details
#description ⇒ Object
Description of the port (not unique or indexable)
19 20 21 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 19 def description @description end |
#external_ip ⇒ Object
The external ip address (for pub-vlan networks)
22 23 24 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 22 def external_ip @external_ip end |
#href ⇒ Object
Link to port resource
25 26 27 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 25 def href @href end |
#ip_address ⇒ Object
The ip address of this port
28 29 30 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 28 def ip_address @ip_address end |
#mac_address ⇒ Object
The mac address of the network interface
31 32 33 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 31 def mac_address @mac_address end |
#port_id ⇒ Object
The unique Port ID
34 35 36 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 34 def port_id @port_id end |
#pvm_instance ⇒ Object
Returns the value of attribute pvm_instance.
36 37 38 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 36 def pvm_instance @pvm_instance end |
#status ⇒ Object
Te
39 40 41 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 39 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 42 def self.attribute_map { :'description' => :'description', :'external_ip' => :'externalIP', :'href' => :'href', :'ip_address' => :'ipAddress', :'mac_address' => :'macAddress', :'port_id' => :'portID', :'pvm_instance' => :'pvmInstance', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 264 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 66 def self.openapi_types { :'description' => :'String', :'external_ip' => :'String', :'href' => :'String', :'ip_address' => :'String', :'mac_address' => :'String', :'port_id' => :'String', :'pvm_instance' => :'NetworkPortPvmInstance', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && external_ip == o.external_ip && href == o.href && ip_address == o.ip_address && mac_address == o.mac_address && port_id == o.port_id && pvm_instance == o.pvm_instance && status == o.status end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 257 def hash [description, external_ip, href, ip_address, mac_address, port_id, pvm_instance, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @ip_address.nil? invalid_properties.push('invalid value for "ip_address", ip_address cannot be nil.') end if @mac_address.nil? invalid_properties.push('invalid value for "mac_address", mac_address cannot be nil.') end if @port_id.nil? invalid_properties.push('invalid value for "port_id", port_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 180 181 182 |
# File 'lib/ibm_cloud_power/models/network_port.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @description.nil? return false if @ip_address.nil? return false if @mac_address.nil? return false if @port_id.nil? return false if @status.nil? true end |