Class: IbmCloudPower::NetworkSecurityGroupAddRule
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::NetworkSecurityGroupAddRule
- Defined in:
- lib/ibm_cloud_power/models/network_security_group_add_rule.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
The action to take if the rule matches network traffic.
-
#destination_port ⇒ Object
The destination port for a network security group rule.
-
#destination_ports ⇒ Object
(deprecated - replaced by destinationPort) The destination port for a network security group rule.
-
#protocol ⇒ Object
Returns the value of attribute protocol.
-
#remote ⇒ Object
Returns the value of attribute remote.
-
#source_port ⇒ Object
The source port for a network security group rule.
-
#source_ports ⇒ Object
(deprecated - replaced by sourcePort) The source port for a network security group rule.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkSecurityGroupAddRule
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NetworkSecurityGroupAddRule
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::NetworkSecurityGroupAddRule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::NetworkSecurityGroupAddRule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'destination_port') self.destination_port = attributes[:'destination_port'] end if attributes.key?(:'destination_ports') self.destination_ports = attributes[:'destination_ports'] end if attributes.key?(:'protocol') self.protocol = attributes[:'protocol'] else self.protocol = nil end if attributes.key?(:'remote') self.remote = attributes[:'remote'] else self.remote = nil end if attributes.key?(:'source_port') self.source_port = attributes[:'source_port'] end if attributes.key?(:'source_ports') self.source_ports = attributes[:'source_ports'] end end |
Instance Attribute Details
#action ⇒ Object
The action to take if the rule matches network traffic
19 20 21 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 19 def action @action end |
#destination_port ⇒ Object
The destination port for a network security group rule.
22 23 24 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 22 def destination_port @destination_port end |
#destination_ports ⇒ Object
(deprecated - replaced by destinationPort) The destination port for a network security group rule.
25 26 27 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 25 def destination_ports @destination_ports end |
#protocol ⇒ Object
Returns the value of attribute protocol.
27 28 29 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 27 def protocol @protocol end |
#remote ⇒ Object
Returns the value of attribute remote.
29 30 31 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 29 def remote @remote end |
#source_port ⇒ Object
The source port for a network security group rule.
32 33 34 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 32 def source_port @source_port end |
#source_ports ⇒ Object
(deprecated - replaced by sourcePort) The source port for a network security group rule.
35 36 37 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 35 def source_ports @source_ports end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 60 def self.attribute_map { :'action' => :'action', :'destination_port' => :'destinationPort', :'destination_ports' => :'destinationPorts', :'protocol' => :'protocol', :'remote' => :'remote', :'source_port' => :'sourcePort', :'source_ports' => :'sourcePorts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 243 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 83 def self.openapi_types { :'action' => :'String', :'destination_port' => :'NetworkSecurityGroupRulePort', :'destination_ports' => :'NetworkSecurityGroupRulePort', :'protocol' => :'NetworkSecurityGroupRuleProtocol', :'remote' => :'NetworkSecurityGroupRuleRemote', :'source_port' => :'NetworkSecurityGroupRulePort', :'source_ports' => :'NetworkSecurityGroupRulePort' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 216 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && destination_port == o.destination_port && destination_ports == o.destination_ports && protocol == o.protocol && remote == o.remote && source_port == o.source_port && source_ports == o.source_ports end |
#eql?(o) ⇒ Boolean
230 231 232 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 230 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 236 def hash [action, destination_port, destination_ports, protocol, remote, source_port, source_ports].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 154 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @protocol.nil? invalid_properties.push('invalid value for "protocol", protocol cannot be nil.') end if @remote.nil? invalid_properties.push('invalid value for "remote", remote cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 180 181 182 |
# File 'lib/ibm_cloud_power/models/network_security_group_add_rule.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @action.nil? action_validator = EnumAttributeValidator.new('String', ["allow", "deny"]) return false unless action_validator.valid?(@action) return false if @protocol.nil? return false if @remote.nil? true end |