Class: IbmCloudPower::PCloudVPMemVolumesApi
- Inherits:
-
Object
- Object
- IbmCloudPower::PCloudVPMemVolumesApi
- Defined in:
- lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ PCloudVPMemVolumesApi
constructor
A new instance of PCloudVPMemVolumesApi.
-
#pcloud_pvminstances_vpmem_volumes_delete(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) ⇒ Object
Delete a vPMEM volume attached to this PVM Instance vPMEM volumes of PVM Instances using SAP profiles will return carved out memory.
-
#pcloud_pvminstances_vpmem_volumes_delete_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete a vPMEM volume attached to this PVM Instance vPMEM volumes of PVM Instances using SAP profiles will return carved out memory.
-
#pcloud_pvminstances_vpmem_volumes_get(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) ⇒ VPMemVolumeReference
Get information about a vPMEM volume.
-
#pcloud_pvminstances_vpmem_volumes_get_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) ⇒ Array<(VPMemVolumeReference, Integer, Hash)>
Get information about a vPMEM volume.
-
#pcloud_pvminstances_vpmem_volumes_getall(cloud_instance_id, pvm_instance_id, opts = {}) ⇒ VPMemVolumes
List all vPMEM volumes attached to this PVM Instance.
-
#pcloud_pvminstances_vpmem_volumes_getall_with_http_info(cloud_instance_id, pvm_instance_id, opts = {}) ⇒ Array<(VPMemVolumes, Integer, Hash)>
List all vPMEM volumes attached to this PVM Instance.
-
#pcloud_pvminstances_vpmem_volumes_post(cloud_instance_id, pvm_instance_id, body, opts = {}) ⇒ VPMemVolumes
Create a vPMEM volume to be attached to this PVM Instance vPMEM volumes of PVM Instances using SAP profiles will be carved out of profile total memory.
-
#pcloud_pvminstances_vpmem_volumes_post_with_http_info(cloud_instance_id, pvm_instance_id, body, opts = {}) ⇒ Array<(VPMemVolumes, Integer, Hash)>
Create a vPMEM volume to be attached to this PVM Instance vPMEM volumes of PVM Instances using SAP profiles will be carved out of profile total memory.
-
#pcloud_pvminstances_vpmem_volumes_put(cloud_instance_id, pvm_instance_id, vpmem_volume_id, body, opts = {}) ⇒ VPMemVolumeReference
Update a vPMEM volume attached to this PVM Instance.
-
#pcloud_pvminstances_vpmem_volumes_put_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, body, opts = {}) ⇒ Array<(VPMemVolumeReference, Integer, Hash)>
Update a vPMEM volume attached to this PVM Instance.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PCloudVPMemVolumesApi
Returns a new instance of PCloudVPMemVolumesApi.
19 20 21 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#pcloud_pvminstances_vpmem_volumes_delete(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) ⇒ Object
Delete a vPMEM volume attached to this PVM Instance vPMEM volumes of PVM Instances using SAP profiles will return carved out memory. Other cases are a reduction from total memory.
29 30 31 32 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 29 def pcloud_pvminstances_vpmem_volumes_delete(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) data, _status_code, _headers = pcloud_pvminstances_vpmem_volumes_delete_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts) data end |
#pcloud_pvminstances_vpmem_volumes_delete_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete a vPMEM volume attached to this PVM Instance vPMEM volumes of PVM Instances using SAP profiles will return carved out memory. Other cases are a reduction from total memory.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 41 def pcloud_pvminstances_vpmem_volumes_delete_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_delete ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_delete" end # verify the required parameter 'pvm_instance_id' is set if @api_client.config.client_side_validation && pvm_instance_id.nil? fail ArgumentError, "Missing the required parameter 'pvm_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_delete" end # verify the required parameter 'vpmem_volume_id' is set if @api_client.config.client_side_validation && vpmem_volume_id.nil? fail ArgumentError, "Missing the required parameter 'vpmem_volume_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_delete" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/pvm-instances/{pvm_instance_id}/vpmem-volumes/{vpmem_volume_id}'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{pvm_instance_id}', CGI.escape(pvm_instance_id.to_s)).sub('{vpmem_volume_id}', CGI.escape(vpmem_volume_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVPMemVolumesApi#pcloud_pvminstances_vpmem_volumes_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_pvminstances_vpmem_volumes_get(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) ⇒ VPMemVolumeReference
Get information about a vPMEM volume
103 104 105 106 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 103 def pcloud_pvminstances_vpmem_volumes_get(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) data, _status_code, _headers = pcloud_pvminstances_vpmem_volumes_get_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts) data end |
#pcloud_pvminstances_vpmem_volumes_get_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) ⇒ Array<(VPMemVolumeReference, Integer, Hash)>
Get information about a vPMEM volume
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 114 def pcloud_pvminstances_vpmem_volumes_get_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_get ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_get" end # verify the required parameter 'pvm_instance_id' is set if @api_client.config.client_side_validation && pvm_instance_id.nil? fail ArgumentError, "Missing the required parameter 'pvm_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_get" end # verify the required parameter 'vpmem_volume_id' is set if @api_client.config.client_side_validation && vpmem_volume_id.nil? fail ArgumentError, "Missing the required parameter 'vpmem_volume_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_get" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/pvm-instances/{pvm_instance_id}/vpmem-volumes/{vpmem_volume_id}'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{pvm_instance_id}', CGI.escape(pvm_instance_id.to_s)).sub('{vpmem_volume_id}', CGI.escape(vpmem_volume_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VPMemVolumeReference' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVPMemVolumesApi#pcloud_pvminstances_vpmem_volumes_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_pvminstances_vpmem_volumes_getall(cloud_instance_id, pvm_instance_id, opts = {}) ⇒ VPMemVolumes
List all vPMEM volumes attached to this PVM Instance
175 176 177 178 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 175 def pcloud_pvminstances_vpmem_volumes_getall(cloud_instance_id, pvm_instance_id, opts = {}) data, _status_code, _headers = pcloud_pvminstances_vpmem_volumes_getall_with_http_info(cloud_instance_id, pvm_instance_id, opts) data end |
#pcloud_pvminstances_vpmem_volumes_getall_with_http_info(cloud_instance_id, pvm_instance_id, opts = {}) ⇒ Array<(VPMemVolumes, Integer, Hash)>
List all vPMEM volumes attached to this PVM Instance
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 185 def pcloud_pvminstances_vpmem_volumes_getall_with_http_info(cloud_instance_id, pvm_instance_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_getall ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_getall" end # verify the required parameter 'pvm_instance_id' is set if @api_client.config.client_side_validation && pvm_instance_id.nil? fail ArgumentError, "Missing the required parameter 'pvm_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_getall" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/pvm-instances/{pvm_instance_id}/vpmem-volumes'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{pvm_instance_id}', CGI.escape(pvm_instance_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VPMemVolumes' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_getall", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVPMemVolumesApi#pcloud_pvminstances_vpmem_volumes_getall\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_pvminstances_vpmem_volumes_post(cloud_instance_id, pvm_instance_id, body, opts = {}) ⇒ VPMemVolumes
Create a vPMEM volume to be attached to this PVM Instance vPMEM volumes of PVM Instances using SAP profiles will be carved out of profile total memory. Other cases are in addition to total memory.
244 245 246 247 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 244 def pcloud_pvminstances_vpmem_volumes_post(cloud_instance_id, pvm_instance_id, body, opts = {}) data, _status_code, _headers = pcloud_pvminstances_vpmem_volumes_post_with_http_info(cloud_instance_id, pvm_instance_id, body, opts) data end |
#pcloud_pvminstances_vpmem_volumes_post_with_http_info(cloud_instance_id, pvm_instance_id, body, opts = {}) ⇒ Array<(VPMemVolumes, Integer, Hash)>
Create a vPMEM volume to be attached to this PVM Instance vPMEM volumes of PVM Instances using SAP profiles will be carved out of profile total memory. Other cases are in addition to total memory.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 256 def pcloud_pvminstances_vpmem_volumes_post_with_http_info(cloud_instance_id, pvm_instance_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_post ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_post" end # verify the required parameter 'pvm_instance_id' is set if @api_client.config.client_side_validation && pvm_instance_id.nil? fail ArgumentError, "Missing the required parameter 'pvm_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_post" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_post" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/pvm-instances/{pvm_instance_id}/vpmem-volumes'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{pvm_instance_id}', CGI.escape(pvm_instance_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'VPMemVolumes' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVPMemVolumesApi#pcloud_pvminstances_vpmem_volumes_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_pvminstances_vpmem_volumes_put(cloud_instance_id, pvm_instance_id, vpmem_volume_id, body, opts = {}) ⇒ VPMemVolumeReference
Update a vPMEM volume attached to this PVM Instance
324 325 326 327 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 324 def pcloud_pvminstances_vpmem_volumes_put(cloud_instance_id, pvm_instance_id, vpmem_volume_id, body, opts = {}) data, _status_code, _headers = pcloud_pvminstances_vpmem_volumes_put_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, body, opts) data end |
#pcloud_pvminstances_vpmem_volumes_put_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, body, opts = {}) ⇒ Array<(VPMemVolumeReference, Integer, Hash)>
Update a vPMEM volume attached to this PVM Instance
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/ibm_cloud_power/api/p_cloud_vp_mem_volumes_api.rb', line 336 def pcloud_pvminstances_vpmem_volumes_put_with_http_info(cloud_instance_id, pvm_instance_id, vpmem_volume_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_put ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_put" end # verify the required parameter 'pvm_instance_id' is set if @api_client.config.client_side_validation && pvm_instance_id.nil? fail ArgumentError, "Missing the required parameter 'pvm_instance_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_put" end # verify the required parameter 'vpmem_volume_id' is set if @api_client.config.client_side_validation && vpmem_volume_id.nil? fail ArgumentError, "Missing the required parameter 'vpmem_volume_id' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_put" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_put" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/pvm-instances/{pvm_instance_id}/vpmem-volumes/{vpmem_volume_id}'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{pvm_instance_id}', CGI.escape(pvm_instance_id.to_s)).sub('{vpmem_volume_id}', CGI.escape(vpmem_volume_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'VPMemVolumeReference' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVPMemVolumesApi.pcloud_pvminstances_vpmem_volumes_put", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVPMemVolumesApi#pcloud_pvminstances_vpmem_volumes_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |