Class: IbmCloudPower::PCloudVolumeGroupsApi
- Inherits:
-
Object
- Object
- IbmCloudPower::PCloudVolumeGroupsApi
- Defined in:
- lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ PCloudVolumeGroupsApi
constructor
A new instance of PCloudVolumeGroupsApi.
-
#pcloud_volumegroups_action_post(cloud_instance_id, volume_group_id, body, opts = {}) ⇒ Object
Perform an action on a volume group Corresponding actions are 'start', 'stop', 'reset'.
-
#pcloud_volumegroups_action_post_with_http_info(cloud_instance_id, volume_group_id, body, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Perform an action on a volume group Corresponding actions are 'start', 'stop', 'reset'.
-
#pcloud_volumegroups_delete(cloud_instance_id, volume_group_id, opts = {}) ⇒ Object
Delete a cloud instance volume group.
-
#pcloud_volumegroups_delete_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete a cloud instance volume group.
-
#pcloud_volumegroups_get(cloud_instance_id, volume_group_id, opts = {}) ⇒ VolumeGroup
Get volume Group.
-
#pcloud_volumegroups_get_details(cloud_instance_id, volume_group_id, opts = {}) ⇒ VolumeGroupDetails
Get volume Group details.
-
#pcloud_volumegroups_get_details_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(VolumeGroupDetails, Integer, Hash)>
Get volume Group details.
-
#pcloud_volumegroups_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(VolumeGroup, Integer, Hash)>
Get volume Group.
-
#pcloud_volumegroups_getall(cloud_instance_id, opts = {}) ⇒ VolumeGroups
Get all volume groups.
-
#pcloud_volumegroups_getall_details(cloud_instance_id, opts = {}) ⇒ VolumeGroupsDetails
Get all volume groups with details.
-
#pcloud_volumegroups_getall_details_with_http_info(cloud_instance_id, opts = {}) ⇒ Array<(VolumeGroupsDetails, Integer, Hash)>
Get all volume groups with details.
-
#pcloud_volumegroups_getall_with_http_info(cloud_instance_id, opts = {}) ⇒ Array<(VolumeGroups, Integer, Hash)>
Get all volume groups.
-
#pcloud_volumegroups_post(cloud_instance_id, body, opts = {}) ⇒ VolumeGroupCreateResponse
Create a new volume group.
-
#pcloud_volumegroups_post_with_http_info(cloud_instance_id, body, opts = {}) ⇒ Array<(VolumeGroupCreateResponse, Integer, Hash)>
Create a new volume group.
-
#pcloud_volumegroups_put(cloud_instance_id, volume_group_id, body, opts = {}) ⇒ Object
updates the volume group.
-
#pcloud_volumegroups_put_with_http_info(cloud_instance_id, volume_group_id, body, opts = {}) ⇒ Array<(Object, Integer, Hash)>
updates the volume group.
-
#pcloud_volumegroups_remote_copy_relationships_get(cloud_instance_id, volume_group_id, opts = {}) ⇒ VolumeGroupRemoteCopyRelationships
Get remote copy relationships of the volume belonging to volume group.
-
#pcloud_volumegroups_remote_copy_relationships_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(VolumeGroupRemoteCopyRelationships, Integer, Hash)>
Get remote copy relationships of the volume belonging to volume group.
-
#pcloud_volumegroups_storage_details_get(cloud_instance_id, volume_group_id, opts = {}) ⇒ VolumeGroupStorageDetails
Get storage details of volume group.
-
#pcloud_volumegroups_storage_details_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(VolumeGroupStorageDetails, Integer, Hash)>
Get storage details of volume group.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PCloudVolumeGroupsApi
Returns a new instance of PCloudVolumeGroupsApi.
19 20 21 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#pcloud_volumegroups_action_post(cloud_instance_id, volume_group_id, body, opts = {}) ⇒ Object
Perform an action on a volume group Corresponding actions are 'start', 'stop', 'reset'
29 30 31 32 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 29 def pcloud_volumegroups_action_post(cloud_instance_id, volume_group_id, body, opts = {}) data, _status_code, _headers = pcloud_volumegroups_action_post_with_http_info(cloud_instance_id, volume_group_id, body, opts) data end |
#pcloud_volumegroups_action_post_with_http_info(cloud_instance_id, volume_group_id, body, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Perform an action on a volume group Corresponding actions are 'start', 'stop', 'reset'
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 41 def pcloud_volumegroups_action_post_with_http_info(cloud_instance_id, volume_group_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_action_post ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_action_post" end # verify the required parameter 'volume_group_id' is set if @api_client.config.client_side_validation && volume_group_id.nil? fail ArgumentError, "Missing the required parameter 'volume_group_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_action_post" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_action_post" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups/{volume_group_id}/action'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{volume_group_id}', CGI.escape(volume_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_action_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_action_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_delete(cloud_instance_id, volume_group_id, opts = {}) ⇒ Object
Delete a cloud instance volume group
107 108 109 110 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 107 def pcloud_volumegroups_delete(cloud_instance_id, volume_group_id, opts = {}) data, _status_code, _headers = pcloud_volumegroups_delete_with_http_info(cloud_instance_id, volume_group_id, opts) data end |
#pcloud_volumegroups_delete_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete a cloud instance volume group
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 117 def pcloud_volumegroups_delete_with_http_info(cloud_instance_id, volume_group_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_delete ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_delete" end # verify the required parameter 'volume_group_id' is set if @api_client.config.client_side_validation && volume_group_id.nil? fail ArgumentError, "Missing the required parameter 'volume_group_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_delete" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups/{volume_group_id}'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{volume_group_id}', CGI.escape(volume_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_get(cloud_instance_id, volume_group_id, opts = {}) ⇒ VolumeGroup
Get volume Group
174 175 176 177 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 174 def pcloud_volumegroups_get(cloud_instance_id, volume_group_id, opts = {}) data, _status_code, _headers = pcloud_volumegroups_get_with_http_info(cloud_instance_id, volume_group_id, opts) data end |
#pcloud_volumegroups_get_details(cloud_instance_id, volume_group_id, opts = {}) ⇒ VolumeGroupDetails
Get volume Group details
241 242 243 244 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 241 def pcloud_volumegroups_get_details(cloud_instance_id, volume_group_id, opts = {}) data, _status_code, _headers = pcloud_volumegroups_get_details_with_http_info(cloud_instance_id, volume_group_id, opts) data end |
#pcloud_volumegroups_get_details_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(VolumeGroupDetails, Integer, Hash)>
Get volume Group details
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 251 def pcloud_volumegroups_get_details_with_http_info(cloud_instance_id, volume_group_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_get_details ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_get_details" end # verify the required parameter 'volume_group_id' is set if @api_client.config.client_side_validation && volume_group_id.nil? fail ArgumentError, "Missing the required parameter 'volume_group_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_get_details" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups/{volume_group_id}/details'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{volume_group_id}', CGI.escape(volume_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VolumeGroupDetails' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_get_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_get_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(VolumeGroup, Integer, Hash)>
Get volume Group
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 184 def pcloud_volumegroups_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_get ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_get" end # verify the required parameter 'volume_group_id' is set if @api_client.config.client_side_validation && volume_group_id.nil? fail ArgumentError, "Missing the required parameter 'volume_group_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_get" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups/{volume_group_id}'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{volume_group_id}', CGI.escape(volume_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VolumeGroup' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_getall(cloud_instance_id, opts = {}) ⇒ VolumeGroups
Get all volume groups
307 308 309 310 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 307 def pcloud_volumegroups_getall(cloud_instance_id, opts = {}) data, _status_code, _headers = pcloud_volumegroups_getall_with_http_info(cloud_instance_id, opts) data end |
#pcloud_volumegroups_getall_details(cloud_instance_id, opts = {}) ⇒ VolumeGroupsDetails
Get all volume groups with details
368 369 370 371 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 368 def pcloud_volumegroups_getall_details(cloud_instance_id, opts = {}) data, _status_code, _headers = pcloud_volumegroups_getall_details_with_http_info(cloud_instance_id, opts) data end |
#pcloud_volumegroups_getall_details_with_http_info(cloud_instance_id, opts = {}) ⇒ Array<(VolumeGroupsDetails, Integer, Hash)>
Get all volume groups with details
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 377 def pcloud_volumegroups_getall_details_with_http_info(cloud_instance_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_getall_details ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_getall_details" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups/details'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VolumeGroupsDetails' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_getall_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_getall_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_getall_with_http_info(cloud_instance_id, opts = {}) ⇒ Array<(VolumeGroups, Integer, Hash)>
Get all volume groups
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 316 def pcloud_volumegroups_getall_with_http_info(cloud_instance_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_getall ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_getall" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VolumeGroups' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_getall", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_getall\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_post(cloud_instance_id, body, opts = {}) ⇒ VolumeGroupCreateResponse
Create a new volume group
430 431 432 433 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 430 def pcloud_volumegroups_post(cloud_instance_id, body, opts = {}) data, _status_code, _headers = pcloud_volumegroups_post_with_http_info(cloud_instance_id, body, opts) data end |
#pcloud_volumegroups_post_with_http_info(cloud_instance_id, body, opts = {}) ⇒ Array<(VolumeGroupCreateResponse, Integer, Hash)>
Create a new volume group
440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 440 def pcloud_volumegroups_post_with_http_info(cloud_instance_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_post ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_post" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_post" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'VolumeGroupCreateResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_put(cloud_instance_id, volume_group_id, body, opts = {}) ⇒ Object
updates the volume group
503 504 505 506 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 503 def pcloud_volumegroups_put(cloud_instance_id, volume_group_id, body, opts = {}) data, _status_code, _headers = pcloud_volumegroups_put_with_http_info(cloud_instance_id, volume_group_id, body, opts) data end |
#pcloud_volumegroups_put_with_http_info(cloud_instance_id, volume_group_id, body, opts = {}) ⇒ Array<(Object, Integer, Hash)>
updates the volume group
514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 514 def pcloud_volumegroups_put_with_http_info(cloud_instance_id, volume_group_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_put ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_put" end # verify the required parameter 'volume_group_id' is set if @api_client.config.client_side_validation && volume_group_id.nil? fail ArgumentError, "Missing the required parameter 'volume_group_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_put" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_put" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups/{volume_group_id}'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{volume_group_id}', CGI.escape(volume_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_put", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_remote_copy_relationships_get(cloud_instance_id, volume_group_id, opts = {}) ⇒ VolumeGroupRemoteCopyRelationships
Get remote copy relationships of the volume belonging to volume group
580 581 582 583 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 580 def pcloud_volumegroups_remote_copy_relationships_get(cloud_instance_id, volume_group_id, opts = {}) data, _status_code, _headers = pcloud_volumegroups_remote_copy_relationships_get_with_http_info(cloud_instance_id, volume_group_id, opts) data end |
#pcloud_volumegroups_remote_copy_relationships_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(VolumeGroupRemoteCopyRelationships, Integer, Hash)>
Get remote copy relationships of the volume belonging to volume group
590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 590 def pcloud_volumegroups_remote_copy_relationships_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_remote_copy_relationships_get ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_remote_copy_relationships_get" end # verify the required parameter 'volume_group_id' is set if @api_client.config.client_side_validation && volume_group_id.nil? fail ArgumentError, "Missing the required parameter 'volume_group_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_remote_copy_relationships_get" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups/{volume_group_id}/remote-copy-relationships'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{volume_group_id}', CGI.escape(volume_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VolumeGroupRemoteCopyRelationships' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_remote_copy_relationships_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_remote_copy_relationships_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pcloud_volumegroups_storage_details_get(cloud_instance_id, volume_group_id, opts = {}) ⇒ VolumeGroupStorageDetails
Get storage details of volume group
647 648 649 650 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 647 def pcloud_volumegroups_storage_details_get(cloud_instance_id, volume_group_id, opts = {}) data, _status_code, _headers = pcloud_volumegroups_storage_details_get_with_http_info(cloud_instance_id, volume_group_id, opts) data end |
#pcloud_volumegroups_storage_details_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) ⇒ Array<(VolumeGroupStorageDetails, Integer, Hash)>
Get storage details of volume group
657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 |
# File 'lib/ibm_cloud_power/api/p_cloud_volume_groups_api.rb', line 657 def pcloud_volumegroups_storage_details_get_with_http_info(cloud_instance_id, volume_group_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PCloudVolumeGroupsApi.pcloud_volumegroups_storage_details_get ...' end # verify the required parameter 'cloud_instance_id' is set if @api_client.config.client_side_validation && cloud_instance_id.nil? fail ArgumentError, "Missing the required parameter 'cloud_instance_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_storage_details_get" end # verify the required parameter 'volume_group_id' is set if @api_client.config.client_side_validation && volume_group_id.nil? fail ArgumentError, "Missing the required parameter 'volume_group_id' when calling PCloudVolumeGroupsApi.pcloud_volumegroups_storage_details_get" end # resource path local_var_path = '/pcloud/v1/cloud-instances/{cloud_instance_id}/volume-groups/{volume_group_id}/storage-details'.sub('{cloud_instance_id}', CGI.escape(cloud_instance_id.to_s)).sub('{volume_group_id}', CGI.escape(volume_group_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VolumeGroupStorageDetails' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PCloudVolumeGroupsApi.pcloud_volumegroups_storage_details_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PCloudVolumeGroupsApi#pcloud_volumegroups_storage_details_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |