Class: IbmCloudPower::PodData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::PodData
- Defined in:
- lib/ibm_cloud_power/models/pod_data.rb
Overview
Description of a PPCaaS Pod
Instance Attribute Summary collapse
-
#cores ⇒ Object
Number of available cores in the Pod.
-
#memory ⇒ Object
Amount of available memory in the Pod (GiB).
-
#sat_location_id ⇒ Object
ID of the Satellite Location.
-
#storage ⇒ Object
Amount of available storage in the Pod (GiB).
-
#total_cores ⇒ Object
Total number of usable cores in the Pod.
-
#total_memory ⇒ Object
Total amount of usable memory in the Pod (GiB).
-
#total_phys_cores ⇒ Object
Total number of physical cores in the Pod.
-
#total_phys_memory ⇒ Object
Total amount of physical memory in the Pod (GiB).
-
#total_phys_storage ⇒ Object
Total amount of physical storage in the Pod (GiB).
-
#total_storage ⇒ Object
Total amount of usable storage in the Pod (GiB).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PodData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PodData
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::PodData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::PodData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cores') self.cores = attributes[:'cores'] else self.cores = nil end if attributes.key?(:'memory') self.memory = attributes[:'memory'] else self.memory = nil end if attributes.key?(:'sat_location_id') self.sat_location_id = attributes[:'sat_location_id'] else self.sat_location_id = nil end if attributes.key?(:'storage') self.storage = attributes[:'storage'] else self.storage = nil end if attributes.key?(:'total_cores') self.total_cores = attributes[:'total_cores'] else self.total_cores = nil end if attributes.key?(:'total_memory') self.total_memory = attributes[:'total_memory'] else self.total_memory = nil end if attributes.key?(:'total_phys_cores') self.total_phys_cores = attributes[:'total_phys_cores'] else self.total_phys_cores = nil end if attributes.key?(:'total_phys_memory') self.total_phys_memory = attributes[:'total_phys_memory'] else self.total_phys_memory = nil end if attributes.key?(:'total_phys_storage') self.total_phys_storage = attributes[:'total_phys_storage'] else self.total_phys_storage = nil end if attributes.key?(:'total_storage') self.total_storage = attributes[:'total_storage'] else self.total_storage = nil end end |
Instance Attribute Details
#cores ⇒ Object
Number of available cores in the Pod
20 21 22 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 20 def cores @cores end |
#memory ⇒ Object
Amount of available memory in the Pod (GiB)
23 24 25 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 23 def memory @memory end |
#sat_location_id ⇒ Object
ID of the Satellite Location
26 27 28 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 26 def sat_location_id @sat_location_id end |
#storage ⇒ Object
Amount of available storage in the Pod (GiB)
29 30 31 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 29 def storage @storage end |
#total_cores ⇒ Object
Total number of usable cores in the Pod
32 33 34 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 32 def total_cores @total_cores end |
#total_memory ⇒ Object
Total amount of usable memory in the Pod (GiB)
35 36 37 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 35 def total_memory @total_memory end |
#total_phys_cores ⇒ Object
Total number of physical cores in the Pod
38 39 40 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 38 def total_phys_cores @total_phys_cores end |
#total_phys_memory ⇒ Object
Total amount of physical memory in the Pod (GiB)
41 42 43 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 41 def total_phys_memory @total_phys_memory end |
#total_phys_storage ⇒ Object
Total amount of physical storage in the Pod (GiB)
44 45 46 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 44 def total_phys_storage @total_phys_storage end |
#total_storage ⇒ Object
Total amount of usable storage in the Pod (GiB)
47 48 49 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 47 def total_storage @total_storage end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 50 def self.attribute_map { :'cores' => :'cores', :'memory' => :'memory', :'sat_location_id' => :'satLocationID', :'storage' => :'storage', :'total_cores' => :'totalCores', :'total_memory' => :'totalMemory', :'total_phys_cores' => :'totalPhysCores', :'total_phys_memory' => :'totalPhysMemory', :'total_phys_storage' => :'totalPhysStorage', :'total_storage' => :'totalStorage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 371 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 76 def self.openapi_types { :'cores' => :'Float', :'memory' => :'Integer', :'sat_location_id' => :'String', :'storage' => :'Integer', :'total_cores' => :'Float', :'total_memory' => :'Integer', :'total_phys_cores' => :'Float', :'total_phys_memory' => :'Integer', :'total_phys_storage' => :'Float', :'total_storage' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 341 def ==(o) return true if self.equal?(o) self.class == o.class && cores == o.cores && memory == o.memory && sat_location_id == o.sat_location_id && storage == o.storage && total_cores == o.total_cores && total_memory == o.total_memory && total_phys_cores == o.total_phys_cores && total_phys_memory == o.total_phys_memory && total_phys_storage == o.total_phys_storage && total_storage == o.total_storage end |
#eql?(o) ⇒ Boolean
358 359 360 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 358 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
364 365 366 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 364 def hash [cores, memory, sat_location_id, storage, total_cores, total_memory, total_phys_cores, total_phys_memory, total_phys_storage, total_storage].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 176 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @cores.nil? invalid_properties.push('invalid value for "cores", cores cannot be nil.') end if @memory.nil? invalid_properties.push('invalid value for "memory", memory cannot be nil.') end if @sat_location_id.nil? invalid_properties.push('invalid value for "sat_location_id", sat_location_id cannot be nil.') end if @storage.nil? invalid_properties.push('invalid value for "storage", storage cannot be nil.') end if @total_cores.nil? invalid_properties.push('invalid value for "total_cores", total_cores cannot be nil.') end if @total_memory.nil? invalid_properties.push('invalid value for "total_memory", total_memory cannot be nil.') end if @total_phys_cores.nil? invalid_properties.push('invalid value for "total_phys_cores", total_phys_cores cannot be nil.') end if @total_phys_memory.nil? invalid_properties.push('invalid value for "total_phys_memory", total_phys_memory cannot be nil.') end if @total_phys_storage.nil? invalid_properties.push('invalid value for "total_phys_storage", total_phys_storage cannot be nil.') end if @total_storage.nil? invalid_properties.push('invalid value for "total_storage", total_storage cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 393 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/ibm_cloud_power/models/pod_data.rb', line 224 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @cores.nil? return false if @memory.nil? return false if @sat_location_id.nil? return false if @storage.nil? return false if @total_cores.nil? return false if @total_memory.nil? return false if @total_phys_cores.nil? return false if @total_phys_memory.nil? return false if @total_phys_storage.nil? return false if @total_storage.nil? true end |