Class: IbmCloudPower::RouteUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::RouteUpdate
- Defined in:
- lib/ibm_cloud_power/models/route_update.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Action.
-
#advertise ⇒ Object
Indicates if the route is advertised externally of the workspace to PER and\or peer networks.
-
#destination ⇒ Object
The route destination.
-
#destination_type ⇒ Object
The destination type.
-
#enabled ⇒ Object
Indicates if the route should be enabled in the fabric.
-
#name ⇒ Object
Name of the route.
-
#next_hop ⇒ Object
The next hop.
-
#next_hop_type ⇒ Object
The next hop type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RouteUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RouteUpdate
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::RouteUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::RouteUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'advertise') self.advertise = attributes[:'advertise'] end if attributes.key?(:'destination') self.destination = attributes[:'destination'] end if attributes.key?(:'destination_type') self.destination_type = attributes[:'destination_type'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'next_hop') self.next_hop = attributes[:'next_hop'] end if attributes.key?(:'next_hop_type') self.next_hop_type = attributes[:'next_hop_type'] end end |
Instance Attribute Details
#action ⇒ Object
Action
19 20 21 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 19 def action @action end |
#advertise ⇒ Object
Indicates if the route is advertised externally of the workspace to PER and\or peer networks
22 23 24 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 22 def advertise @advertise end |
#destination ⇒ Object
The route destination
25 26 27 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 25 def destination @destination end |
#destination_type ⇒ Object
The destination type
28 29 30 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 28 def destination_type @destination_type end |
#enabled ⇒ Object
Indicates if the route should be enabled in the fabric
31 32 33 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 31 def enabled @enabled end |
#name ⇒ Object
Name of the route
34 35 36 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 34 def name @name end |
#next_hop ⇒ Object
The next hop
37 38 39 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 37 def next_hop @next_hop end |
#next_hop_type ⇒ Object
The next hop type
40 41 42 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 40 def next_hop_type @next_hop_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 65 def self.attribute_map { :'action' => :'action', :'advertise' => :'advertise', :'destination' => :'destination', :'destination_type' => :'destinationType', :'enabled' => :'enabled', :'name' => :'name', :'next_hop' => :'nextHop', :'next_hop_type' => :'nextHopType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 280 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 89 def self.openapi_types { :'action' => :'String', :'advertise' => :'String', :'destination' => :'String', :'destination_type' => :'String', :'enabled' => :'Boolean', :'name' => :'String', :'next_hop' => :'String', :'next_hop_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && advertise == o.advertise && destination == o.destination && destination_type == o.destination_type && enabled == o.enabled && name == o.name && next_hop == o.next_hop && next_hop_type == o.next_hop_type end |
#eql?(o) ⇒ Boolean
267 268 269 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 267 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
273 274 275 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 273 def hash [action, advertise, destination, destination_type, enabled, name, next_hop, next_hop_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end pattern = Regexp.new(/^[\s]*[A-Za-z0-9:_.\-][A-Za-z0-9\s:_.\-]*$/) if !@name.nil? && @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/ibm_cloud_power/models/route_update.rb', line 176 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' action_validator = EnumAttributeValidator.new('String', ["deliver"]) return false unless action_validator.valid?(@action) advertise_validator = EnumAttributeValidator.new('String', ["enable", "disable"]) return false unless advertise_validator.valid?(@advertise) destination_type_validator = EnumAttributeValidator.new('String', ["ipv4-address"]) return false unless destination_type_validator.valid?(@destination_type) return false if !@name.nil? && @name.to_s.length > 128 return false if !@name.nil? && @name !~ Regexp.new(/^[\s]*[A-Za-z0-9:_.\-][A-Za-z0-9\s:_.\-]*$/) next_hop_type_validator = EnumAttributeValidator.new('String', ["ipv4-address"]) return false unless next_hop_type_validator.valid?(@next_hop_type) true end |