Class: IbmCloudPower::SPPPlacementGroup
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::SPPPlacementGroup
- Defined in:
- lib/ibm_cloud_power/models/spp_placement_group.rb
Instance Attribute Summary collapse
-
#crn ⇒ Object
The CRN for this resource.
-
#id ⇒ Object
The id of the Shared Processor Pool Placement Group.
-
#member_shared_processor_pools ⇒ Object
The list of Shared Processor Pool names that are a member of the Shared Processor Pool Placement Group.
-
#name ⇒ Object
The name of the Shared Processor Pool Placement Group.
-
#policy ⇒ Object
The Shared Processor Pool Placement Group policy.
-
#user_tags ⇒ Object
List of user tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SPPPlacementGroup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SPPPlacementGroup
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::SPPPlacementGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::SPPPlacementGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'crn') self.crn = attributes[:'crn'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'member_shared_processor_pools') if (value = attributes[:'member_shared_processor_pools']).is_a?(Array) self.member_shared_processor_pools = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'policy') self.policy = attributes[:'policy'] else self.policy = nil end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#crn ⇒ Object
The CRN for this resource
19 20 21 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 19 def crn @crn end |
#id ⇒ Object
The id of the Shared Processor Pool Placement Group
22 23 24 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 22 def id @id end |
#member_shared_processor_pools ⇒ Object
The list of Shared Processor Pool names that are a member of the Shared Processor Pool Placement Group
25 26 27 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 25 def member_shared_processor_pools @member_shared_processor_pools end |
#name ⇒ Object
The name of the Shared Processor Pool Placement Group
28 29 30 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 28 def name @name end |
#policy ⇒ Object
The Shared Processor Pool Placement Group policy
31 32 33 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 31 def policy @policy end |
#user_tags ⇒ Object
List of user tags
34 35 36 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 34 def @user_tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 37 def self.attribute_map { :'crn' => :'crn', :'id' => :'id', :'member_shared_processor_pools' => :'memberSharedProcessorPools', :'name' => :'name', :'policy' => :'policy', :'user_tags' => :'userTags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 234 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 59 def self.openapi_types { :'crn' => :'String', :'id' => :'String', :'member_shared_processor_pools' => :'Array<String>', :'name' => :'String', :'policy' => :'String', :'user_tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && crn == o.crn && id == o.id && member_shared_processor_pools == o.member_shared_processor_pools && name == o.name && policy == o.policy && == o. end |
#eql?(o) ⇒ Boolean
221 222 223 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 221 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 227 def hash [crn, id, member_shared_processor_pools, name, policy, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @policy.nil? invalid_properties.push('invalid value for "policy", policy cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 159 160 |
# File 'lib/ibm_cloud_power/models/spp_placement_group.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @policy.nil? return false if !@user_tags.nil? && @user_tags.length > 100 true end |