Class: IbmCloudPower::Snapshot
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::Snapshot
- Defined in:
- lib/ibm_cloud_power/models/snapshot.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
Action performed on the instance snapshot.
-
#creation_date ⇒ Object
Creation Date.
-
#description ⇒ Object
Description of the PVM instance snapshot with a maximum of 255 characters allowed.
-
#last_update_date ⇒ Object
Last Update Date.
-
#name ⇒ Object
Name of the PVM instance snapshot.
-
#percent_complete ⇒ Object
Snapshot completion percentage.
-
#pvm_instance_id ⇒ Object
PCloud PVM Instance ID.
-
#snapshot_id ⇒ Object
ID of the PVM instance snapshot.
-
#status ⇒ Object
Status of the PVM instance snapshot.
-
#status_detail ⇒ Object
Detailed information for the last PVM instance snapshot action.
-
#volume_snapshots ⇒ Object
A map of volume snapshots included in the PVM instance snapshot.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Snapshot
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Snapshot
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::Snapshot` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::Snapshot`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'last_update_date') self.last_update_date = attributes[:'last_update_date'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] end if attributes.key?(:'pvm_instance_id') self.pvm_instance_id = attributes[:'pvm_instance_id'] else self.pvm_instance_id = nil end if attributes.key?(:'snapshot_id') self.snapshot_id = attributes[:'snapshot_id'] else self.snapshot_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'status_detail') self.status_detail = attributes[:'status_detail'] end if attributes.key?(:'volume_snapshots') if (value = attributes[:'volume_snapshots']).is_a?(Hash) self.volume_snapshots = value end else self.volume_snapshots = nil end end |
Instance Attribute Details
#action ⇒ Object
Action performed on the instance snapshot
19 20 21 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 19 def action @action end |
#creation_date ⇒ Object
Creation Date
22 23 24 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 22 def creation_date @creation_date end |
#description ⇒ Object
Description of the PVM instance snapshot with a maximum of 255 characters allowed.
25 26 27 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 25 def description @description end |
#last_update_date ⇒ Object
Last Update Date
28 29 30 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 28 def last_update_date @last_update_date end |
#name ⇒ Object
Name of the PVM instance snapshot
31 32 33 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 31 def name @name end |
#percent_complete ⇒ Object
Snapshot completion percentage
34 35 36 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 34 def percent_complete @percent_complete end |
#pvm_instance_id ⇒ Object
PCloud PVM Instance ID
37 38 39 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 37 def pvm_instance_id @pvm_instance_id end |
#snapshot_id ⇒ Object
ID of the PVM instance snapshot
40 41 42 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 40 def snapshot_id @snapshot_id end |
#status ⇒ Object
Status of the PVM instance snapshot
43 44 45 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 43 def status @status end |
#status_detail ⇒ Object
Detailed information for the last PVM instance snapshot action
46 47 48 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 46 def status_detail @status_detail end |
#volume_snapshots ⇒ Object
A map of volume snapshots included in the PVM instance snapshot
49 50 51 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 49 def volume_snapshots @volume_snapshots end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 52 def self.attribute_map { :'action' => :'action', :'creation_date' => :'creationDate', :'description' => :'description', :'last_update_date' => :'lastUpdateDate', :'name' => :'name', :'percent_complete' => :'percentComplete', :'pvm_instance_id' => :'pvmInstanceID', :'snapshot_id' => :'snapshotID', :'status' => :'status', :'status_detail' => :'statusDetail', :'volume_snapshots' => :'volumeSnapshots' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 280 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 79 def self.openapi_types { :'action' => :'String', :'creation_date' => :'Time', :'description' => :'String', :'last_update_date' => :'Time', :'name' => :'String', :'percent_complete' => :'Integer', :'pvm_instance_id' => :'String', :'snapshot_id' => :'String', :'status' => :'String', :'status_detail' => :'String', :'volume_snapshots' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && action == o.action && creation_date == o.creation_date && description == o.description && last_update_date == o.last_update_date && name == o.name && percent_complete == o.percent_complete && pvm_instance_id == o.pvm_instance_id && snapshot_id == o.snapshot_id && status == o.status && status_detail == o.status_detail && volume_snapshots == o.volume_snapshots end |
#eql?(o) ⇒ Boolean
267 268 269 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 267 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
273 274 275 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 273 def hash [action, creation_date, description, last_update_date, name, percent_complete, pvm_instance_id, snapshot_id, status, status_detail, volume_snapshots].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 174 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @pvm_instance_id.nil? invalid_properties.push('invalid value for "pvm_instance_id", pvm_instance_id cannot be nil.') end if @snapshot_id.nil? invalid_properties.push('invalid value for "snapshot_id", snapshot_id cannot be nil.') end if @volume_snapshots.nil? invalid_properties.push('invalid value for "volume_snapshots", volume_snapshots cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
198 199 200 201 202 203 204 205 |
# File 'lib/ibm_cloud_power/models/snapshot.rb', line 198 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @pvm_instance_id.nil? return false if @snapshot_id.nil? return false if @volume_snapshots.nil? true end |