Class: IbmCloudPower::SnapshotCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::SnapshotCreate
- Defined in:
- lib/ibm_cloud_power/models/snapshot_create.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Description of the PVM instance snapshot.
-
#name ⇒ Object
Name of the PVM instance snapshot to create.
-
#user_tags ⇒ Object
List of user tags.
-
#volume_ids ⇒ Object
List of volumes to include in the PVM instance snapshot.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SnapshotCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SnapshotCreate
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::SnapshotCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::SnapshotCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end if attributes.key?(:'volume_ids') if (value = attributes[:'volume_ids']).is_a?(Array) self.volume_ids = value end end end |
Instance Attribute Details
#description ⇒ Object
Description of the PVM instance snapshot
19 20 21 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 19 def description @description end |
#name ⇒ Object
Name of the PVM instance snapshot to create
22 23 24 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 22 def name @name end |
#user_tags ⇒ Object
List of user tags
25 26 27 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 25 def @user_tags end |
#volume_ids ⇒ Object
List of volumes to include in the PVM instance snapshot
28 29 30 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 28 def volume_ids @volume_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 31 def self.attribute_map { :'description' => :'description', :'name' => :'name', :'user_tags' => :'userTags', :'volume_ids' => :'volumeIDs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 219 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 51 def self.openapi_types { :'description' => :'String', :'name' => :'String', :'user_tags' => :'Array<String>', :'volume_ids' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && name == o.name && == o. && volume_ids == o.volume_ids end |
#eql?(o) ⇒ Boolean
206 207 208 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 206 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 212 def hash [description, name, , volume_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@description.nil? && @description.to_s.length > 255 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 120 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 120.') end pattern = Regexp.new(/^[a-zA-Z0-9_.-]+$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 141 142 143 144 |
# File 'lib/ibm_cloud_power/models/snapshot_create.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@description.nil? && @description.to_s.length > 255 return false if @name.nil? return false if @name.to_s.length > 120 return false if @name !~ Regexp.new(/^[a-zA-Z0-9_.-]+$/) return false if !@user_tags.nil? && @user_tags.length > 100 true end |