Class: IbmCloudPower::SnapshotsApi
- Inherits:
-
Object
- Object
- IbmCloudPower::SnapshotsApi
- Defined in:
- lib/ibm_cloud_power/api/snapshots_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ SnapshotsApi
constructor
A new instance of SnapshotsApi.
-
#v1_snapshots_get(snapshot_id, opts = {}) ⇒ SnapshotV1
Get the detail of a snapshot This API is deprecated for /v1/snapshots.
-
#v1_snapshots_get_with_http_info(snapshot_id, opts = {}) ⇒ Array<(SnapshotV1, Integer, Hash)>
Get the detail of a snapshot This API is deprecated for /v1/snapshots.
-
#v1_snapshots_getall(opts = {}) ⇒ SnapshotList
Get a list of all the snapshots on a workspace This API is deprecated for /v1/snapshots.
-
#v1_snapshots_getall_with_http_info(opts = {}) ⇒ Array<(SnapshotList, Integer, Hash)>
Get a list of all the snapshots on a workspace This API is deprecated for /v1/snapshots.
-
#v1_volume_snapshots_get(opts = {}) ⇒ VolumeSnapshotList
Get the list of volume snapshots on a workspace View the usage of volume snapshots on the workspace.
-
#v1_volume_snapshots_get_0(volume_snapshot_uuid, opts = {}) ⇒ SnapshotV1
Get the detail of a volume snapshot View the usage of a snapshot.
-
#v1_volume_snapshots_get_0_with_http_info(volume_snapshot_uuid, opts = {}) ⇒ Array<(SnapshotV1, Integer, Hash)>
Get the detail of a volume snapshot View the usage of a snapshot.
-
#v1_volume_snapshots_get_with_http_info(opts = {}) ⇒ Array<(VolumeSnapshotList, Integer, Hash)>
Get the list of volume snapshots on a workspace View the usage of volume snapshots on the workspace.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SnapshotsApi
Returns a new instance of SnapshotsApi.
19 20 21 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_snapshots_get(snapshot_id, opts = {}) ⇒ SnapshotV1
Get the detail of a snapshot This API is deprecated for /v1/snapshots. The API v1/volume-snapshots has replaced this endpoint. View the usage of a snapshot. The snapshot may take time sync because the data is cached.
27 28 29 30 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 27 def v1_snapshots_get(snapshot_id, opts = {}) data, _status_code, _headers = v1_snapshots_get_with_http_info(snapshot_id, opts) data end |
#v1_snapshots_get_with_http_info(snapshot_id, opts = {}) ⇒ Array<(SnapshotV1, Integer, Hash)>
Get the detail of a snapshot This API is deprecated for /v1/snapshots. The API v1/volume-snapshots has replaced this endpoint. View the usage of a snapshot. The snapshot may take time sync because the data is cached.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 37 def v1_snapshots_get_with_http_info(snapshot_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SnapshotsApi.v1_snapshots_get ...' end # verify the required parameter 'snapshot_id' is set if @api_client.config.client_side_validation && snapshot_id.nil? fail ArgumentError, "Missing the required parameter 'snapshot_id' when calling SnapshotsApi.v1_snapshots_get" end # resource path local_var_path = '/v1/snapshots/{snapshot_id}'.sub('{snapshot_id}', CGI.escape(snapshot_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SnapshotV1' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"SnapshotsApi.v1_snapshots_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SnapshotsApi#v1_snapshots_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_snapshots_getall(opts = {}) ⇒ SnapshotList
Get a list of all the snapshots on a workspace This API is deprecated for /v1/snapshots. The API v1/volume-snapshots has replaced this endpoint. View the usage of snapshots on the workspace. The snapshots may take time sync because the data is cached.
89 90 91 92 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 89 def v1_snapshots_getall(opts = {}) data, _status_code, _headers = v1_snapshots_getall_with_http_info(opts) data end |
#v1_snapshots_getall_with_http_info(opts = {}) ⇒ Array<(SnapshotList, Integer, Hash)>
Get a list of all the snapshots on a workspace This API is deprecated for /v1/snapshots. The API v1/volume-snapshots has replaced this endpoint. View the usage of snapshots on the workspace. The snapshots may take time sync because the data is cached.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 98 def v1_snapshots_getall_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SnapshotsApi.v1_snapshots_getall ...' end # resource path local_var_path = '/v1/snapshots' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SnapshotList' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"SnapshotsApi.v1_snapshots_getall", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SnapshotsApi#v1_snapshots_getall\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_volume_snapshots_get(opts = {}) ⇒ VolumeSnapshotList
Get the list of volume snapshots on a workspace View the usage of volume snapshots on the workspace. The volume snapshots may take time sync because the data is cached.
146 147 148 149 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 146 def v1_volume_snapshots_get(opts = {}) data, _status_code, _headers = v1_volume_snapshots_get_with_http_info(opts) data end |
#v1_volume_snapshots_get_0(volume_snapshot_uuid, opts = {}) ⇒ SnapshotV1
Get the detail of a volume snapshot View the usage of a snapshot. The snapshot may take time sync because the data is cached.
204 205 206 207 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 204 def v1_volume_snapshots_get_0(volume_snapshot_uuid, opts = {}) data, _status_code, _headers = v1_volume_snapshots_get_0_with_http_info(volume_snapshot_uuid, opts) data end |
#v1_volume_snapshots_get_0_with_http_info(volume_snapshot_uuid, opts = {}) ⇒ Array<(SnapshotV1, Integer, Hash)>
Get the detail of a volume snapshot View the usage of a snapshot. The snapshot may take time sync because the data is cached.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 214 def v1_volume_snapshots_get_0_with_http_info(volume_snapshot_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SnapshotsApi.v1_volume_snapshots_get_0 ...' end # verify the required parameter 'volume_snapshot_uuid' is set if @api_client.config.client_side_validation && volume_snapshot_uuid.nil? fail ArgumentError, "Missing the required parameter 'volume_snapshot_uuid' when calling SnapshotsApi.v1_volume_snapshots_get_0" end # resource path local_var_path = '/v1/volume-snapshots/{volume_snapshot_uuid}'.sub('{volume_snapshot_uuid}', CGI.escape(volume_snapshot_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SnapshotV1' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"SnapshotsApi.v1_volume_snapshots_get_0", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SnapshotsApi#v1_volume_snapshots_get_0\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_volume_snapshots_get_with_http_info(opts = {}) ⇒ Array<(VolumeSnapshotList, Integer, Hash)>
Get the list of volume snapshots on a workspace View the usage of volume snapshots on the workspace. The volume snapshots may take time sync because the data is cached.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/ibm_cloud_power/api/snapshots_api.rb', line 155 def v1_volume_snapshots_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SnapshotsApi.v1_volume_snapshots_get ...' end # resource path local_var_path = '/v1/volume-snapshots' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VolumeSnapshotList' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"SnapshotsApi.v1_volume_snapshots_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SnapshotsApi#v1_volume_snapshots_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |