Class: IbmCloudPower::StoragePoolCapacity
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::StoragePoolCapacity
- Defined in:
- lib/ibm_cloud_power/models/storage_pool_capacity.rb
Overview
Storage pool capacity
Instance Attribute Summary collapse
-
#available_capacity ⇒ Object
Available/Unused pool capacity (GiB).
-
#max_allocation_size ⇒ Object
Maximum allocation storage size (GiB).
-
#pool_name ⇒ Object
Pool name.
-
#replication_enabled ⇒ Object
true if storage-pool is replication enabled and can be used to manage replication enabled volumes.
-
#storage_host ⇒ Object
Storage host/controller for this storage pool.
-
#storage_type ⇒ Object
Storage type of the storage pool.
-
#total_capacity ⇒ Object
Total pool capacity (GiB).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StoragePoolCapacity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StoragePoolCapacity
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::StoragePoolCapacity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::StoragePoolCapacity`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'available_capacity') self.available_capacity = attributes[:'available_capacity'] end if attributes.key?(:'max_allocation_size') self.max_allocation_size = attributes[:'max_allocation_size'] else self.max_allocation_size = nil end if attributes.key?(:'pool_name') self.pool_name = attributes[:'pool_name'] end if attributes.key?(:'replication_enabled') self.replication_enabled = attributes[:'replication_enabled'] end if attributes.key?(:'storage_host') self.storage_host = attributes[:'storage_host'] end if attributes.key?(:'storage_type') self.storage_type = attributes[:'storage_type'] end if attributes.key?(:'total_capacity') self.total_capacity = attributes[:'total_capacity'] end end |
Instance Attribute Details
#available_capacity ⇒ Object
Available/Unused pool capacity (GiB)
20 21 22 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 20 def available_capacity @available_capacity end |
#max_allocation_size ⇒ Object
Maximum allocation storage size (GiB)
23 24 25 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 23 def max_allocation_size @max_allocation_size end |
#pool_name ⇒ Object
Pool name
26 27 28 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 26 def pool_name @pool_name end |
#replication_enabled ⇒ Object
true if storage-pool is replication enabled and can be used to manage replication enabled volumes
29 30 31 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 29 def replication_enabled @replication_enabled end |
#storage_host ⇒ Object
Storage host/controller for this storage pool
32 33 34 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 32 def storage_host @storage_host end |
#storage_type ⇒ Object
Storage type of the storage pool
35 36 37 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 35 def storage_type @storage_type end |
#total_capacity ⇒ Object
Total pool capacity (GiB)
38 39 40 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 38 def total_capacity @total_capacity end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 41 def self.attribute_map { :'available_capacity' => :'availableCapacity', :'max_allocation_size' => :'maxAllocationSize', :'pool_name' => :'poolName', :'replication_enabled' => :'replicationEnabled', :'storage_host' => :'storageHost', :'storage_type' => :'storageType', :'total_capacity' => :'totalCapacity' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 188 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 64 def self.openapi_types { :'available_capacity' => :'Integer', :'max_allocation_size' => :'Integer', :'pool_name' => :'String', :'replication_enabled' => :'Boolean', :'storage_host' => :'String', :'storage_type' => :'String', :'total_capacity' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && available_capacity == o.available_capacity && max_allocation_size == o.max_allocation_size && pool_name == o.pool_name && replication_enabled == o.replication_enabled && storage_host == o.storage_host && storage_type == o.storage_type && total_capacity == o.total_capacity end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 181 def hash [available_capacity, max_allocation_size, pool_name, replication_enabled, storage_host, storage_type, total_capacity].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @max_allocation_size.nil? invalid_properties.push('invalid value for "max_allocation_size", max_allocation_size cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 |
# File 'lib/ibm_cloud_power/models/storage_pool_capacity.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @max_allocation_size.nil? true end |