Class: IbmCloudPower::SystemResources
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::SystemResources
- Defined in:
- lib/ibm_cloud_power/models/system_resources.rb
Overview
Information about the resources that a single system contains
Instance Attribute Summary collapse
-
#cores ⇒ Object
The host available Processor units.
-
#host_mtms_name ⇒ Object
The host MTMS name.
-
#id ⇒ Object
The host identifier.
-
#memory ⇒ Object
The host available RAM memory in GiB.
-
#total_cores ⇒ Object
The host total usable Processor units.
-
#total_memory ⇒ Object
The host total usable RAM memory in GiB.
-
#total_phys_cores ⇒ Object
Total number of physical cores in the Pod.
-
#total_phys_memory ⇒ Object
Total amount of physical memory in the Pod (GiB).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SystemResources
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SystemResources
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::SystemResources` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::SystemResources`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cores') self.cores = attributes[:'cores'] else self.cores = nil end if attributes.key?(:'host_mtms_name') self.host_mtms_name = attributes[:'host_mtms_name'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'memory') self.memory = attributes[:'memory'] else self.memory = nil end if attributes.key?(:'total_cores') self.total_cores = attributes[:'total_cores'] else self.total_cores = nil end if attributes.key?(:'total_memory') self.total_memory = attributes[:'total_memory'] else self.total_memory = nil end if attributes.key?(:'total_phys_cores') self.total_phys_cores = attributes[:'total_phys_cores'] else self.total_phys_cores = nil end if attributes.key?(:'total_phys_memory') self.total_phys_memory = attributes[:'total_phys_memory'] else self.total_phys_memory = nil end end |
Instance Attribute Details
#cores ⇒ Object
The host available Processor units
20 21 22 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 20 def cores @cores end |
#host_mtms_name ⇒ Object
The host MTMS name
23 24 25 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 23 def host_mtms_name @host_mtms_name end |
#id ⇒ Object
The host identifier
26 27 28 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 26 def id @id end |
#memory ⇒ Object
The host available RAM memory in GiB
29 30 31 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 29 def memory @memory end |
#total_cores ⇒ Object
The host total usable Processor units
32 33 34 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 32 def total_cores @total_cores end |
#total_memory ⇒ Object
The host total usable RAM memory in GiB
35 36 37 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 35 def total_memory @total_memory end |
#total_phys_cores ⇒ Object
Total number of physical cores in the Pod
38 39 40 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 38 def total_phys_cores @total_phys_cores end |
#total_phys_memory ⇒ Object
Total amount of physical memory in the Pod (GiB)
41 42 43 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 41 def total_phys_memory @total_phys_memory end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 44 def self.attribute_map { :'cores' => :'cores', :'host_mtms_name' => :'hostMTMSName', :'id' => :'id', :'memory' => :'memory', :'total_cores' => :'totalCores', :'total_memory' => :'totalMemory', :'total_phys_cores' => :'totalPhysCores', :'total_phys_memory' => :'totalPhysMemory' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 300 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 68 def self.openapi_types { :'cores' => :'Float', :'host_mtms_name' => :'String', :'id' => :'Integer', :'memory' => :'Integer', :'total_cores' => :'Float', :'total_memory' => :'Integer', :'total_phys_cores' => :'Float', :'total_phys_memory' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 272 def ==(o) return true if self.equal?(o) self.class == o.class && cores == o.cores && host_mtms_name == o.host_mtms_name && id == o.id && memory == o.memory && total_cores == o.total_cores && total_memory == o.total_memory && total_phys_cores == o.total_phys_cores && total_phys_memory == o.total_phys_memory end |
#eql?(o) ⇒ Boolean
287 288 289 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 287 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
293 294 295 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 293 def hash [cores, host_mtms_name, id, memory, total_cores, total_memory, total_phys_cores, total_phys_memory].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @cores.nil? invalid_properties.push('invalid value for "cores", cores cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @memory.nil? invalid_properties.push('invalid value for "memory", memory cannot be nil.') end if @total_cores.nil? invalid_properties.push('invalid value for "total_cores", total_cores cannot be nil.') end if @total_memory.nil? invalid_properties.push('invalid value for "total_memory", total_memory cannot be nil.') end if @total_phys_cores.nil? invalid_properties.push('invalid value for "total_phys_cores", total_phys_cores cannot be nil.') end if @total_phys_memory.nil? invalid_properties.push('invalid value for "total_phys_memory", total_phys_memory cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 322 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/ibm_cloud_power/models/system_resources.rb', line 188 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @cores.nil? return false if @id.nil? return false if @memory.nil? return false if @total_cores.nil? return false if @total_memory.nil? return false if @total_phys_cores.nil? return false if @total_phys_memory.nil? true end |