Class: IbmCloudPower::VolumeReference
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudPower::VolumeReference
- Defined in:
- lib/ibm_cloud_power/models/volume_reference.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aux_volume_name ⇒ Object
Auxiliary volume name at storage host level.
-
#auxiliary ⇒ Object
true if volume is auxiliary otherwise false.
-
#boot_volume ⇒ Object
Indicates if the volume is the server's boot volume.
-
#bootable ⇒ Object
Indicates if the volume is boot capable.
-
#consistency_group_name ⇒ Object
Consistency Group Name if volume is a part of volume group.
-
#creation_date ⇒ Object
Creation Date.
-
#crn ⇒ Object
The CRN for this resource.
-
#delete_on_termination ⇒ Object
Indicates if the volume should be deleted when the server terminates.
-
#disk_type ⇒ Object
Type of Disk.
-
#freeze_time ⇒ Object
Freeze time of remote copy relationship.
-
#group_id ⇒ Object
Volume Group ID.
-
#href ⇒ Object
Link to Volume resource.
-
#io_throttle_rate ⇒ Object
Amount of iops assigned to the volume.
-
#last_update_date ⇒ Object
Last Update Date.
-
#master_volume_name ⇒ Object
Master volume name at storage host level.
-
#mirroring_state ⇒ Object
mirroring state for replication enabled volume.
-
#name ⇒ Object
Volume Name.
-
#out_of_band_deleted ⇒ Object
true if volume does not exist on storage controller, as volume has been deleted by deleting its paired volume from the mapped replication site.
-
#primary_role ⇒ Object
indicates whether master/aux volume is playing the primary role.
-
#pvm_instance_ids ⇒ Object
List of PCloud PVM Instance attached to the volume.
-
#replication_enabled ⇒ Object
True if volume is replication enabled otherwise false.
-
#replication_status ⇒ Object
shows the replication status of a volume.
-
#replication_type ⇒ Object
type of replication(metro, global)s.
-
#shareable ⇒ Object
Indicates if the volume is shareable between VMs.
-
#size ⇒ Object
Volume Size.
-
#state ⇒ Object
Volume State.
-
#user_tags ⇒ Object
List of user tags.
-
#volume_id ⇒ Object
Volume ID.
-
#volume_pool ⇒ Object
Volume pool, name of storage pool where the volume is located.
-
#volume_type ⇒ Object
Volume type, name of storage template used to create the volume.
-
#wwn ⇒ Object
Volume world wide name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeReference
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumeReference
Initializes the object
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 225 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudPower::VolumeReference` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudPower::VolumeReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'aux_volume_name') self.aux_volume_name = attributes[:'aux_volume_name'] end if attributes.key?(:'auxiliary') self.auxiliary = attributes[:'auxiliary'] end if attributes.key?(:'boot_volume') self.boot_volume = attributes[:'boot_volume'] end if attributes.key?(:'bootable') self.bootable = attributes[:'bootable'] else self.bootable = nil end if attributes.key?(:'consistency_group_name') self.consistency_group_name = attributes[:'consistency_group_name'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'crn') self.crn = attributes[:'crn'] end if attributes.key?(:'delete_on_termination') self.delete_on_termination = attributes[:'delete_on_termination'] end if attributes.key?(:'disk_type') self.disk_type = attributes[:'disk_type'] else self.disk_type = nil end if attributes.key?(:'freeze_time') self.freeze_time = attributes[:'freeze_time'] end if attributes.key?(:'group_id') self.group_id = attributes[:'group_id'] end if attributes.key?(:'href') self.href = attributes[:'href'] else self.href = nil end if attributes.key?(:'io_throttle_rate') self.io_throttle_rate = attributes[:'io_throttle_rate'] end if attributes.key?(:'last_update_date') self.last_update_date = attributes[:'last_update_date'] else self.last_update_date = nil end if attributes.key?(:'master_volume_name') self.master_volume_name = attributes[:'master_volume_name'] end if attributes.key?(:'mirroring_state') self.mirroring_state = attributes[:'mirroring_state'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'out_of_band_deleted') self.out_of_band_deleted = attributes[:'out_of_band_deleted'] end if attributes.key?(:'primary_role') self.primary_role = attributes[:'primary_role'] end if attributes.key?(:'pvm_instance_ids') if (value = attributes[:'pvm_instance_ids']).is_a?(Array) self.pvm_instance_ids = value end end if attributes.key?(:'replication_enabled') self.replication_enabled = attributes[:'replication_enabled'] end if attributes.key?(:'replication_status') self.replication_status = attributes[:'replication_status'] end if attributes.key?(:'replication_type') self.replication_type = attributes[:'replication_type'] end if attributes.key?(:'shareable') self.shareable = attributes[:'shareable'] else self.shareable = nil end if attributes.key?(:'size') self.size = attributes[:'size'] else self.size = nil end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'user_tags') if (value = attributes[:'user_tags']).is_a?(Array) self. = value end end if attributes.key?(:'volume_id') self.volume_id = attributes[:'volume_id'] else self.volume_id = nil end if attributes.key?(:'volume_pool') self.volume_pool = attributes[:'volume_pool'] end if attributes.key?(:'volume_type') self.volume_type = attributes[:'volume_type'] end if attributes.key?(:'wwn') self.wwn = attributes[:'wwn'] else self.wwn = nil end end |
Instance Attribute Details
#aux_volume_name ⇒ Object
Auxiliary volume name at storage host level
19 20 21 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 19 def aux_volume_name @aux_volume_name end |
#auxiliary ⇒ Object
true if volume is auxiliary otherwise false
22 23 24 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 22 def auxiliary @auxiliary end |
#boot_volume ⇒ Object
Indicates if the volume is the server's boot volume. Only returned when querying a server's attached volumes
25 26 27 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 25 def boot_volume @boot_volume end |
#bootable ⇒ Object
Indicates if the volume is boot capable
28 29 30 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 28 def bootable @bootable end |
#consistency_group_name ⇒ Object
Consistency Group Name if volume is a part of volume group
31 32 33 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 31 def consistency_group_name @consistency_group_name end |
#creation_date ⇒ Object
Creation Date
34 35 36 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 34 def creation_date @creation_date end |
#crn ⇒ Object
The CRN for this resource
37 38 39 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 37 def crn @crn end |
#delete_on_termination ⇒ Object
Indicates if the volume should be deleted when the server terminates. Only returned when querying a server's attached volumes
40 41 42 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 40 def delete_on_termination @delete_on_termination end |
#disk_type ⇒ Object
Type of Disk
43 44 45 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 43 def disk_type @disk_type end |
#freeze_time ⇒ Object
Freeze time of remote copy relationship
46 47 48 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 46 def freeze_time @freeze_time end |
#group_id ⇒ Object
Volume Group ID
49 50 51 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 49 def group_id @group_id end |
#href ⇒ Object
Link to Volume resource
52 53 54 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 52 def href @href end |
#io_throttle_rate ⇒ Object
Amount of iops assigned to the volume
55 56 57 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 55 def io_throttle_rate @io_throttle_rate end |
#last_update_date ⇒ Object
Last Update Date
58 59 60 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 58 def last_update_date @last_update_date end |
#master_volume_name ⇒ Object
Master volume name at storage host level
61 62 63 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 61 def master_volume_name @master_volume_name end |
#mirroring_state ⇒ Object
mirroring state for replication enabled volume
64 65 66 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 64 def mirroring_state @mirroring_state end |
#name ⇒ Object
Volume Name
67 68 69 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 67 def name @name end |
#out_of_band_deleted ⇒ Object
true if volume does not exist on storage controller, as volume has been deleted by deleting its paired volume from the mapped replication site.
70 71 72 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 70 def out_of_band_deleted @out_of_band_deleted end |
#primary_role ⇒ Object
indicates whether master/aux volume is playing the primary role
73 74 75 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 73 def primary_role @primary_role end |
#pvm_instance_ids ⇒ Object
List of PCloud PVM Instance attached to the volume
76 77 78 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 76 def pvm_instance_ids @pvm_instance_ids end |
#replication_enabled ⇒ Object
True if volume is replication enabled otherwise false
79 80 81 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 79 def replication_enabled @replication_enabled end |
#replication_status ⇒ Object
shows the replication status of a volume
82 83 84 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 82 def replication_status @replication_status end |
#replication_type ⇒ Object
type of replication(metro, global)s
85 86 87 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 85 def replication_type @replication_type end |
#shareable ⇒ Object
Indicates if the volume is shareable between VMs
88 89 90 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 88 def shareable @shareable end |
#size ⇒ Object
Volume Size
91 92 93 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 91 def size @size end |
#state ⇒ Object
Volume State
94 95 96 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 94 def state @state end |
#user_tags ⇒ Object
List of user tags
97 98 99 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 97 def @user_tags end |
#volume_id ⇒ Object
Volume ID
100 101 102 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 100 def volume_id @volume_id end |
#volume_pool ⇒ Object
Volume pool, name of storage pool where the volume is located
103 104 105 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 103 def volume_pool @volume_pool end |
#volume_type ⇒ Object
Volume type, name of storage template used to create the volume
106 107 108 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 106 def volume_type @volume_type end |
#wwn ⇒ Object
Volume world wide name
109 110 111 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 109 def wwn @wwn end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
171 172 173 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 171 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
176 177 178 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 176 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 134 def self.attribute_map { :'aux_volume_name' => :'auxVolumeName', :'auxiliary' => :'auxiliary', :'boot_volume' => :'bootVolume', :'bootable' => :'bootable', :'consistency_group_name' => :'consistencyGroupName', :'creation_date' => :'creationDate', :'crn' => :'crn', :'delete_on_termination' => :'deleteOnTermination', :'disk_type' => :'diskType', :'freeze_time' => :'freezeTime', :'group_id' => :'groupID', :'href' => :'href', :'io_throttle_rate' => :'ioThrottleRate', :'last_update_date' => :'lastUpdateDate', :'master_volume_name' => :'masterVolumeName', :'mirroring_state' => :'mirroringState', :'name' => :'name', :'out_of_band_deleted' => :'outOfBandDeleted', :'primary_role' => :'primaryRole', :'pvm_instance_ids' => :'pvmInstanceIDs', :'replication_enabled' => :'replicationEnabled', :'replication_status' => :'replicationStatus', :'replication_type' => :'replicationType', :'shareable' => :'shareable', :'size' => :'size', :'state' => :'state', :'user_tags' => :'userTags', :'volume_id' => :'volumeID', :'volume_pool' => :'volumePool', :'volume_type' => :'volumeType', :'wwn' => :'wwn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 654 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
218 219 220 221 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 218 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 181 def self.openapi_types { :'aux_volume_name' => :'String', :'auxiliary' => :'Boolean', :'boot_volume' => :'Boolean', :'bootable' => :'Boolean', :'consistency_group_name' => :'String', :'creation_date' => :'Time', :'crn' => :'String', :'delete_on_termination' => :'Boolean', :'disk_type' => :'String', :'freeze_time' => :'Time', :'group_id' => :'String', :'href' => :'String', :'io_throttle_rate' => :'String', :'last_update_date' => :'Time', :'master_volume_name' => :'String', :'mirroring_state' => :'String', :'name' => :'String', :'out_of_band_deleted' => :'Boolean', :'primary_role' => :'String', :'pvm_instance_ids' => :'Array<String>', :'replication_enabled' => :'Boolean', :'replication_status' => :'String', :'replication_type' => :'String', :'shareable' => :'Boolean', :'size' => :'Float', :'state' => :'String', :'user_tags' => :'Array<String>', :'volume_id' => :'String', :'volume_pool' => :'String', :'volume_type' => :'String', :'wwn' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 603 def ==(o) return true if self.equal?(o) self.class == o.class && aux_volume_name == o.aux_volume_name && auxiliary == o.auxiliary && boot_volume == o.boot_volume && bootable == o.bootable && consistency_group_name == o.consistency_group_name && creation_date == o.creation_date && crn == o.crn && delete_on_termination == o.delete_on_termination && disk_type == o.disk_type && freeze_time == o.freeze_time && group_id == o.group_id && href == o.href && io_throttle_rate == o.io_throttle_rate && last_update_date == o.last_update_date && master_volume_name == o.master_volume_name && mirroring_state == o.mirroring_state && name == o.name && out_of_band_deleted == o.out_of_band_deleted && primary_role == o.primary_role && pvm_instance_ids == o.pvm_instance_ids && replication_enabled == o.replication_enabled && replication_status == o.replication_status && replication_type == o.replication_type && shareable == o.shareable && size == o.size && state == o.state && == o. && volume_id == o.volume_id && volume_pool == o.volume_pool && volume_type == o.volume_type && wwn == o.wwn end |
#eql?(o) ⇒ Boolean
641 642 643 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 641 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
647 648 649 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 647 def hash [aux_volume_name, auxiliary, boot_volume, bootable, consistency_group_name, creation_date, crn, delete_on_termination, disk_type, freeze_time, group_id, href, io_throttle_rate, last_update_date, master_volume_name, mirroring_state, name, out_of_band_deleted, primary_role, pvm_instance_ids, replication_enabled, replication_status, replication_type, shareable, size, state, , volume_id, volume_pool, volume_type, wwn].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 392 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @bootable.nil? invalid_properties.push('invalid value for "bootable", bootable cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end if @disk_type.nil? invalid_properties.push('invalid value for "disk_type", disk_type cannot be nil.') end if @href.nil? invalid_properties.push('invalid value for "href", href cannot be nil.') end if @last_update_date.nil? invalid_properties.push('invalid value for "last_update_date", last_update_date cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @shareable.nil? invalid_properties.push('invalid value for "shareable", shareable cannot be nil.') end if @size.nil? invalid_properties.push('invalid value for "size", size cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if !@user_tags.nil? && @user_tags.length > 100 invalid_properties.push('invalid value for "user_tags", number of items must be less than or equal to 100.') end if @volume_id.nil? invalid_properties.push('invalid value for "volume_id", volume_id cannot be nil.') end if @wwn.nil? invalid_properties.push('invalid value for "wwn", wwn cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
676 677 678 679 680 681 682 683 684 685 686 687 688 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 676 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/ibm_cloud_power/models/volume_reference.rb', line 448 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @bootable.nil? return false if @creation_date.nil? return false if @disk_type.nil? return false if @href.nil? return false if @last_update_date.nil? return false if @name.nil? primary_role_validator = EnumAttributeValidator.new('String', ["master", "aux"]) return false unless primary_role_validator.valid?(@primary_role) return false if @shareable.nil? return false if @size.nil? return false if @state.nil? return false if !@user_tags.nil? && @user_tags.length > 100 return false if @volume_id.nil? return false if @wwn.nil? true end |